@@ -1,8 +1,8 @@
 /* === S Y N F I G ========================================================= */
 /*!	\file metaballs.cpp
-**	\brief Implements metaballs
+**	\brief Implementation of the "Metaballs" layer
 **
-**	$Id: metaballs.cpp 578 2007-09-03 19:13:34Z dooglus $
+**	$Id: metaballs.cpp 1191 2007-12-10 01:58:46Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -53,10 +53,10 @@ using namespace synfig;
 
 SYNFIG_LAYER_INIT(Metaballs);
 SYNFIG_LAYER_SET_NAME(Metaballs,"metaballs");
-SYNFIG_LAYER_SET_LOCAL_NAME(Metaballs,_("Metaballs"));
-SYNFIG_LAYER_SET_CATEGORY(Metaballs,_("Default"));
+SYNFIG_LAYER_SET_LOCAL_NAME(Metaballs,N_("Metaballs"));
+SYNFIG_LAYER_SET_CATEGORY(Metaballs,N_("Default"));
 SYNFIG_LAYER_SET_VERSION(Metaballs,"0.1");
-SYNFIG_LAYER_SET_CVS_ID(Metaballs,"$Id: metaballs.cpp 578 2007-09-03 19:13:34Z dooglus $");
+SYNFIG_LAYER_SET_CVS_ID(Metaballs,"$Id: metaballs.cpp 1191 2007-12-10 01:58:46Z dooglus $");
 
 /* === P R O C E D U R E S ================================================= */
 
