@@ -1,13 +1,13 @@
 /* === S Y N F I G ========================================================= */
 /*!	\file lyr_freetype.cpp
-**	\brief Template Header
+**	\brief Implementation of the "Text" layer
 **
-**	$Id: lyr_freetype.cpp 848 2007-10-06 02:25:36Z dooglus $
+**	$Id: lyr_freetype.cpp 1643 2008-02-09 19:12:18Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
 **	Copyright (c) 2006 Paul Wise
-**	Copyright (c) 2007 Chris Moore
+**	Copyright (c) 2007, 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -39,8 +39,6 @@
 #endif
 
 #include "lyr_freetype.h"
-
-
 #endif
 
 using namespace std;
@@ -55,7 +53,6 @@ using namespace synfig;
 #define PANGO_STYLE_OBLIQUE (1)
 #define PANGO_STYLE_ITALIC (2)
 
-
 #define WEIGHT_NORMAL (400)
 #define WEIGHT_BOLD (700)
 
@@ -63,10 +60,10 @@ using namespace synfig;
 
 SYNFIG_LAYER_INIT(Layer_Freetype);
 SYNFIG_LAYER_SET_NAME(Layer_Freetype,"text");
-SYNFIG_LAYER_SET_LOCAL_NAME(Layer_Freetype,_("Text"));
-SYNFIG_LAYER_SET_CATEGORY(Layer_Freetype,_("Other"));
+SYNFIG_LAYER_SET_LOCAL_NAME(Layer_Freetype,N_("Text"));
+SYNFIG_LAYER_SET_CATEGORY(Layer_Freetype,N_("Other"));
 SYNFIG_LAYER_SET_VERSION(Layer_Freetype,"0.2");
-SYNFIG_LAYER_SET_CVS_ID(Layer_Freetype,"$Id: lyr_freetype.cpp 848 2007-10-06 02:25:36Z dooglus $");
+SYNFIG_LAYER_SET_CVS_ID(Layer_Freetype,"$Id: lyr_freetype.cpp 1643 2008-02-09 19:12:18Z dooglus $");
 
 /* === P R O C E D U R E S ================================================= */
 
@@ -148,12 +145,14 @@ Layer_Freetype::new_font_(const synfig::String &font_fam_, int style, int weight
 	//end evil hack
 
 	if(font_fam=="arial black")
+	{
 #ifndef __APPLE__
-	if(new_face("ariblk"))
+		if(new_face("ariblk"))
 			return true;
 		else
 #endif
 		font_fam="sans serif";
+	}
 
 	if(font_fam=="sans serif" || font_fam=="arial")
 	{
@@ -228,7 +227,6 @@ Layer_Freetype::new_font_(const synfig::String &font_fam_, int style, int weight
 			return true;
 	}
 
-
 	if(font_fam=="sans serif" || font_fam=="luxi sans")
 	{
 		{
@@ -240,7 +238,6 @@ Layer_Freetype::new_font_(const synfig::String &font_fam_, int style, int weight
 			if(style==PANGO_STYLE_ITALIC||style==PANGO_STYLE_OBLIQUE)
 				luxi+='i';
 
-
 			if(new_face(luxi))
 				return true;
 		}
@@ -370,7 +367,6 @@ Layer_Freetype::new_face(const String &newfont)
 			synfig::info(__FILE__":%d: \"%s\" -- ft_error=%d",__LINE__,newfont.c_str(),error);
 			// Unable to generate fs_spec
 		}
-
 	}
 #endif
 
@@ -381,7 +377,7 @@ Layer_Freetype::new_face(const String &newfont)
 		FcResult result;
 		if( !FcInit() )
 		{
-			synfig::warning("Layer_Freetype: fontconfig: %s",_("unable to initialise"));
+			synfig::warning("Layer_Freetype: fontconfig: %s",_("unable to initialize"));
 			error = 1;
 		} else {
 			FcPattern* pat = FcNameParse((FcChar8 *) newfont.c_str());
@@ -463,7 +459,9 @@ Layer_Freetype::set_param(const String & param, const ValueBase &value)
 	IMPORT_PLUS(size, if(old_version){size/=2.0;} needs_sync_=true );
 	IMPORT_PLUS(text,needs_sync_=true);
 	IMPORT_PLUS(pos,needs_sync_=true);
-	IMPORT(color);
+	IMPORT_PLUS(color, { if (color.get_a() == 0) { if (converted_blend_) {
+					set_blend_method(Color::BLEND_ALPHA_OVER);
+					color.set_a(1); } else transparent_color_ = true; } });
 	IMPORT(invert);
 	IMPORT_PLUS(orient,needs_sync_=true);
 	IMPORT_PLUS(compress,needs_sync_=true);
@@ -593,10 +591,15 @@ void
 Layer_Freetype::sync()
 {
 	needs_sync_=false;
+}
 
-
-
-
+inline Color
+Layer_Freetype::color_func(const Point &point_, int quality, float supersample)const
+{
+	if (invert)
+		return color;
+	else
+		return Color::alpha();
 }
 
 Color
@@ -605,9 +608,15 @@ Layer_Freetype::get_color(Context context, const synfig::Point &pos)const
 	if(needs_sync_)
 		const_cast<Layer_Freetype*>(this)->sync();
 
+	const Color color(color_func(pos,0));
+
 	if(!face)
 		return context.get_color(pos);
-	return context.get_color(pos);
+
+	if(get_amount()==1.0 && get_blend_method()==Color::BLEND_STRAIGHT)
+		return color;
+	else
+		return Color::blend(color,context.get_color(pos),get_amount(),get_blend_method());
 }
 
 bool
@@ -618,9 +627,6 @@ Layer_Freetype::accelerated_render(Context context,Surface *surface,int quality,
 	if(needs_sync_)
 		const_cast<Layer_Freetype*>(this)->sync();
 
-
-
-
 	int error;
 	Vector size(Layer_Freetype::size*2);
 
@@ -697,6 +703,9 @@ Layer_Freetype::accelerated_render(Context context,Surface *surface,int quality,
  --	** -- CREATE GLYPHS -------------------------------------------------------
 	*/
 
+	mbstate_t ps;
+	memset(&ps, 0, sizeof(ps));
+
 	lines.push_front(TextLine());
 	string::const_iterator iter;
 	for (iter=text.begin(); iter!=text.end(); ++iter)
@@ -716,7 +725,29 @@ Layer_Freetype::accelerated_render(Context context,Surface *surface,int quality,
 			glyph_index = FT_Get_Char_Index( face, ' ' );
 		}
 		else
-			glyph_index = FT_Get_Char_Index( face, *iter );
+		{
+			wchar_t wc;
+			size_t converted = mbrtowc(&wc, &(*iter), text.end() - iter, &ps);
+
+			if(converted == (size_t)(-1))
+			{
+				synfig::warning("Layer_Freetype: multibyte: %s",
+								_("Invalid multibyte sequence - is the locale set?\n"));
+				continue;
+			}
+
+			if(converted == (size_t)(-2))
+			{
+				synfig::warning("Layer_Freetype: multibyte: %s",
+								_("Can't parse multibyte character.\n"));
+				continue;
+			}
+
+			glyph_index = FT_Get_Char_Index( face, wc );
+
+			if(converted > 1)
+				iter += converted - 1;
+		}
 
         // retrieve kerning distance and move pen position
 		if ( FT_HAS_KERNING(face) && use_kerning && previous && glyph_index )
@@ -777,7 +808,6 @@ Layer_Freetype::accelerated_render(Context context,Surface *surface,int quality,
 
 	}
 
-
 	//float	string_height;
 	//string_height=(((lines.size()-1)*face->size->metrics.height+lines.back().actual_height()));
 
@@ -788,6 +818,11 @@ Layer_Freetype::accelerated_render(Context context,Surface *surface,int quality,
 	float line_height;
 	line_height=vcompress*((float)face->height*(((float)face->size->metrics.y_scale/METRICS_SCALE_ONE)));
 
+	// This module sees to expect pixel height to be negative, as it
+	// usually is.  But rendering to .bmp format causes ph to be
+	// positive, which was causing text to be rendered upside down.
+	if (ph>0) line_height = -line_height;
+
 	int	string_height;
 	string_height=round_to_int(((lines.size()-1)*line_height+lines.back().actual_height()));
 	//synfig::info("string_height=%d",string_height);
@@ -813,55 +848,61 @@ Layer_Freetype::accelerated_render(Context context,Surface *surface,int quality,
 	}
 
 	{
-	std::list<TextLine>::iterator iter;
-	int curr_line;
-	for(curr_line=0,iter=lines.begin();iter!=lines.end();++iter,curr_line++)
-	{
-		bx=round_to_int((pos[0]-renddesc.get_tl()[0])*pw*CHAR_RESOLUTION-orient[0]*iter->width);
-		by=round_to_int((pos[1]-renddesc.get_tl()[1])*ph*CHAR_RESOLUTION+(1.0-orient[1])*string_height-line_height*curr_line);
-		//by=round_to_int(vcompress*((pos[1]-renddesc.get_tl()[1])*ph*64+(1.0-orient[1])*string_height-face->size->metrics.height*curr_line));
-		//synfig::info("curr_line=%d, bx=%d, by=%d",curr_line,bx,by);
-
-		std::vector<Glyph>::iterator iter2;
-		for(iter2=iter->glyph_table.begin();iter2!=iter->glyph_table.end();++iter2)
+		std::list<TextLine>::iterator iter;
+		int curr_line;
+		for(curr_line=0,iter=lines.begin();iter!=lines.end();++iter,curr_line++)
 		{
-			FT_Glyph  image(iter2->glyph);
-			FT_Vector pen;
-			FT_BitmapGlyph  bit;
+			bx=round_to_int((pos[0]-renddesc.get_tl()[0])*pw*CHAR_RESOLUTION-orient[0]*iter->width);
+			// I've no idea why 1.5, but it kind of works.  Otherwise,
+			// rendering to .bmp (which renders from bottom to top, due to
+			// the .bmp format describing the image from bottom to top,
+			// renders text in the wrong place.
+			by=round_to_int((pos[1]-renddesc.get_tl()[1])*ph*CHAR_RESOLUTION +
+							(1.0-orient[1])*string_height-line_height*curr_line +
+							((ph>0) ? line_height/1.5 : 0));
 
-			pen.x = bx + iter2->pos.x;
-			pen.y = by + iter2->pos.y;
+			//by=round_to_int(vcompress*((pos[1]-renddesc.get_tl()[1])*ph*64+(1.0-orient[1])*string_height-face->size->metrics.height*curr_line));
+			//synfig::info("curr_line=%d, bx=%d, by=%d",curr_line,bx,by);
 
-			//synfig::info("GLYPH: pen.x=%d, pen,y=%d",curr_line,(pen.x+32)>>6,(pen.y+32)>>6);
+			std::vector<Glyph>::iterator iter2;
+			for(iter2=iter->glyph_table.begin();iter2!=iter->glyph_table.end();++iter2)
+			{
+				FT_Glyph  image(iter2->glyph);
+				FT_Vector pen;
+				FT_BitmapGlyph  bit;
 
-			error = FT_Glyph_To_Bitmap( &image, ft_render_mode_normal,0/*&pen*/, 1 );
-			if(error) { FT_Done_Glyph( image ); continue; }
+				pen.x = bx + iter2->pos.x;
+				pen.y = by + iter2->pos.y;
 
-			bit = (FT_BitmapGlyph)image;
+				//synfig::info("GLYPH: line %d, pen.x=%d, pen,y=%d",curr_line,(pen.x+32)>>6,(pen.y+32)>>6);
 
-			for(v=0;v<bit->bitmap.rows;v++)
-				for(u=0;u<bit->bitmap.width;u++)
-				{
-					int x=u+((pen.x+32)>>6)+ bit->left;
-					int y=v+((pen.y+32)>>6)- bit->top;
-					if(	y>=0 &&
-						x>=0 &&
-						y<surface->get_h() &&
-						x<surface->get_w())
+				error = FT_Glyph_To_Bitmap( &image, ft_render_mode_normal,0/*&pen*/, 1 );
+				if(error) { FT_Done_Glyph( image ); continue; }
+
+				bit = (FT_BitmapGlyph)image;
+
+				for(v=0;v<bit->bitmap.rows;v++)
+					for(u=0;u<bit->bitmap.width;u++)
 					{
-						float myamount=(float)bit->bitmap.buffer[v*bit->bitmap.pitch+u]/255.0f;
-						if(invert)
-							myamount=1.0f-myamount;
-						(*surface)[y][x]=Color::blend(color,(*src_surface)[y][x],myamount*get_amount(),get_blend_method());
+						int x=u+((pen.x+32)>>6)+ bit->left;
+						int y=((pen.y+32)>>6) + (bit->top - v) * ((ph<0) ? -1 : 1);
+						if(	y>=0 &&
+							x>=0 &&
+							y<surface->get_h() &&
+							x<surface->get_w())
+						{
+							float myamount=(float)bit->bitmap.buffer[v*bit->bitmap.pitch+u]/255.0f;
+							if(invert)
+								myamount=1.0f-myamount;
+							(*surface)[y][x]=Color::blend(color,(*src_surface)[y][x],myamount*get_amount(),get_blend_method());
+						}
 					}
-				}
 
-			FT_Done_Glyph( image );
+				FT_Done_Glyph( image );
+			}
+			//iter->clear_and_free();
 		}
-		//iter->clear_and_free();
 	}
-	}
-
 
 	return true;
 }
