@@ -1,8 +1,8 @@
 /* === S Y N F I G ========================================================= */
 /*!	\file bevel.cpp
-**	\brief Template Header
+**	\brief Implementation of the "Bevel" layer
 **
-**	$Id: bevel.cpp 335 2007-03-16 00:39:09Z dooglus $
+**	$Id: bevel.cpp 1191 2007-12-10 01:58:46Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -64,10 +64,10 @@ using namespace std;
 
 SYNFIG_LAYER_INIT(Layer_Bevel);
 SYNFIG_LAYER_SET_NAME(Layer_Bevel,"bevel");
-SYNFIG_LAYER_SET_LOCAL_NAME(Layer_Bevel,_("Bevel"));
-SYNFIG_LAYER_SET_CATEGORY(Layer_Bevel,_("Stylize"));
+SYNFIG_LAYER_SET_LOCAL_NAME(Layer_Bevel,N_("Bevel"));
+SYNFIG_LAYER_SET_CATEGORY(Layer_Bevel,N_("Stylize"));
 SYNFIG_LAYER_SET_VERSION(Layer_Bevel,"0.2");
-SYNFIG_LAYER_SET_CVS_ID(Layer_Bevel,"$Id: bevel.cpp 335 2007-03-16 00:39:09Z dooglus $");
+SYNFIG_LAYER_SET_CVS_ID(Layer_Bevel,"$Id: bevel.cpp 1191 2007-12-10 01:58:46Z dooglus $");
 
 /* -- F U N C T I O N S ----------------------------------------------------- */
 
