@@ -2,7 +2,7 @@
 /*!	\file booleancurve.cpp
 **	\brief Boolean Curve Implementation File
 **
-**	$Id: booleancurve.cpp 335 2007-03-16 00:39:09Z dooglus $
+**	$Id: booleancurve.cpp 631 2007-09-08 15:33:07Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -68,7 +68,7 @@ BooleanCurve::~BooleanCurve()
 
 bool BooleanCurve::set_param(const String & param, const synfig::ValueBase &value)
 {
-	if(param=="regions" && value.same_as(regions))
+	if(param=="regions" && value.same_type_as(regions))
 	{
 		vector<BLinePoint> bv;
 		int size = value.get_list().size();
@@ -108,14 +108,14 @@ Layer::Vocab BooleanCurve::get_param_vocab()const
 	return ret;
 }
 
-Color BooleanCurve::get_color(Context context, const Point &pos)const
+Color BooleanCurve::get_color(Context /*context*/, const Point &/*pos*/)const
 {
 	Color c(Color::alpha());
 
 	return c;
 }
 
-bool BooleanCurve::accelerated_render(Context context,Surface *surface,int quality, const RendDesc &renddesc, ProgressCallback *cb)const
+bool BooleanCurve::accelerated_render(Context /*context*/,Surface */*surface*/,int /*quality*/, const RendDesc &/*renddesc*/, ProgressCallback */*cb*/)const
 {
 	return false;
 }
