@@ -1,8 +1,8 @@
 /* === S Y N F I G ========================================================= */
 /*!	\file clamp.cpp
-**	\brief Template Header
+**	\brief Implementation of the "Clamp" layer
 **
-**	$Id: clamp.cpp 335 2007-03-16 00:39:09Z dooglus $
+**	$Id: clamp.cpp 1191 2007-12-10 01:58:46Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -51,10 +51,10 @@ using namespace synfig;
 
 SYNFIG_LAYER_INIT(Layer_Clamp);
 SYNFIG_LAYER_SET_NAME(Layer_Clamp,"clamp");
-SYNFIG_LAYER_SET_LOCAL_NAME(Layer_Clamp,_("Clamp"));
-SYNFIG_LAYER_SET_CATEGORY(Layer_Clamp,_("Filters"));
+SYNFIG_LAYER_SET_LOCAL_NAME(Layer_Clamp,N_("Clamp"));
+SYNFIG_LAYER_SET_CATEGORY(Layer_Clamp,N_("Filters"));
 SYNFIG_LAYER_SET_VERSION(Layer_Clamp,"0.2");
-SYNFIG_LAYER_SET_CVS_ID(Layer_Clamp,"$Id: clamp.cpp 335 2007-03-16 00:39:09Z dooglus $");
+SYNFIG_LAYER_SET_CVS_ID(Layer_Clamp,"$Id: clamp.cpp 1191 2007-12-10 01:58:46Z dooglus $");
 
 /* === P R O C E D U R E S ================================================= */
 
