@@ -1,8 +1,8 @@
 /* === S Y N F I G ========================================================= */
 /*!	\file import.cpp
-**	\brief Image Import Layer Implementation
+**	\brief Implementation of the "Import Image" layer
 **
-**	$Id: import.cpp 848 2007-10-06 02:25:36Z dooglus $
+**	$Id: import.cpp 1191 2007-12-10 01:58:46Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -55,10 +55,10 @@ using namespace etl;
 
 SYNFIG_LAYER_INIT(Import);
 SYNFIG_LAYER_SET_NAME(Import,"import");
-SYNFIG_LAYER_SET_LOCAL_NAME(Import,_("Import Image"));
-SYNFIG_LAYER_SET_CATEGORY(Import,_("Other"));
+SYNFIG_LAYER_SET_LOCAL_NAME(Import,N_("Import Image"));
+SYNFIG_LAYER_SET_CATEGORY(Import,N_("Other"));
 SYNFIG_LAYER_SET_VERSION(Import,"0.1");
-SYNFIG_LAYER_SET_CVS_ID(Import,"$Id: import.cpp 848 2007-10-06 02:25:36Z dooglus $");
+SYNFIG_LAYER_SET_CVS_ID(Import,"$Id: import.cpp 1191 2007-12-10 01:58:46Z dooglus $");
 
 /* === P R O C E D U R E S ================================================= */
 
