@@ -1,8 +1,8 @@
 /* === S Y N F I G ========================================================= */
 /*!	\file insideout.cpp
-**	\brief Template Header
+**	\brief Implementation of the "Inside Out" layer
 **
-**	$Id: insideout.cpp 848 2007-10-06 02:25:36Z dooglus $
+**	$Id: insideout.cpp 1191 2007-12-10 01:58:46Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -52,10 +52,10 @@
 
 SYNFIG_LAYER_INIT(InsideOut);
 SYNFIG_LAYER_SET_NAME(InsideOut,"inside_out");
-SYNFIG_LAYER_SET_LOCAL_NAME(InsideOut,_("Inside Out"));
-SYNFIG_LAYER_SET_CATEGORY(InsideOut,_("Distortions"));
+SYNFIG_LAYER_SET_LOCAL_NAME(InsideOut,N_("Inside Out"));
+SYNFIG_LAYER_SET_CATEGORY(InsideOut,N_("Distortions"));
 SYNFIG_LAYER_SET_VERSION(InsideOut,"0.1");
-SYNFIG_LAYER_SET_CVS_ID(InsideOut,"$Id: insideout.cpp 848 2007-10-06 02:25:36Z dooglus $");
+SYNFIG_LAYER_SET_CVS_ID(InsideOut,"$Id: insideout.cpp 1191 2007-12-10 01:58:46Z dooglus $");
 
 /* === P R O C E D U R E S ================================================= */
 
