@@ -1,11 +1,12 @@
 /* === S Y N F I G ========================================================= */
 /*!	\file rotate.cpp
-**	\brief Template Header
+**	\brief Implementation of the "Rotate" layer
 **
-**	$Id: rotate.cpp 578 2007-09-03 19:13:34Z dooglus $
+**	$Id: rotate.cpp 1643 2008-02-09 19:12:18Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -51,10 +52,10 @@
 
 SYNFIG_LAYER_INIT(Rotate);
 SYNFIG_LAYER_SET_NAME(Rotate,"rotate");
-SYNFIG_LAYER_SET_LOCAL_NAME(Rotate,_("Rotate"));
-SYNFIG_LAYER_SET_CATEGORY(Rotate,_("Transform"));
+SYNFIG_LAYER_SET_LOCAL_NAME(Rotate,N_("Rotate"));
+SYNFIG_LAYER_SET_CATEGORY(Rotate,N_("Transform"));
 SYNFIG_LAYER_SET_VERSION(Rotate,"0.1");
-SYNFIG_LAYER_SET_CVS_ID(Rotate,"$Id: rotate.cpp 578 2007-09-03 19:13:34Z dooglus $");
+SYNFIG_LAYER_SET_CVS_ID(Rotate,"$Id: rotate.cpp 1643 2008-02-09 19:12:18Z dooglus $");
 
 /* === P R O C E D U R E S ================================================= */
 
@@ -256,7 +257,7 @@ Rotate::accelerated_render(Context context,Surface *surface,int quality, const R
 				tmp=Point(cos_val*(point[0]-origin[0])+sin_val*(point[1]-origin[1]),-sin_val*(point[0]-origin[0])+cos_val*(point[1]-origin[1])) +origin;
 				(*surface)[y][x]=source.cubic_sample((tmp[0]-tl[0])*pw,(tmp[1]-tl[1])*ph);
 			}
-			if(y&31==0 && cb)
+			if((y&31)==0 && cb)
 			{
 				if(!stagetwo.amount_complete(y,surface->get_h()))
 					return false;
@@ -276,7 +277,7 @@ Rotate::accelerated_render(Context context,Surface *surface,int quality, const R
 				tmp=Point(cos_val*(point[0]-origin[0])+sin_val*(point[1]-origin[1]),-sin_val*(point[0]-origin[0])+cos_val*(point[1]-origin[1])) +origin;
 				(*surface)[y][x]=source.linear_sample((tmp[0]-tl[0])*pw,(tmp[1]-tl[1])*ph);
 			}
-			if(y&31==0 && cb)
+			if((y&31)==0 && cb)
 			{
 				if(!stagetwo.amount_complete(y,surface->get_h()))
 					return false;
@@ -306,7 +307,7 @@ Rotate::accelerated_render(Context context,Surface *surface,int quality, const R
 				//pen.set_value(source[v][u]);
 				(*surface)[y][x]=source[v][u];
 			}
-			if(y&31==0 && cb)
+			if((y&31)==0 && cb)
 			{
 				if(!stagetwo.amount_complete(y,surface->get_h()))
 					return false;
