@@ -1,11 +1,12 @@
 /* === S Y N F I G ========================================================= */
 /*!	\file shade.cpp
-**	\brief Template Header
+**	\brief Implementation of the "Shade" layer
 **
-**	$Id: shade.cpp 859 2007-10-07 22:45:42Z dooglus $
+**	$Id: shade.cpp 1643 2008-02-09 19:12:18Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -62,10 +63,10 @@ using namespace std;
 
 SYNFIG_LAYER_INIT(Layer_Shade);
 SYNFIG_LAYER_SET_NAME(Layer_Shade,"shade");
-SYNFIG_LAYER_SET_LOCAL_NAME(Layer_Shade,_("Shade"));
-SYNFIG_LAYER_SET_CATEGORY(Layer_Shade,_("Stylize"));
+SYNFIG_LAYER_SET_LOCAL_NAME(Layer_Shade,N_("Shade"));
+SYNFIG_LAYER_SET_CATEGORY(Layer_Shade,N_("Stylize"));
 SYNFIG_LAYER_SET_VERSION(Layer_Shade,"0.2");
-SYNFIG_LAYER_SET_CVS_ID(Layer_Shade,"$Id: shade.cpp 859 2007-10-07 22:45:42Z dooglus $");
+SYNFIG_LAYER_SET_CVS_ID(Layer_Shade,"$Id: shade.cpp 1643 2008-02-09 19:12:18Z dooglus $");
 
 /* -- F U N C T I O N S ----------------------------------------------------- */
 
@@ -90,7 +91,9 @@ Layer_Shade::set_param(const String &param, const ValueBase &value)
 {
 	IMPORT_PLUS(size,clamp(size));
 	IMPORT(type);
-	IMPORT(color);
+	IMPORT_PLUS(color, { if (color.get_a() == 0) { if (converted_blend_) {
+					set_blend_method(Color::BLEND_ALPHA_OVER);
+					color.set_a(1); } else transparent_color_ = true; } });
 	IMPORT(offset);
 	IMPORT(invert);
 
@@ -161,14 +164,12 @@ Layer_Shade::accelerated_render(Context context,Surface *surface,int quality, co
 		(offset_v>0?offset_v:0)+h
 	);
 
-	/*
-	if(quality >=10)
+	if(quality >= 10)
 	{
 		halfsizex=1;
 		halfsizey=1;
-	}else
-	*/
-	if(quality == 9)
+	}
+	else if (quality == 9)
 	{
 		halfsizex/=4;
 		halfsizey/=4;
