@@ -1,11 +1,12 @@
 /* === S Y N F I G ========================================================= */
 /*!	\file shade.h
-**	\brief Template Header
+**	\brief Header file for implementation of the "Shade" layer
 **
-**	$Id: shade.h 335 2007-03-16 00:39:09Z dooglus $
+**	$Id: shade.h 1643 2008-02-09 19:12:18Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -57,9 +58,9 @@ public:
 
 	virtual bool accelerated_render(Context context,Surface *surface,int quality, const RendDesc &renddesc, ProgressCallback *cb)const;
 	virtual Rect get_full_bounding_rect(Context context)const;
-
 	virtual Vocab get_param_vocab()const;
-}; // END of class Blur
+	virtual bool reads_context()const { return true; }
+}; // END of class Layer_Shade
 
 /* -- E X T E R N S --------------------------------------------------------- */
 
