@@ -1,11 +1,12 @@
 /* === S Y N F I G ========================================================= */
 /*!	\file sphere_distort.h
-**	\brief Sphere Distort Header
+**	\brief Header file for implementation of the "Spherize" layer
 **
-**	$Id: sphere_distort.h 335 2007-03-16 00:39:09Z dooglus $
+**	$Id: sphere_distort.h 1643 2008-02-09 19:12:18Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -40,7 +41,7 @@ namespace synfig
 {
 class Spherize_Trans;
 
-class Layer_SphereDistort : public Layer_Composite
+class Layer_SphereDistort : public Layer
 {
 	SYNFIG_LAYER_MODULE_EXT
 	friend class Spherize_Trans;
