@@ -1,8 +1,8 @@
 /* === S Y N F I G ========================================================= */
 /*!	\file supersample.cpp
-**	\brief Template Header
+**	\brief Implementation of the "Super Sample" layer
 **
-**	$Id: supersample.cpp 373 2007-03-23 16:02:09Z dooglus $
+**	$Id: supersample.cpp 1479 2008-01-25 14:26:17Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -52,10 +52,10 @@
 
 SYNFIG_LAYER_INIT(SuperSample);
 SYNFIG_LAYER_SET_NAME(SuperSample,"super_sample");
-SYNFIG_LAYER_SET_LOCAL_NAME(SuperSample,_("Super Sample"));
-SYNFIG_LAYER_SET_CATEGORY(SuperSample,_("Other"));
+SYNFIG_LAYER_SET_LOCAL_NAME(SuperSample,N_("Super Sample"));
+SYNFIG_LAYER_SET_CATEGORY(SuperSample,N_("Other"));
 SYNFIG_LAYER_SET_VERSION(SuperSample,"0.1");
-SYNFIG_LAYER_SET_CVS_ID(SuperSample,"$Id: supersample.cpp 373 2007-03-23 16:02:09Z dooglus $");
+SYNFIG_LAYER_SET_CVS_ID(SuperSample,"$Id: supersample.cpp 1479 2008-01-25 14:26:17Z dooglus $");
 
 /* === P R O C E D U R E S ================================================= */
 
@@ -170,7 +170,7 @@ SuperSample::accelerated_render(Context context,Surface *surface,int quality, co
 				else
 					pen.put_value(Color::alpha());
 			}
-			if(y&31==0 && cb)
+			if((y&31)==0 && cb)
 			{
 				if(!stagetwo.amount_complete(y,surface->get_h()))
 					return false;
@@ -193,7 +193,7 @@ SuperSample::accelerated_render(Context context,Surface *surface,int quality, co
 				temp_pen.dec_y(v);
 				pen.put_value(pool*multiplier);
 			}
-			if(y&31==0 && cb)
+			if((y&31)==0 && cb)
 			{
 				if(!stagetwo.amount_complete(y,surface->get_h()))
 					return false;
