@@ -1,11 +1,12 @@
 /* === S Y N F I G ========================================================= */
 /*!	\file timeloop.h
-**	\brief Template Header
+**	\brief Header file for implementation of the "Time Loop" layer
 **
-**	$Id: timeloop.h 335 2007-03-16 00:39:09Z dooglus $
+**	$Id: timeloop.h 1813 2008-02-24 20:50:31Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -43,8 +44,15 @@ class Layer_TimeLoop : public synfig::Layer
 	SYNFIG_LAYER_MODULE_EXT
 
 private:
+	synfig::Time	link_time;
+	synfig::Time	local_time;
+	synfig::Time	duration;
+
 	synfig::Time	start_time;
 	synfig::Time	end_time;
+	bool			old_version;
+	bool			only_for_positive_duration;
+	bool			symmetrical; // the 0.1 version of this layer behaved differently before 'start_time' was reached
 
 protected:
 	Layer_TimeLoop();
@@ -57,6 +65,8 @@ public:
 	virtual synfig::ValueBase get_param(const synfig::String & param)const;
 
 	virtual Vocab get_param_vocab()const;
+	virtual bool set_version(const synfig::String &ver);
+	virtual void reset_version();
 	virtual synfig::Color get_color(synfig::Context context, const synfig::Point &pos)const;
 
 	virtual void set_time(synfig::Context context, synfig::Time time)const;
