@@ -1,8 +1,8 @@
 /* === S Y N F I G ========================================================= */
 /*!	\file translate.cpp
-**	\brief Template File
+**	\brief Implementation of the "Translate" layer
 **
-**	$Id: translate.cpp 373 2007-03-23 16:02:09Z dooglus $
+**	$Id: translate.cpp 1191 2007-12-10 01:58:46Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -51,10 +51,10 @@
 
 SYNFIG_LAYER_INIT(Translate);
 SYNFIG_LAYER_SET_NAME(Translate,"translate");
-SYNFIG_LAYER_SET_LOCAL_NAME(Translate,_("Translate"));
-SYNFIG_LAYER_SET_CATEGORY(Translate,_("Transform"));
+SYNFIG_LAYER_SET_LOCAL_NAME(Translate,N_("Translate"));
+SYNFIG_LAYER_SET_CATEGORY(Translate,N_("Transform"));
 SYNFIG_LAYER_SET_VERSION(Translate,"0.1");
-SYNFIG_LAYER_SET_CVS_ID(Translate,"$Id: translate.cpp 373 2007-03-23 16:02:09Z dooglus $");
+SYNFIG_LAYER_SET_CVS_ID(Translate,"$Id: translate.cpp 1191 2007-12-10 01:58:46Z dooglus $");
 
 /* === P R O C E D U R E S ================================================= */
 
