@@ -1,8 +1,8 @@
 /* === S Y N F I G ========================================================= */
 /*!	\file twirl.cpp
-**	\brief Template Header
+**	\brief Implementation of the "Twirl" layer
 **
-**	$Id: twirl.cpp 335 2007-03-16 00:39:09Z dooglus $
+**	$Id: twirl.cpp 1191 2007-12-10 01:58:46Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -52,10 +52,10 @@ using namespace synfig;
 
 SYNFIG_LAYER_INIT(Twirl);
 SYNFIG_LAYER_SET_NAME(Twirl,"twirl");
-SYNFIG_LAYER_SET_LOCAL_NAME(Twirl,_("Twirl"));
-SYNFIG_LAYER_SET_CATEGORY(Twirl,_("Distortions"));
+SYNFIG_LAYER_SET_LOCAL_NAME(Twirl,N_("Twirl"));
+SYNFIG_LAYER_SET_CATEGORY(Twirl,N_("Distortions"));
 SYNFIG_LAYER_SET_VERSION(Twirl,"0.1");
-SYNFIG_LAYER_SET_CVS_ID(Twirl,"$Id: twirl.cpp 335 2007-03-16 00:39:09Z dooglus $");
+SYNFIG_LAYER_SET_CVS_ID(Twirl,"$Id: twirl.cpp 1191 2007-12-10 01:58:46Z dooglus $");
 
 /* === P R O C E D U R E S ================================================= */
 
