@@ -1,11 +1,12 @@
 /* === S Y N F I G ========================================================= */
 /*!	\file twirl.h
-**	\brief Template Header
+**	\brief Header file for implementation of the "Twirl" layer
 **
-**	$Id: twirl.h 335 2007-03-16 00:39:09Z dooglus $
+**	$Id: twirl.h 1643 2008-02-09 19:12:18Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -75,6 +76,7 @@ public:
 
 	virtual Vocab get_param_vocab()const;
 	virtual etl::handle<synfig::Transform> get_transform()const;
+	virtual bool reads_context()const { return true; }
 }; // END of class Twirl
 
 /* === E N D =============================================================== */
