@@ -2,10 +2,11 @@
 /*!	\file trgt_dv.cpp
 **	\brief ppm Target Module
 **
-**	$Id: trgt_dv.cpp 631 2007-09-08 15:33:07Z dooglus $
+**	$Id: trgt_dv.cpp 1642 2008-02-09 18:25:35Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -36,6 +37,20 @@
 #include <ETL/stringf>
 #include "trgt_dv.h"
 #include <stdio.h>
+#include <sys/types.h>
+#if HAVE_SYS_WAIT_H
+ #include <sys/wait.h>
+#endif
+#if HAVE_IO_H
+ #include <io.h>
+#endif
+#if HAVE_PROCESS_H
+ #include <process.h>
+#endif
+#if HAVE_FCNTL_H
+ #include <fcntl.h>
+#endif
+#include <unistd.h>
 #include <algorithm>
 #include <functional>
 #include <ETL/clock>
@@ -48,19 +63,26 @@ using namespace synfig;
 using namespace std;
 using namespace etl;
 
+#if defined(HAVE_FORK) && defined(HAVE_PIPE) && defined(HAVE_WAITPID)
+ #define UNIX_PIPE_TO_PROCESSES
+#else
+ #define WIN32_PIPE_TO_PROCESSES
+#endif
+
 /* === G L O B A L S ======================================================= */
 
 SYNFIG_TARGET_INIT(dv_trgt);
 SYNFIG_TARGET_SET_NAME(dv_trgt,"dv");
 SYNFIG_TARGET_SET_EXT(dv_trgt,"dv");
 SYNFIG_TARGET_SET_VERSION(dv_trgt,"0.1");
-SYNFIG_TARGET_SET_CVS_ID(dv_trgt,"$Id: trgt_dv.cpp 631 2007-09-08 15:33:07Z dooglus $");
+SYNFIG_TARGET_SET_CVS_ID(dv_trgt,"$Id: trgt_dv.cpp 1642 2008-02-09 18:25:35Z dooglus $");
 
 /* === M E T H O D S ======================================================= */
 
 
 dv_trgt::dv_trgt(const char *Filename)
 {
+	pid=-1;
 	file=NULL;
 	filename=Filename;
 	buffer=NULL;
@@ -72,8 +94,15 @@ dv_trgt::dv_trgt(const char *Filename)
 
 dv_trgt::~dv_trgt()
 {
-	if(file)
+	if(file){
+#if defined(WIN32_PIPE_TO_PROCESSES)
 		pclose(file);
+#elif defined(UNIX_PIPE_TO_PROCESSES)
+		fclose(file);
+		int status;
+		waitpid(pid,&status,0);
+#endif
+	}
 	file=NULL;
 	delete [] buffer;
 	delete [] color_buffer;
@@ -120,15 +149,17 @@ dv_trgt::init()
 {
 	imagecount=desc.get_frame_start();
 
-	string command;
+#if defined(WIN32_PIPE_TO_PROCESSES)
 
+	string command;
+	
 	if(wide_aspect)
 		command=strprintf("encodedv -w 1 - > \"%s\"\n",filename.c_str());
 	else
 		command=strprintf("encodedv - > \"%s\"\n",filename.c_str());
 
 	// Open the pipe to encodedv
-	file=popen(command.c_str(),"w");
+	file=popen(command.c_str(),POPEN_BINARY_WRITE_TYPE);
 
 	if(!file)
 	{
@@ -136,6 +167,73 @@ dv_trgt::init()
 		return false;
 	}
 
+#elif defined(UNIX_PIPE_TO_PROCESSES)
+
+	int p[2];
+  
+	if (pipe(p)) {
+		synfig::error(_("Unable to open pipe to encodedv"));
+		return false;
+	};
+  
+	pid_t pid = fork();
+  
+	if (pid == -1) {
+		synfig::error(_("Unable to open pipe to encodedv"));
+		return false;
+	}
+  
+	if (pid == 0){
+		// Child process
+		// Close pipeout, not needed
+		close(p[1]);
+		// Dup pipeout to stdin
+		if( dup2( p[0], STDIN_FILENO ) == -1 ){
+			synfig::error(_("Unable to open pipe to encodedv"));
+			return false;
+		}
+		// Close the unneeded pipeout
+		close(p[0]);
+		// Open filename to stdout
+		FILE* outfile = fopen(filename.c_str(),"wb");
+		if( outfile == NULL ){
+			synfig::error(_("Unable to open pipe to encodedv"));
+			return false;
+		}
+		int outfilefd = fileno(outfile);
+		if( outfilefd == -1 ){
+			synfig::error(_("Unable to open pipe to encodedv"));
+			return false;
+		}
+		if( dup2( outfilefd, STDOUT_FILENO ) == -1 ){
+			synfig::error(_("Unable to open pipe to encodedv"));
+			return false;
+		}
+		
+		if(wide_aspect)
+			execlp("encodedv", "encodedv", "-w", "1", "-", (const char *)NULL);
+		else
+			execlp("encodedv", "encodedv", "-", (const char *)NULL);
+		// We should never reach here unless the exec failed
+		synfig::error(_("Unable to open pipe to encodedv"));
+		return false;
+	} else {
+		// Parent process
+		// Close pipein, not needed
+		close(p[0]);
+		// Save pipeout to file handle, will write to it later
+		file = fdopen(p[1], "wb");
+		if (file == NULL) {
+			synfig::error(_("Unable to open pipe to encodedv"));
+			return false;
+		}
+	}
+
+#else
+	#error There are no known APIs for creating child processes
+#endif
+
+
 	// Sleep for a moment to let the pipe catch up
 	etl::clock().sleep(0.25f);
 
