@@ -2,7 +2,7 @@
 /*!	\file trgt_dv.h
 **	\brief Template Header
 **
-**	$Id: trgt_dv.h 335 2007-03-16 00:39:09Z dooglus $
+**	$Id: trgt_dv.h 1184 2007-12-07 03:36:30Z pabs $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -31,6 +31,7 @@
 
 #include <synfig/target_scanline.h>
 #include <synfig/string.h>
+#include <sys/types.h>
 #include <cstdio>
 
 /* === M A C R O S ========================================================= */
@@ -44,6 +45,7 @@ class dv_trgt : public synfig::Target_Scanline
 {
 	SYNFIG_TARGET_MODULE_EXT
 private:
+	pid_t pid;
 	int imagecount;
 	bool wide_aspect;
 	FILE *file;
