@@ -2,10 +2,11 @@
 /*!	\file mptr_ffmpeg.cpp
 **	\brief ppm Target Module
 **
-**	$Id: mptr_ffmpeg.cpp 373 2007-03-23 16:02:09Z dooglus $
+**	$Id: mptr_ffmpeg.cpp 1642 2008-02-09 18:25:35Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -34,6 +35,20 @@
 #include <ETL/stringf>
 #include "mptr_ffmpeg.h"
 #include <stdio.h>
+#include <sys/types.h>
+#if HAVE_SYS_WAIT_H
+ #include <sys/wait.h>
+#endif
+#if HAVE_IO_H
+ #include <io.h>
+#endif
+#if HAVE_PROCESS_H
+ #include <process.h>
+#endif
+#if HAVE_FCNTL_H
+ #include <fcntl.h>
+#endif
+#include <unistd.h>
 #include <iostream>
 #include <algorithm>
 #include <functional>
@@ -46,13 +61,19 @@ using namespace synfig;
 using namespace std;
 using namespace etl;
 
+#if defined(HAVE_FORK) && defined(HAVE_PIPE) && defined(HAVE_WAITPID)
+ #define UNIX_PIPE_TO_PROCESSES
+#else
+ #define WIN32_PIPE_TO_PROCESSES
+#endif
+
 /* === G L O B A L S ======================================================= */
 
 SYNFIG_IMPORTER_INIT(ffmpeg_mptr);
 SYNFIG_IMPORTER_SET_NAME(ffmpeg_mptr,"ffmpeg");
 SYNFIG_IMPORTER_SET_EXT(ffmpeg_mptr,"avi");
 SYNFIG_IMPORTER_SET_VERSION(ffmpeg_mptr,"0.1");
-SYNFIG_IMPORTER_SET_CVS_ID(ffmpeg_mptr,"$Id: mptr_ffmpeg.cpp 373 2007-03-23 16:02:09Z dooglus $");
+SYNFIG_IMPORTER_SET_CVS_ID(ffmpeg_mptr,"$Id: mptr_ffmpeg.cpp 1642 2008-02-09 18:25:35Z dooglus $");
 
 /* === M E T H O D S ======================================================= */
 
@@ -63,14 +84,65 @@ ffmpeg_mptr::seek_to(int frame)
 	{
 		if(file)
 		{
+#if defined(WIN32_PIPE_TO_PROCESSES)
 			pclose(file);
+#elif defined(UNIX_PIPE_TO_PROCESSES)
+			fclose(file);
+			int status;
+			waitpid(pid,&status,0);
+#endif
 		}
 
+#if defined(WIN32_PIPE_TO_PROCESSES)
+
 		string command;
-
+		
 		command=strprintf("ffmpeg -i \"%s\" -an -f image2pipe -vcodec ppm -\n",filename.c_str());
+		
+		file=popen(command.c_str(),POPEN_BINARY_READ_TYPE);
 
-		file=popen(command.c_str(),"r");
+#elif defined(UNIX_PIPE_TO_PROCESSES)
+
+		int p[2];
+	  
+		if (pipe(p)) {
+			cerr<<"Unable to open pipe to ffmpeg"<<endl;
+			return false;
+		};
+	  
+		pid = fork();
+	  
+		if (pid == -1) {
+			cerr<<"Unable to open pipe to ffmpeg"<<endl;
+			return false;
+		}
+	  
+		if (pid == 0){
+			// Child process
+			// Close pipein, not needed
+			close(p[0]);
+			// Dup pipein to stdout
+			if( dup2( p[1], STDOUT_FILENO ) == -1 ){
+				cerr<<"Unable to open pipe to ffmpeg"<<endl;
+				return false;
+			}
+			// Close the unneeded pipein
+			close(p[1]);
+			execlp("ffmpeg", "ffmpeg", "-i", filename.c_str(), "-an", "-f", "image2pipe", "-vcodec", "ppm", "-", (const char *)NULL);
+			// We should never reach here unless the exec failed
+			cerr<<"Unable to open pipe to ffmpeg"<<endl;
+			return false;
+		} else {
+			// Parent process
+			// Close pipeout, not needed
+			close(p[1]);
+			// Save pipein to file handle, will read from it later
+			file = fdopen(p[0], "rb");
+		}
+
+#else
+	#error There are no known APIs for creating child processes
+#endif
 
 		if(!file)
 		{
@@ -148,6 +220,7 @@ ffmpeg_mptr::grab_frame(void)
 
 ffmpeg_mptr::ffmpeg_mptr(const char *f)
 {
+	pid=-1;
 #ifdef HAVE_TERMIOS_H
 	tcgetattr (0, &oldtty);
 #endif
@@ -160,7 +233,15 @@ ffmpeg_mptr::ffmpeg_mptr(const char *f)
 ffmpeg_mptr::~ffmpeg_mptr()
 {
 	if(file)
+	{
+#if defined(WIN32_PIPE_TO_PROCESSES)
 		pclose(file);
+#elif defined(UNIX_PIPE_TO_PROCESSES)
+		fclose(file);
+		int status;
+		waitpid(pid,&status,0);
+#endif
+	}
 #ifdef HAVE_TERMIOS_H
 	tcsetattr(0,TCSANOW,&oldtty);
 #endif
@@ -174,7 +255,7 @@ ffmpeg_mptr::get_frame(synfig::Surface &surface,Time time, synfig::ProgressCallb
 	{
 		if(!seek_to(i))
 			return false;
-		if(!grab_frame());
+		if(!grab_frame())
 			return false;
 	}
 
