@@ -2,7 +2,7 @@
 /*!	\file mptr_ffmpeg.h
 **	\brief Template Header
 **
-**	$Id: mptr_ffmpeg.h 335 2007-03-16 00:39:09Z dooglus $
+**	$Id: mptr_ffmpeg.h 1186 2007-12-07 04:29:57Z pabs $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -30,6 +30,7 @@
 /* === H E A D E R S ======================================================= */
 
 #include <synfig/importer.h>
+#include <sys/types.h>
 #include <stdio.h>
 #include "string.h"
 #ifdef HAVE_TERMIOS_H
@@ -49,6 +50,7 @@ class ffmpeg_mptr : public synfig::Importer
 	SYNFIG_IMPORTER_MODULE_EXT
 public:
 private:
+	pid_t pid;
 	synfig::String filename;
 	FILE *file;
 	int cur_frame;
