@@ -2,10 +2,11 @@
 /*!	\file trgt_ffmpeg.cpp
 **	\brief ppm Target Module
 **
-**	$Id: trgt_ffmpeg.cpp 631 2007-09-08 15:33:07Z dooglus $
+**	$Id: trgt_ffmpeg.cpp 1642 2008-02-09 18:25:35Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -36,6 +37,20 @@
 #include <ETL/stringf>
 #include "trgt_ffmpeg.h"
 #include <stdio.h>
+#include <sys/types.h>
+#if HAVE_SYS_WAIT_H
+ #include <sys/wait.h>
+#endif
+#if HAVE_IO_H
+ #include <io.h>
+#endif
+#if HAVE_PROCESS_H
+ #include <process.h>
+#endif
+#if HAVE_FCNTL_H
+ #include <fcntl.h>
+#endif
+#include <unistd.h>
 #include <algorithm>
 #include <functional>
 #include <ETL/clock>
@@ -48,18 +63,25 @@ using namespace synfig;
 using namespace std;
 using namespace etl;
 
+#if defined(HAVE_FORK) && defined(HAVE_PIPE) && defined(HAVE_WAITPID)
+ #define UNIX_PIPE_TO_PROCESSES
+#else
+ #define WIN32_PIPE_TO_PROCESSES
+#endif
+
 /* === G L O B A L S ======================================================= */
 
 SYNFIG_TARGET_INIT(ffmpeg_trgt);
 SYNFIG_TARGET_SET_NAME(ffmpeg_trgt,"ffmpeg");
 SYNFIG_TARGET_SET_EXT(ffmpeg_trgt,"mpg");
 SYNFIG_TARGET_SET_VERSION(ffmpeg_trgt,"0.1");
-SYNFIG_TARGET_SET_CVS_ID(ffmpeg_trgt,"$Id: trgt_ffmpeg.cpp 631 2007-09-08 15:33:07Z dooglus $");
+SYNFIG_TARGET_SET_CVS_ID(ffmpeg_trgt,"$Id: trgt_ffmpeg.cpp 1642 2008-02-09 18:25:35Z dooglus $");
 
 /* === M E T H O D S ======================================================= */
 
 ffmpeg_trgt::ffmpeg_trgt(const char *Filename)
 {
+	pid=-1;
 	file=NULL;
 	filename=Filename;
 	multi_image=false;
@@ -74,7 +96,13 @@ ffmpeg_trgt::~ffmpeg_trgt()
 	{
 		etl::yield();
 		sleep(1);
+#if defined(WIN32_PIPE_TO_PROCESSES)
 		pclose(file);
+#elif defined(UNIX_PIPE_TO_PROCESSES)
+		fclose(file);
+		int status;
+		waitpid(pid,&status,0);
+#endif
 	}
 	file=NULL;
 	delete [] buffer;
@@ -124,11 +152,63 @@ ffmpeg_trgt::init()
 	imagecount=desc.get_frame_start();
 	if(desc.get_frame_end()-desc.get_frame_start()>0)
 		multi_image=true;
+
+#if defined(WIN32_PIPE_TO_PROCESSES)
+
 	string command;
 
-	command=strprintf("ffmpeg -f image2pipe -vcodec ppm -an -r %f -i pipe: -loop -hq -title \"%s\" -vcodec mpeg1video -y \"%s\"\n",desc.get_frame_rate(),get_canvas()->get_name().c_str(),filename.c_str());
+	if( filename.c_str()[0] == '-' )
+			command=strprintf("ffmpeg -f image2pipe -vcodec ppm -an -r %f -i pipe: -loop -hq -title \"%s\" -vcodec mpeg1video -y -- \"%s\"\n",desc.get_frame_rate(),get_canvas()->get_name().c_str(),filename.c_str());
+	else
+			command=strprintf("ffmpeg -f image2pipe -vcodec ppm -an -r %f -i pipe: -loop -hq -title \"%s\" -vcodec mpeg1video -y \"%s\"\n",desc.get_frame_rate(),get_canvas()->get_name().c_str(),filename.c_str());
+				
+	file=popen(command.c_str(),POPEN_BINARY_WRITE_TYPE);
 
-	file=popen(command.c_str(),"w");
+#elif defined(UNIX_PIPE_TO_PROCESSES)
+
+	int p[2];
+  
+	if (pipe(p)) {
+		synfig::error(_("Unable to open pipe to ffmpeg"));
+		return false;
+	};
+  
+	pid = fork();
+  
+	if (pid == -1) {
+		synfig::error(_("Unable to open pipe to ffmpeg"));
+		return false;
+	}
+  
+	if (pid == 0){
+		// Child process
+		// Close pipeout, not needed
+		close(p[1]);
+		// Dup pipeout to stdin
+		if( dup2( p[0], STDIN_FILENO ) == -1 ){
+			synfig::error(_("Unable to open pipe to ffmpeg"));
+			return false;
+		}
+		// Close the unneeded pipeout
+		close(p[0]);
+		if( filename.c_str()[0] == '-' )
+			execlp("ffmpeg", "ffmpeg", "-f", "image2pipe", "-vcodec", "ppm", "-an", "-r", strprintf("%f", desc.get_frame_rate()).c_str(), "-i", "pipe:", "-loop", "-hq", "-title", get_canvas()->get_name().c_str(), "-vcodec", "mpeg1video", "-y", "--", filename.c_str(), (const char *)NULL);
+		else
+			execlp("ffmpeg", "ffmpeg", "-f", "image2pipe", "-vcodec", "ppm", "-an", "-r", strprintf("%f", desc.get_frame_rate()).c_str(), "-i", "pipe:", "-loop", "-hq", "-title", get_canvas()->get_name().c_str(), "-vcodec", "mpeg1video", "-y", filename.c_str(), (const char *)NULL);
+		// We should never reach here unless the exec failed
+		synfig::error(_("Unable to open pipe to ffmpeg"));
+		return false;
+	} else {
+		// Parent process
+		// Close pipein, not needed
+		close(p[0]);
+		// Save pipeout to file handle, will write to it later
+		file = fdopen(p[1], "wb");
+	}
+
+#else
+	#error There are no known APIs for creating child processes
+#endif
 
 	// etl::yield();
 
