@@ -1,11 +1,12 @@
 /* === S Y N F I G ========================================================= */
 /*!	\file mod_filter/blur.cpp
-**	\brief Template Header
+**	\brief Implementation of the "Blur" layer
 **
-**	$Id: blur.cpp 335 2007-03-16 00:39:09Z dooglus $
+**	$Id: blur.cpp 1643 2008-02-09 19:12:18Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -63,10 +64,10 @@ using namespace std;
 
 SYNFIG_LAYER_INIT(Blur_Layer);
 SYNFIG_LAYER_SET_NAME(Blur_Layer,"blur");
-SYNFIG_LAYER_SET_LOCAL_NAME(Blur_Layer,_("Blur"));
-SYNFIG_LAYER_SET_CATEGORY(Blur_Layer,_("Blurs"));
+SYNFIG_LAYER_SET_LOCAL_NAME(Blur_Layer,N_("Blur"));
+SYNFIG_LAYER_SET_CATEGORY(Blur_Layer,N_("Blurs"));
 SYNFIG_LAYER_SET_VERSION(Blur_Layer,"0.2");
-SYNFIG_LAYER_SET_CVS_ID(Blur_Layer,"$Id: blur.cpp 335 2007-03-16 00:39:09Z dooglus $");
+SYNFIG_LAYER_SET_CVS_ID(Blur_Layer,"$Id: blur.cpp 1643 2008-02-09 19:12:18Z dooglus $");
 
 /* -- F U N C T I O N S ----------------------------------------------------- */
 
@@ -121,6 +122,10 @@ Blur_Layer::get_color(Context context, const Point &pos)const
 bool
 Blur_Layer::accelerated_render(Context context,Surface *surface,int quality, const RendDesc &renddesc, ProgressCallback *cb)const
 {
+	// don't do anything at quality 10
+	if (quality == 10)
+		return context.accelerated_render(surface,quality,renddesc,cb);
+
 	// int x,y;
 	SuperCallback stageone(cb,0,5000,10000);
 	SuperCallback stagetwo(cb,5000,10000,10000);
