@@ -1,8 +1,8 @@
 /* === S Y N F I G ========================================================= */
 /*!	\file colorcorrect.cpp
-**	\brief Template Header
+**	\brief Implementation of the "Color Correct" layer
 **
-**	$Id: colorcorrect.cpp 335 2007-03-16 00:39:09Z dooglus $
+**	$Id: colorcorrect.cpp 1191 2007-12-10 01:58:46Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -51,10 +51,10 @@ using namespace synfig;
 
 SYNFIG_LAYER_INIT(Layer_ColorCorrect);
 SYNFIG_LAYER_SET_NAME(Layer_ColorCorrect,"colorcorrect");
-SYNFIG_LAYER_SET_LOCAL_NAME(Layer_ColorCorrect,_("Color Correct"));
-SYNFIG_LAYER_SET_CATEGORY(Layer_ColorCorrect,_("Filters"));
+SYNFIG_LAYER_SET_LOCAL_NAME(Layer_ColorCorrect,N_("Color Correct"));
+SYNFIG_LAYER_SET_CATEGORY(Layer_ColorCorrect,N_("Filters"));
 SYNFIG_LAYER_SET_VERSION(Layer_ColorCorrect,"0.1");
-SYNFIG_LAYER_SET_CVS_ID(Layer_ColorCorrect,"$Id: colorcorrect.cpp 335 2007-03-16 00:39:09Z dooglus $");
+SYNFIG_LAYER_SET_CVS_ID(Layer_ColorCorrect,"$Id: colorcorrect.cpp 1191 2007-12-10 01:58:46Z dooglus $");
 
 /* === P R O C E D U R E S ================================================= */
 
