@@ -1,11 +1,12 @@
 /* === S Y N F I G ========================================================= */
 /*!	\file lumakey.h
-**	\brief Checkerboard Layer
+**	\brief Header file for implementation of the "Luma Key" layer
 **
-**	$Id: lumakey.h 335 2007-03-16 00:39:09Z dooglus $
+**	$Id: lumakey.h 1643 2008-02-09 19:12:18Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -59,7 +60,8 @@ public:
 	virtual synfig::Rect get_bounding_rect(synfig::Context context)const;
 
 	virtual bool accelerated_render(synfig::Context context,synfig::Surface *surface,int quality, const synfig::RendDesc &renddesc, synfig::ProgressCallback *cb)const;
-};
+	virtual bool reads_context()const { return true; }
+}; // END of class LumaKey
 
 /* === E N D =============================================================== */
 
