@@ -1,11 +1,12 @@
 /* === S Y N F I G ========================================================= */
 /*!	\file radialblur.h
-**	\brief Template Header
+**	\brief Header file for implementation of the "Radial Blur" layer
 **
-**	$Id: radialblur.h 335 2007-03-16 00:39:09Z dooglus $
+**	$Id: radialblur.h 1643 2008-02-09 19:12:18Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -61,7 +62,8 @@ public:
 	virtual Color get_color(Context context, const Point &pos)const;
 	virtual bool accelerated_render(Context context,Surface *surface,int quality, const RendDesc &renddesc, ProgressCallback *cb)const;
 	virtual Vocab get_param_vocab()const;
-};
+	virtual bool reads_context()const { return true; }
+}; // END of class RadialBlur
 
 /* === E N D =============================================================== */
 
