@@ -1,12 +1,12 @@
 /* === S Y N F I G ========================================================= */
 /*!	\file checkerboard.cpp
-**	\brief Template Header
+**	\brief Implementation of the "Checkerboard" layer
 **
-**	$Id: checkerboard.cpp 848 2007-10-06 02:25:36Z dooglus $
+**	$Id: checkerboard.cpp 1643 2008-02-09 19:12:18Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
-**	Copyright (c) 2007 Chris Moore
+**	Copyright (c) 2007, 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -54,10 +54,10 @@ using namespace etl;
 
 SYNFIG_LAYER_INIT(CheckerBoard);
 SYNFIG_LAYER_SET_NAME(CheckerBoard,"checker_board");
-SYNFIG_LAYER_SET_LOCAL_NAME(CheckerBoard,_("Checkerboard"));
-SYNFIG_LAYER_SET_CATEGORY(CheckerBoard,_("Geometry"));
+SYNFIG_LAYER_SET_LOCAL_NAME(CheckerBoard,N_("Checkerboard"));
+SYNFIG_LAYER_SET_CATEGORY(CheckerBoard,N_("Geometry"));
 SYNFIG_LAYER_SET_VERSION(CheckerBoard,"0.1");
-SYNFIG_LAYER_SET_CVS_ID(CheckerBoard,"$Id: checkerboard.cpp 848 2007-10-06 02:25:36Z dooglus $");
+SYNFIG_LAYER_SET_CVS_ID(CheckerBoard,"$Id: checkerboard.cpp 1643 2008-02-09 19:12:18Z dooglus $");
 
 /* === P R O C E D U R E S ================================================= */
 
@@ -87,7 +87,9 @@ CheckerBoard::point_test(const synfig::Point& getpos)const
 bool
 CheckerBoard::set_param(const String &param, const ValueBase &value)
 {
-	IMPORT(color);
+	IMPORT_PLUS(color, { if (color.get_a() == 0) { if (converted_blend_) {
+					set_blend_method(Color::BLEND_ALPHA_OVER);
+					color.set_a(1); } else transparent_color_ = true; } });
 	IMPORT(pos);
 	IMPORT(pos[0]);
 	IMPORT(pos[1]);
