@@ -1,8 +1,8 @@
 /* === S Y N F I G ========================================================= */
 /*!	\file outline.cpp
-**	\brief Template
+**	\brief Implementation of the "Outline" layer
 **
-**	$Id: outline.cpp 848 2007-10-06 02:25:36Z dooglus $
+**	$Id: outline.cpp 1697 2008-02-15 13:55:34Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -67,10 +67,10 @@ using namespace etl;
 
 SYNFIG_LAYER_INIT(Outline);
 SYNFIG_LAYER_SET_NAME(Outline,"outline");
-SYNFIG_LAYER_SET_LOCAL_NAME(Outline,_("Outline"));
-SYNFIG_LAYER_SET_CATEGORY(Outline,_("Geometry"));
+SYNFIG_LAYER_SET_LOCAL_NAME(Outline,N_("Outline"));
+SYNFIG_LAYER_SET_CATEGORY(Outline,N_("Geometry"));
 SYNFIG_LAYER_SET_VERSION(Outline,"0.2");
-SYNFIG_LAYER_SET_CVS_ID(Outline,"$Id: outline.cpp 848 2007-10-06 02:25:36Z dooglus $");
+SYNFIG_LAYER_SET_CVS_ID(Outline,"$Id: outline.cpp 1697 2008-02-15 13:55:34Z dooglus $");
 
 /* === P R O C E D U R E S ================================================= */
 
@@ -99,7 +99,7 @@ Point line_intersection(
 
 	float m1,m2;    // the slopes of each line
 
-	// compute slopes, note the cludge for infinity, however, this will
+	// compute slopes, note the kluge for infinity, however, this will
 	// be close enough
 
 	if ((x1-x0)!=0)
@@ -175,7 +175,7 @@ Outline::sync()
 
 	if (!bline.get_list().size())
 	{
-		synfig::warning(string("Outline::sync():")+_("No verticies in outline " + string("\"") + get_description() + string("\"")));
+		synfig::warning(string("Outline::sync():")+N_("No vertices in outline " + string("\"") + get_description() + string("\"")));
 		return;
 	}
 		
@@ -798,7 +798,7 @@ Outline::get_param_vocab()const
 	ret.push_back(ParamDesc("bline")
 		.set_local_name(_("Vertices"))
 		.set_origin("offset")
-		.set_scalar("width")
+		.set_hint("width")
 		.set_description(_("A list of BLine Points"))
 	);
 
