@@ -1,12 +1,12 @@
 /* === S Y N F I G ========================================================= */
 /*!	\file rectangle.cpp
-**	\brief Template Header
+**	\brief Implementation of the "Rectangle" layer
 **
-**	$Id: rectangle.cpp 848 2007-10-06 02:25:36Z dooglus $
+**	$Id: rectangle.cpp 1643 2008-02-09 19:12:18Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002 Robert B. Quattlebaum Jr.
-**	Copyright (c) 2007 Chris Moore
+**	Copyright (c) 2007, 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -55,10 +55,10 @@ using namespace synfig;
 
 SYNFIG_LAYER_INIT(Rectangle);
 SYNFIG_LAYER_SET_NAME(Rectangle,"rectangle");
-SYNFIG_LAYER_SET_LOCAL_NAME(Rectangle,_("Rectangle"));
-SYNFIG_LAYER_SET_CATEGORY(Rectangle,_("Geometry"));
+SYNFIG_LAYER_SET_LOCAL_NAME(Rectangle,N_("Rectangle"));
+SYNFIG_LAYER_SET_CATEGORY(Rectangle,N_("Geometry"));
 SYNFIG_LAYER_SET_VERSION(Rectangle,"0.2");
-SYNFIG_LAYER_SET_CVS_ID(Rectangle,"$Id: rectangle.cpp 848 2007-10-06 02:25:36Z dooglus $");
+SYNFIG_LAYER_SET_CVS_ID(Rectangle,"$Id: rectangle.cpp 1643 2008-02-09 19:12:18Z dooglus $");
 
 /* === P R O C E D U R E S ================================================= */
 
@@ -87,7 +87,9 @@ Rectangle::Rectangle():
 bool
 Rectangle::set_param(const String & param, const ValueBase &value)
 {
-	IMPORT(color);
+	IMPORT_PLUS(color, { if (color.get_a() == 0) { if (converted_blend_) {
+					set_blend_method(Color::BLEND_ALPHA_OVER);
+					color.set_a(1); } else transparent_color_ = true; } });
 	IMPORT(point1);
 	IMPORT(point2);
 	IMPORT(expand);
@@ -422,7 +424,7 @@ Rectangle::accelerated_render(Context context,Surface *surface,int quality, cons
 				surface->blit_to(subimage_pen,left,top,right-left,bottom-top);
 			}
 
-			// fill surface with the rectangle's colour
+			// fill surface with the rectangle's color
 			Surface::alpha_pen surface_pen(surface->begin(),get_amount(),get_blend_method());
 			surface->fill(color,surface_pen,w,h);
 
@@ -490,8 +492,8 @@ Rectangle::accelerated_render(Context context,Surface *surface,int quality, cons
 	right = std::min(w,right);
 */
 
-	// optimisation - if the whole tile is covered by this rectangle,
-	// and the rectangle is a solid colour, we don't need to render
+	// optimization - if the whole tile is covered by this rectangle,
+	// and the rectangle is a solid color, we don't need to render
 	// what's behind us
 	if (is_solid_color() && top == 0 && left == 0 && bottom == h && right == w)
 	{
