@@ -1,8 +1,8 @@
 /* === S Y N F I G ========================================================= */
 /*!	\file region.cpp
-**	\brief Template Header
+**	\brief Implementation of the "Region" layer
 **
-**	$Id: region.cpp 848 2007-10-06 02:25:36Z dooglus $
+**	$Id: region.cpp 1191 2007-12-10 01:58:46Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -60,10 +60,10 @@ using namespace etl;
 
 SYNFIG_LAYER_INIT(Region);
 SYNFIG_LAYER_SET_NAME(Region,"region");
-SYNFIG_LAYER_SET_LOCAL_NAME(Region,_("Region"));
-SYNFIG_LAYER_SET_CATEGORY(Region,_("Geometry"));
+SYNFIG_LAYER_SET_LOCAL_NAME(Region,N_("Region"));
+SYNFIG_LAYER_SET_CATEGORY(Region,N_("Geometry"));
 SYNFIG_LAYER_SET_VERSION(Region,"0.1");
-SYNFIG_LAYER_SET_CVS_ID(Region,"$Id: region.cpp 848 2007-10-06 02:25:36Z dooglus $");
+SYNFIG_LAYER_SET_CVS_ID(Region,"$Id: region.cpp 1191 2007-12-10 01:58:46Z dooglus $");
 
 /* === P R O C E D U R E S ================================================= */
 
