@@ -2,10 +2,11 @@
 /*!	\file trgt_gif.cpp
 **	\brief BMP Target Module
 **
-**	$Id: trgt_gif.cpp 373 2007-03-23 16:02:09Z dooglus $
+**	$Id: trgt_gif.cpp 1642 2008-02-09 18:25:35Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -52,13 +53,13 @@ SYNFIG_TARGET_INIT(gif);
 SYNFIG_TARGET_SET_NAME(gif,"gif");
 SYNFIG_TARGET_SET_EXT(gif,"gif");
 SYNFIG_TARGET_SET_VERSION(gif,"0.1");
-SYNFIG_TARGET_SET_CVS_ID(gif,"$Id: trgt_gif.cpp 373 2007-03-23 16:02:09Z dooglus $");
+SYNFIG_TARGET_SET_CVS_ID(gif,"$Id: trgt_gif.cpp 1642 2008-02-09 18:25:35Z dooglus $");
 
 /* === M E T H O D S ======================================================= */
 
 gif::gif(const char *filename_):
 	filename(filename_),
-	file( (filename=="-")?stdout:fopen(filename_,"wb") ),
+	file( (filename=="-")?stdout:fopen(filename_,POPEN_BINARY_WRITE_TYPE) ),
 	imagecount(0),
 
 	lossy(true),
@@ -132,21 +133,17 @@ gif::init()
 	else
 		fputc((0xF0+(rootsize-1))&~(1<<7),file.get());	// flags
 
-	fputc(0,file.get());		// backgound color
+	fputc(0,file.get());		// background color
 	fputc(0,file.get());		// Pixel Aspect Ratio
 
-	DEBUGPOINT();
-
 	if(!local_palette)
 	{
-	DEBUGPOINT();
 		curr_palette=Palette::grayscale(256/(1<<(8-rootsize))-1);
 		output_curr_palette();
 	}
 
 	if(loop_count && multi_image)
 	{
-	DEBUGPOINT();
 		fputc(33,file.get()); // 33 (hex 0x21) GIF Extension code
 		fputc(255,file.get()); // 255 (hex 0xFF) Application Extension Label
 		fputc(11,file.get()); // 11 (hex (0x0B) Length of Application Block
@@ -157,7 +154,6 @@ gif::init()
 		fputc((loop_count&0x0000ff00)>>8,file.get());
 		fputc(0,file.get()); // 0 (hex 0x00) a Data Sub-block Terminator.
 	}
-	DEBUGPOINT();
 
 	return true;
 }
