@@ -2,7 +2,7 @@
 /*!	\file trgt_gif.h
 **	\brief Template Header
 **
-**	$Id: trgt_gif.h 335 2007-03-16 00:39:09Z dooglus $
+**	$Id: trgt_gif.h 1079 2007-10-30 16:14:08Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -68,7 +68,7 @@ private:
 				empty();
 		}
 
-		// Emptys out the current pool into
+		// Empties out the current pool into
 		// the buffer. Calls 'dump()' if the
 		// buffer is full.
 		void empty()
@@ -151,7 +151,7 @@ private:
 		}
 
 		// Destructor just deletes any
-		// children and sibblings.
+		// children and siblings.
 		~lzwcode()
 		{
 			if(kids)
@@ -168,7 +168,7 @@ private:
 	int
 		i,			// General-purpose index
 		codesize,	// Current code size
-		rootsize,	// Size of pixel bits (will be recalculted)
+		rootsize,	// Size of pixel bits (will be recalculated)
 		nextcode;	// Next code to use
 	lzwcode *table,*next,*node;
 
