@@ -1,8 +1,8 @@
 /* === S Y N F I G ========================================================= */
 /*!	\file conicalgradient.cpp
-**	\brief Template Header
+**	\brief Implementation of the "Conical Gradient" layer
 **
-**	$Id: conicalgradient.cpp 368 2007-03-22 18:54:54Z dooglus $
+**	$Id: conicalgradient.cpp 1191 2007-12-10 01:58:46Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -53,10 +53,10 @@ using namespace synfig;
 
 SYNFIG_LAYER_INIT(ConicalGradient);
 SYNFIG_LAYER_SET_NAME(ConicalGradient,"conical_gradient");
-SYNFIG_LAYER_SET_LOCAL_NAME(ConicalGradient,_("Conical Gradient"));
-SYNFIG_LAYER_SET_CATEGORY(ConicalGradient,_("Gradients"));
+SYNFIG_LAYER_SET_LOCAL_NAME(ConicalGradient,N_("Conical Gradient"));
+SYNFIG_LAYER_SET_CATEGORY(ConicalGradient,N_("Gradients"));
 SYNFIG_LAYER_SET_VERSION(ConicalGradient,"0.1");
-SYNFIG_LAYER_SET_CVS_ID(ConicalGradient,"$Id: conicalgradient.cpp 368 2007-03-22 18:54:54Z dooglus $");
+SYNFIG_LAYER_SET_CVS_ID(ConicalGradient,"$Id: conicalgradient.cpp 1191 2007-12-10 01:58:46Z dooglus $");
 
 /* === P R O C E D U R E S ================================================= */
 
