@@ -2,7 +2,7 @@
 /*!	\file mptr_jpeg.cpp
 **	\brief ppm Target Module
 **
-**	$Id: mptr_jpeg.cpp 373 2007-03-23 16:02:09Z dooglus $
+**	$Id: mptr_jpeg.cpp 631 2007-09-08 15:33:07Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -62,7 +62,7 @@ SYNFIG_IMPORTER_INIT(jpeg_mptr);
 SYNFIG_IMPORTER_SET_NAME(jpeg_mptr,"jpeg");
 SYNFIG_IMPORTER_SET_EXT(jpeg_mptr,"jpg");
 SYNFIG_IMPORTER_SET_VERSION(jpeg_mptr,"0.1");
-SYNFIG_IMPORTER_SET_CVS_ID(jpeg_mptr,"$Id: mptr_jpeg.cpp 373 2007-03-23 16:02:09Z dooglus $");
+SYNFIG_IMPORTER_SET_CVS_ID(jpeg_mptr,"$Id: mptr_jpeg.cpp 631 2007-09-08 15:33:07Z dooglus $");
 
 /* === M E T H O D S ======================================================= */
 
@@ -249,7 +249,7 @@ jpeg_mptr::~jpeg_mptr()
 }
 
 bool
-jpeg_mptr::get_frame(synfig::Surface &surface,Time, synfig::ProgressCallback *cb)
+jpeg_mptr::get_frame(synfig::Surface &surface,Time, synfig::ProgressCallback */*cb*/)
 {
 	surface.mirror(surface_buffer);
 	return true;
