@@ -2,10 +2,11 @@
 /*!	\file trgt_jpeg.cpp
 **	\brief jpeg_trgt Target Module
 **
-**	$Id: trgt_jpeg.cpp 631 2007-09-08 15:33:07Z dooglus $
+**	$Id: trgt_jpeg.cpp 1642 2008-02-09 18:25:35Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -53,7 +54,7 @@ SYNFIG_TARGET_INIT(jpeg_trgt);
 SYNFIG_TARGET_SET_NAME(jpeg_trgt,"jpeg");
 SYNFIG_TARGET_SET_EXT(jpeg_trgt,"jpg");
 SYNFIG_TARGET_SET_VERSION(jpeg_trgt,"0.1");
-SYNFIG_TARGET_SET_CVS_ID(jpeg_trgt,"$Id: trgt_jpeg.cpp 631 2007-09-08 15:33:07Z dooglus $");
+SYNFIG_TARGET_SET_CVS_ID(jpeg_trgt,"$Id: trgt_jpeg.cpp 1642 2008-02-09 18:25:35Z dooglus $");
 
 /* === M E T H O D S ======================================================= */
 
@@ -109,18 +110,15 @@ jpeg_trgt::start_frame(synfig::ProgressCallback *callback)
 	}
 	else if(multi_image)
 	{
-		String
-			newfilename(filename),
-			ext(find(filename.begin(),filename.end(),'.'),filename.end());
-		newfilename.erase(find(newfilename.begin(),newfilename.end(),'.'),newfilename.end());
-
-		newfilename+=etl::strprintf("%04d",imagecount)+ext;
-		file=fopen(newfilename.c_str(),"wb");
+		String newfilename(filename_sans_extension(filename) +
+						   etl::strprintf(".%04d",imagecount) +
+						   filename_extension(filename));
+		file=fopen(newfilename.c_str(),POPEN_BINARY_WRITE_TYPE);
 		if(callback)callback->task(newfilename);
 	}
 	else
 	{
-		file=fopen(filename.c_str(),"wb");
+		file=fopen(filename.c_str(),POPEN_BINARY_WRITE_TYPE);
 		if(callback)callback->task(filename);
 	}
 
