@@ -2,7 +2,7 @@
 /*!	\file trgt_av.cpp
 **	\brief \writeme
 **
-**	$Id: trgt_av.cpp 631 2007-09-08 15:33:07Z dooglus $
+**	$Id: trgt_av.cpp 1141 2007-11-12 09:34:37Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -61,7 +61,7 @@ SYNFIG_TARGET_INIT(Target_LibAVCodec);
 SYNFIG_TARGET_SET_NAME(Target_LibAVCodec,"libav");
 SYNFIG_TARGET_SET_EXT(Target_LibAVCodec,"avi");
 SYNFIG_TARGET_SET_VERSION(Target_LibAVCodec,"0.1");
-SYNFIG_TARGET_SET_CVS_ID(Target_LibAVCodec,"$Id: trgt_av.cpp 631 2007-09-08 15:33:07Z dooglus $");
+SYNFIG_TARGET_SET_CVS_ID(Target_LibAVCodec,"$Id: trgt_av.cpp 1141 2007-11-12 09:34:37Z dooglus $");
 
 /* === C L A S S E S & S T R U C T S ======================================= */
 
@@ -286,7 +286,7 @@ public:
 class VideoEncoder
 {
 public:
-	AVFrame *encodable;	//for compressiong and output to a file (in compatible pixel format)
+	AVFrame *encodable;	//for compression and output to a file (in compatible pixel format)
 
 	vector<unsigned char>	videobuffer;
 
@@ -406,7 +406,7 @@ public:
 		if( context->coded_frame && context->coded_frame->key_frame)
 			pkt.flags |= PKT_FLAG_KEY;
 
-		//cludge for raw picture format (they said they'd fix)
+		//kluge for raw picture format (they said they'd fix)
 		if (formatc->oformat->flags & AVFMT_RAWPICTURE)
 		{
 			ret = av_write_frame(formatc, &pkt);
@@ -642,7 +642,7 @@ public:
 
 	void CleanUp()
 	{
-		int i;
+		unsigned int i;
 
 		if(picture) free_picture(picture);
 
@@ -929,7 +929,7 @@ Target_LibAVCodec::end_scanline()
 
 bool Target_LibAVCodec::init()
 {
-	//hardcode test for mpeg
+	//hardcoded test for mpeg
 	if(!data->Initialize(filename.c_str(),NULL))
 	{
 		synfig::warning("Unable to Initialize the audio video encoders");
