@@ -1,11 +1,12 @@
 /* === S Y N F I G ========================================================= */
 /*!	\file distort.h
-**	\brief Template Header
+**	\brief Header file for implementation of the "Noise Distort" layer
 **
-**	$Id: distort.h 335 2007-03-16 00:39:09Z dooglus $
+**	$Id: distort.h 1643 2008-02-09 19:12:18Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007, 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -49,7 +50,7 @@ private:
 	synfig::Vector size;
 
 	Random random;
-	int smooth;
+	Random::SmoothType smooth;
 	int detail;
 	synfig::Real speed;
 	bool turbulent;
@@ -73,9 +74,9 @@ public:
 	virtual void set_time(synfig::Context context, synfig::Time time)const;
 	virtual void set_time(synfig::Context context, synfig::Time time, const synfig::Point &point)const;
 	virtual synfig::Rect get_bounding_rect(synfig::Context context)const;
-
 	virtual Vocab get_param_vocab()const;
-};
+	virtual bool reads_context()const { return true; }
+}; // EOF of class NoiseDistort
 
 /* === E N D =============================================================== */
 
