@@ -2,10 +2,11 @@
 /*!	\file mod_noise/main.cpp
 **	\brief Template Header
 **
-**	$Id: main.cpp 335 2007-03-16 00:39:09Z dooglus $
+**	$Id: main.cpp 1643 2008-02-09 19:12:18Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007, 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -41,6 +42,7 @@
 #include "noise.h"
 #include "distort.h"
 #include "random.h"
+#include "valuenode_random.h"
 
 #endif
 
@@ -59,4 +61,8 @@ MODULE_INVENTORY_BEGIN(libmod_noise)
 		LAYER(Noise)
 		LAYER(NoiseDistort)
 	END_LAYERS
+
+	BEGIN_VALUENODES
+		VALUENODE(synfig::ValueNode_Random, "random", _("Random"), synfig::RELEASE_VERSION_0_61_08) // SVN r907
+	END_VALUENODES
 MODULE_INVENTORY_END
