@@ -1,11 +1,12 @@
 /* === S Y N F I G ========================================================= */
 /*!	\file noise.cpp
-**	\brief blehh
+**	\brief Implementation of the "Noise Gradient" layer
 **
-**	$Id: noise.cpp 631 2007-09-08 15:33:07Z dooglus $
+**	$Id: noise.cpp 1642 2008-02-09 18:25:35Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -52,10 +53,10 @@ using namespace etl;
 
 SYNFIG_LAYER_INIT(Noise);
 SYNFIG_LAYER_SET_NAME(Noise,"noise");
-SYNFIG_LAYER_SET_LOCAL_NAME(Noise,_("Noise Gradient"));
-SYNFIG_LAYER_SET_CATEGORY(Noise,_("Gradients"));
+SYNFIG_LAYER_SET_LOCAL_NAME(Noise,N_("Noise Gradient"));
+SYNFIG_LAYER_SET_CATEGORY(Noise,N_("Gradients"));
 SYNFIG_LAYER_SET_VERSION(Noise,"0.0");
-SYNFIG_LAYER_SET_CVS_ID(Noise,"$Id: noise.cpp 631 2007-09-08 15:33:07Z dooglus $");
+SYNFIG_LAYER_SET_CVS_ID(Noise,"$Id: noise.cpp 1642 2008-02-09 18:25:35Z dooglus $");
 
 /* === P R O C E D U R E S ================================================= */
 
@@ -65,7 +66,7 @@ Noise::Noise():
 	size(1,1),
 	gradient(Color::black(), Color::white())
 {
-	smooth=2;
+	smooth=Random::SMOOTH_COSINE;
 	detail=4;
 	speed=0;
 	do_alpha=false;
@@ -96,9 +97,9 @@ Noise::color_func(const Point &point, float pixel_size,Context /*context*/)const
 	int i;
 	Time time;
 	time=speed*curr_time;
-	int smooth((!speed && Noise::smooth==3)?5:Noise::smooth);
+	Random::SmoothType smooth((!speed && Noise::smooth == Random::SMOOTH_SPLINE) ? Random::SMOOTH_FAST_SPLINE : Noise::smooth);
 
-	float t(time);
+	float ftime(time);
 
 	{
 		float amount=0.0f;
@@ -107,15 +108,15 @@ Noise::color_func(const Point &point, float pixel_size,Context /*context*/)const
 		float alpha=0.0f;
 		for(i=0;i<detail;i++)
 		{
-			amount=random(smooth,0+(detail-i)*5,x,y,t)+amount*0.5;
+			amount=random(smooth,0+(detail-i)*5,x,y,ftime)+amount*0.5;
 			if(amount<-1)amount=-1;if(amount>1)amount=1;
 
 			if(super_sample&&pixel_size)
 			{
-				amount2=random(smooth,0+(detail-i)*5,x2,y,t)+amount2*0.5;
+				amount2=random(smooth,0+(detail-i)*5,x2,y,ftime)+amount2*0.5;
 				if(amount2<-1)amount2=-1;if(amount2>1)amount2=1;
 
-				amount3=random(smooth,0+(detail-i)*5,x,y2,t)+amount3*0.5;
+				amount3=random(smooth,0+(detail-i)*5,x,y2,ftime)+amount3*0.5;
 				if(amount3<-1)amount3=-1;if(amount3>1)amount3=1;
 
 				if(turbulent)
@@ -130,7 +131,7 @@ Noise::color_func(const Point &point, float pixel_size,Context /*context*/)const
 
 			if(do_alpha)
 			{
-				alpha=random(smooth,3+(detail-i)*5,x,y,t)+alpha*0.5;
+				alpha=random(smooth,3+(detail-i)*5,x,y,ftime)+alpha*0.5;
 				if(alpha<-1)alpha=-1;if(alpha>1)alpha=1;
 			}
 
@@ -142,7 +143,7 @@ Noise::color_func(const Point &point, float pixel_size,Context /*context*/)const
 
 			x*=0.5f;
 			y*=0.5f;
-			//t*=0.5f;
+			//ftime*=0.5f;
 		}
 
 		if(!turbulent)
@@ -258,11 +259,11 @@ Noise::get_param_vocab()const
 		.set_local_name(_("Interpolation"))
 		.set_description(_("What type of interpolation to use"))
 		.set_hint("enum")
-		.add_enum_value(0,"nearest",_("Nearest Neighbor"))
-		.add_enum_value(1,"linear",_("Linear"))
-		.add_enum_value(2,"cosine",_("Cosine"))
-		.add_enum_value(3,"spline",_("Spline"))
-		.add_enum_value(4,"cubic",_("Cubic"))
+		.add_enum_value(Random::SMOOTH_DEFAULT,	"nearest",	_("Nearest Neighbor"))
+		.add_enum_value(Random::SMOOTH_LINEAR,	"linear",	_("Linear"))
+		.add_enum_value(Random::SMOOTH_COSINE,	"cosine",	_("Cosine"))
+		.add_enum_value(Random::SMOOTH_SPLINE,	"spline",	_("Spline"))
+		.add_enum_value(Random::SMOOTH_CUBIC,	"cubic",	_("Cubic"))
 	);
 	ret.push_back(ParamDesc("detail")
 		.set_local_name(_("Detail"))
