@@ -1,11 +1,12 @@
 /* === S Y N F I G ========================================================= */
 /*!	\file noise.h
-**	\brief Template Header
+**	\brief Header file for implementation of the "Noise Gradient" layer
 **
-**	$Id: noise.h 335 2007-03-16 00:39:09Z dooglus $
+**	$Id: noise.h 1642 2008-02-09 18:25:35Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -50,7 +51,7 @@ private:
 	synfig::Vector size;
 
 	Random random;
-	int smooth;
+	Random::SmoothType smooth;
 	int detail;
 	bool do_alpha;
 	synfig::Gradient gradient;
