@@ -2,10 +2,11 @@
 /*!	\file mod_noise/random.h
 **	\brief Template Header
 **
-**	$Id: random.h 335 2007-03-16 00:39:09Z dooglus $
+**	$Id: random.h 880 2007-10-10 03:20:35Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -43,8 +44,18 @@ public:
 	void set_seed(int x);
 	int get_seed()const { return seed_; }
 
+	enum SmoothType
+	{
+		SMOOTH_DEFAULT		= 0,
+		SMOOTH_LINEAR		= 1,
+		SMOOTH_COSINE		= 2,
+		SMOOTH_SPLINE		= 3,
+		SMOOTH_CUBIC		= 4,
+		SMOOTH_FAST_SPLINE	= 5,
+	};
+
 	float operator()(int subseed,int x,int y=0, int t=0)const;
-	float operator()(int smooth,int subseed,float x,float y=0, float t=0)const;
+	float operator()(SmoothType smooth,int subseed,float x,float y=0, float t=0)const;
 };
 
 /* === E N D =============================================================== */
