@@ -1,12 +1,12 @@
 /* === S Y N F I G ========================================================= */
 /*!	\file plant.cpp
-**	\brief Template
+**	\brief Implementation of the "Plant" layer
 **
-**	$Id: plant.cpp 848 2007-10-06 02:25:36Z dooglus $
+**	$Id: plant.cpp 1699 2008-02-15 13:56:05Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
-**	Copyright (c) 2007 Chris Moore
+**	Copyright (c) 2007, 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -65,10 +65,10 @@ using namespace etl;
 
 SYNFIG_LAYER_INIT(Plant);
 SYNFIG_LAYER_SET_NAME(Plant,"plant");
-SYNFIG_LAYER_SET_LOCAL_NAME(Plant,_("Plant"));
-SYNFIG_LAYER_SET_CATEGORY(Plant,_("Other"));
-SYNFIG_LAYER_SET_VERSION(Plant,"0.1");
-SYNFIG_LAYER_SET_CVS_ID(Plant,"$Id: plant.cpp 848 2007-10-06 02:25:36Z dooglus $");
+SYNFIG_LAYER_SET_LOCAL_NAME(Plant,N_("Plant"));
+SYNFIG_LAYER_SET_CATEGORY(Plant,N_("Other"));
+SYNFIG_LAYER_SET_VERSION(Plant,"0.2");
+SYNFIG_LAYER_SET_CVS_ID(Plant,"$Id: plant.cpp 1699 2008-02-15 13:56:05Z dooglus $");
 
 /* === P R O C E D U R E S ================================================= */
 
@@ -76,12 +76,15 @@ SYNFIG_LAYER_SET_CVS_ID(Plant,"$Id: plant.cpp 848 2007-10-06 02:25:36Z dooglus $
 
 
 Plant::Plant():
+	offset(0,0),
 	split_angle(Angle::deg(10)),
 	gravity(0,-0.1),
 	velocity(0.3),
 	perp_velocity(0.0),
 	step(0.01),
-	sprouts(10)
+	sprouts(10),
+	version(version__),
+	use_width(true)
 {
 	bounding_rect=Rect::zero();
 	random_factor=0.2;
@@ -107,6 +110,7 @@ Plant::Plant():
 	needs_sync_=true;
 	sync();
 	size_as_alpha=false;
+	reverse=true;
 }
 
 void
@@ -207,6 +211,9 @@ Plant::sync()const
 	// loop through the bline; seg counts the blines as we do so; stop before iter is the last bline in the list
 	for(;next!=bline.end();iter=next++,seg++)
 	{
+		float iterw=iter->get_width();	// the width value of the iter vertex
+		float nextw=next->get_width();	// the width value of the next vertex
+		float width;					// the width at an intermediate position
 		curve.p1()=iter->get_vertex();
 		curve.t1()=iter->get_tangent2();
 		curve.p2()=next->get_vertex();
@@ -217,6 +224,7 @@ Plant::sync()const
 		Real f;
 
 		int i=0, branch_count = 0, steps = round_to_int(1.0/step);
+		if (steps < 1) steps = 1;
 		for(f=0.0;f<1.0;f+=step,i++)
 		{
 			Point point(curve(f));
@@ -236,6 +244,14 @@ Plant::sync()const
 				branch_velocity[0] += random_factor * random(Random::SMOOTH_COSINE, 1, f*splits, 0.0f, 0.0f);
 				branch_velocity[1] += random_factor * random(Random::SMOOTH_COSINE, 2, f*splits, 0.0f, 0.0f);
 
+				if (use_width)
+				{
+					width = iterw+(nextw-iterw)*f; // calculate the width based on the current position
+
+					branch_velocity[0] *= width; // scale the velocity accordingly to the current width
+					branch_velocity[1] *= width;
+				}
+
 				branch_count++;
 				branch(i, 0, 0,		 // time
 					   stunt_growth, // stunt growth
@@ -268,18 +284,32 @@ Plant::set_param(const String & param, const ValueBase &value)
 		needs_sync_=true;
 		return true;
 	}
+	IMPORT(offset);
 	IMPORT_PLUS(split_angle,needs_sync_=true);
 	IMPORT_PLUS(gravity,needs_sync_=true);
 	IMPORT_PLUS(gradient,needs_sync_=true);
 	IMPORT_PLUS(velocity,needs_sync_=true);
 	IMPORT_PLUS(perp_velocity,needs_sync_=true);
-	IMPORT_PLUS(step,needs_sync_=true);
-	IMPORT_PLUS(splits,needs_sync_=true);
+	IMPORT_PLUS(step,{
+			needs_sync_ = true;
+			if (step <= 0)
+				step=0.01; // user is probably clueless - give a good default
+			else if (step < 0.00001)
+				step=0.00001; // 100K should be enough for anyone
+			else if (step > 1)
+				step=1;
+		});
+	IMPORT_PLUS(splits,{
+			needs_sync_=true;
+			if (splits < 1)
+				splits = 1;
+		});
 	IMPORT_PLUS(sprouts,needs_sync_=true);
 	IMPORT_PLUS(random_factor,needs_sync_=true);
 	IMPORT_PLUS(drag,needs_sync_=true);
 	IMPORT(size);
 	IMPORT(size_as_alpha);
+	IMPORT(reverse);
 
 	return Layer_Composite::set_param(param,value);
 }
@@ -314,6 +344,7 @@ Plant::get_param(const String& param)const
 	if(param=="seed")
 		return random.get_seed();
 	EXPORT(bline);
+	EXPORT(offset);
 	EXPORT(split_angle);
 	EXPORT(gravity);
 	EXPORT(velocity);
@@ -327,9 +358,12 @@ Plant::get_param(const String& param)const
 	EXPORT(size);
 
 	EXPORT(size_as_alpha);
+	EXPORT(reverse);
 
 	EXPORT_NAME();
-	EXPORT_VERSION();
+
+	if(param=="Version" || param=="version" || param=="version__")
+		return version;
 
 	return Layer_Composite::get_param(param);
 }
@@ -342,8 +376,12 @@ Plant::get_param_vocab()const
 	ret.push_back(ParamDesc("bline")
 		.set_local_name(_("Vertices"))
 		.set_description(_("A list of BLine Points"))
-		//.set_origin("offset")
-		//.set_scalar("width")
+		.set_origin("offset")
+		.set_hint("width")
+	);
+
+	ret.push_back(ParamDesc("offset")
+		.set_local_name(_("Offset"))
 	);
 
 	ret.push_back(ParamDesc("gradient")
@@ -383,6 +421,11 @@ Plant::get_param_vocab()const
 		.set_description(_("If enabled, the alpha channel from the gradient is multiplied by the stem size, and an alpha of 1.0 is used when rendering"))
 	);
 
+	ret.push_back(ParamDesc("reverse")
+		.set_local_name(_("Reverse"))
+		.set_description(_("If enabled, render the plant in the opposite direction"))
+	);
+
 	ret.push_back(ParamDesc("step")
 		.set_local_name(_("Step"))
 		.set_description(_("Measure of the distance between points when rendering"))
@@ -416,6 +459,17 @@ Plant::get_param_vocab()const
 	return ret;
 }
 
+bool
+Plant::set_version(const String &ver)
+{
+	version = ver;
+
+	if (version == "0.1")
+		use_width = false;
+
+	return true;
+}
+
 bool
 Plant::accelerated_render(Context context,Surface *surface,int quality, const RendDesc &renddesc, ProgressCallback *cb)const
 {
@@ -427,8 +481,8 @@ Plant::accelerated_render(Context context,Surface *surface,int quality, const Re
 	dest_surface.set_wh(surface->get_w(),surface->get_h());
 	dest_surface.clear();
 
-	const Point	tl(renddesc.get_tl());
-	const Point br(renddesc.get_br());
+	const Point	tl(renddesc.get_tl()-offset);
+	const Point br(renddesc.get_br()-offset);
 
 	const int	w(renddesc.get_w());
 	const int	h(renddesc.get_h());
@@ -440,190 +494,216 @@ Plant::accelerated_render(Context context,Surface *surface,int quality, const Re
 	const Real pw = (br[0] - tl[0]) / w;
 	const Real ph = (br[1] - tl[1]) / h;
 
+	if (isinf(pw) || isinf(ph))
+		return true;
+
 	if(needs_sync_==true)
 		sync();
 
-	std::vector<Particle>::reverse_iterator iter;
-
-	float radius(size*sqrt(1.0f/(abs(pw)*abs(ph))));
-
-	int x1,y1,x2,y2;
-	for(iter=particle_list.rbegin();iter!=particle_list.rend();++iter)
+	if (particle_list.begin() != particle_list.end())
 	{
-		float scaled_radius(radius);
-		Color color(iter->color);
-		if(size_as_alpha)
+		std::vector<Particle>::iterator iter;
+		Particle *particle;
+
+		float radius(size*sqrt(1.0f/(abs(pw)*abs(ph))));
+
+		int x1,y1,x2,y2;
+
+		if (reverse)	iter = particle_list.end();
+		else			iter = particle_list.begin();
+
+		while (true)
 		{
-			scaled_radius*=color.get_a();
-			color.set_a(1);
-		}
+			if (reverse)	particle = &(*(iter-1));
+			else			particle = &(*iter);
 
-		// previously, radius was multiplied by sqrt(step)*12 only if
-		// the radius came out at less than 1 (pixel):
-		//   if (radius<=1.0f) radius*=sqrt(step)*12.0f;
-		// seems a little arbitrary - does it help?
-
-		// calculate the box that this particle will be drawn as
-		float x1f=(iter->point[0]-tl[0])/pw-(scaled_radius*0.5);
-		float x2f=(iter->point[0]-tl[0])/pw+(scaled_radius*0.5);
-		float y1f=(iter->point[1]-tl[1])/ph-(scaled_radius*0.5);
-		float y2f=(iter->point[1]-tl[1])/ph+(scaled_radius*0.5);
-		x1=ceil_to_int(x1f);
-		x2=ceil_to_int(x2f)-1;
-		y1=ceil_to_int(y1f);
-		y2=ceil_to_int(y2f)-1;
-
-		// if the box is entirely off the canvas, go to the next particle
-		if(x1>surface_width || y1>surface_height || x2<0 || y2<0) continue;
-
-		float x1e=x1-x1f, x2e=x2f-x2, y1e=y1-y1f, y2e=y2f-y2;
-		// printf("x1e %.4f x2e %.4f y1e %.4f y2e %.4f\n", x1e, x2e, y1e, y2e);
-
-		// adjust the box so it's entirely on the canvas
-		if(x1<=0) { x1=0; x1e=0; }
-		if(y1<=0) { y1=0; y1e=0; }
-		if(x2>=surface_width)  { x2=surface_width;  x2e=0; }
-		if(y2>=surface_height) { y2=surface_height; y2e=0; }
-
-		int w(x2-x1), h(y2-y1);
-
-		Surface::alpha_pen surface_pen(dest_surface.get_pen(x1,y1),1.0f);
-		if(w>0 && h>0)
-			dest_surface.fill(color,surface_pen,w,h);
-
-		/* the rectangle doesn't cross any vertical pixel boundaries so we don't
-		 * need to draw any top or bottom edges
-		 */
-		if(x2<x1)
-		{
-			// case 1 - a single pixel
-			if(y2<y1)
+			float scaled_radius(radius);
+			Color color(particle->color);
+			if(size_as_alpha)
 			{
-				surface_pen.move_to(x2,y2);
-				surface_pen.set_alpha((x2f-x1f)*(y2f-y1f));
-				surface_pen.put_value(color);
+				scaled_radius*=color.get_a();
+				color.set_a(1);
 			}
-			// case 2 - a single vertical column of pixels
-			else
+
+			// previously, radius was multiplied by sqrt(step)*12 only if
+			// the radius came out at less than 1 (pixel):
+			//   if (radius<=1.0f) radius*=sqrt(step)*12.0f;
+			// seems a little arbitrary - does it help?
+
+			// calculate the box that this particle will be drawn as
+			float x1f=(particle->point[0]-tl[0])/pw-(scaled_radius*0.5);
+			float x2f=(particle->point[0]-tl[0])/pw+(scaled_radius*0.5);
+			float y1f=(particle->point[1]-tl[1])/ph-(scaled_radius*0.5);
+			float y2f=(particle->point[1]-tl[1])/ph+(scaled_radius*0.5);
+			x1=ceil_to_int(x1f);
+			x2=ceil_to_int(x2f)-1;
+			y1=ceil_to_int(y1f);
+			y2=ceil_to_int(y2f)-1;
+
+			// if the box isn't entirely off the canvas, draw it
+			if(x1<=surface_width && y1<=surface_height && x2>=0 && y2>=0)
 			{
-				surface_pen.move_to(x2,y1-1);
-				if (y1e!=0)	// maybe draw top pixel
+				float x1e=x1-x1f, x2e=x2f-x2, y1e=y1-y1f, y2e=y2f-y2;
+				// printf("x1e %.4f x2e %.4f y1e %.4f y2e %.4f\n", x1e, x2e, y1e, y2e);
+
+				// adjust the box so it's entirely on the canvas
+				if(x1<=0) { x1=0; x1e=0; }
+				if(y1<=0) { y1=0; y1e=0; }
+				if(x2>=surface_width)  { x2=surface_width;  x2e=0; }
+				if(y2>=surface_height) { y2=surface_height; y2e=0; }
+
+				int w(x2-x1), h(y2-y1);
+
+				Surface::alpha_pen surface_pen(dest_surface.get_pen(x1,y1),1.0f);
+				if(w>0 && h>0)
+					dest_surface.fill(color,surface_pen,w,h);
+
+				/* the rectangle doesn't cross any vertical pixel boundaries so we don't
+				 * need to draw any top or bottom edges
+				 */
+				if(x2<x1)
 				{
-					surface_pen.set_alpha(y1e*(x2f-x1f));
-					surface_pen.put_value(color);
-				}
-				surface_pen.inc_y();
-				surface_pen.set_alpha(x2f-x1f);
-				for(int i=y1; i<y2; i++) // maybe draw pixels between
-				{
-					surface_pen.put_value(color);
-					surface_pen.inc_y();
-				}
-				if (y2e!=0)	// maybe draw bottom pixel
-				{
-					surface_pen.set_alpha(y2e*(x2f-x1f));
-					surface_pen.put_value(color);
-				}
-			}
-		}
-		else
-		{
-			// case 3 - a single horizontal row of pixels
-			if(y2<y1)
-			{
-				surface_pen.move_to(x1-1,y2);
-				if (x1e!=0)	// maybe draw left pixel
-				{
-					surface_pen.set_alpha(x1e*(y2f-y1f));
-					surface_pen.put_value(color);
-				}
-				surface_pen.inc_x();
-				surface_pen.set_alpha(y2f-y1f);
-				for(int i=x1; i<x2; i++) // maybe draw pixels between
-				{
-					surface_pen.put_value(color);
-					surface_pen.inc_x();
-				}
-				if (x2e!=0)	// maybe draw right pixel
-				{
-					surface_pen.set_alpha(x2e*(y2f-y1f));
-					surface_pen.put_value(color);
-				}
-			}
-			// case 4 - a proper block of pixels
-			else
-			{
-				if (x1e!=0)	// maybe draw left edge
-				{
-					surface_pen.move_to(x1-1,y1-1);
-					if (y1e!=0)	// maybe draw top left pixel
+					// case 1 - a single pixel
+					if(y2<y1)
 					{
-						surface_pen.set_alpha(x1e*y1e);
+						surface_pen.move_to(x2,y2);
+						surface_pen.set_alpha((x2f-x1f)*(y2f-y1f));
 						surface_pen.put_value(color);
 					}
-					surface_pen.inc_y();
-					surface_pen.set_alpha(x1e);
-					for(int i=y1; i<y2; i++) // maybe draw pixels along the left edge
+					// case 2 - a single vertical column of pixels
+					else
 					{
-						surface_pen.put_value(color);
+						surface_pen.move_to(x2,y1-1);
+						if (y1e!=0)	// maybe draw top pixel
+						{
+							surface_pen.set_alpha(y1e*(x2f-x1f));
+							surface_pen.put_value(color);
+						}
 						surface_pen.inc_y();
+						surface_pen.set_alpha(x2f-x1f);
+						for(int i=y1; i<y2; i++) // maybe draw pixels between
+						{
+							surface_pen.put_value(color);
+							surface_pen.inc_y();
+						}
+						if (y2e!=0)	// maybe draw bottom pixel
+						{
+							surface_pen.set_alpha(y2e*(x2f-x1f));
+							surface_pen.put_value(color);
+						}
 					}
-					if (y2e!=0)	// maybe draw bottom left pixel
-					{
-						surface_pen.set_alpha(x1e*y2e);
-						surface_pen.put_value(color);
-					}
-					surface_pen.inc_x();
 				}
 				else
-					surface_pen.move_to(x1,y2);
-
-				if (y2e!=0)	// maybe draw bottom edge
 				{
-					surface_pen.set_alpha(y2e);
-					for(int i=x1; i<x2; i++) // maybe draw pixels along the bottom edge
+					// case 3 - a single horizontal row of pixels
+					if(y2<y1)
 					{
-						surface_pen.put_value(color);
+						surface_pen.move_to(x1-1,y2);
+						if (x1e!=0)	// maybe draw left pixel
+						{
+							surface_pen.set_alpha(x1e*(y2f-y1f));
+							surface_pen.put_value(color);
+						}
 						surface_pen.inc_x();
+						surface_pen.set_alpha(y2f-y1f);
+						for(int i=x1; i<x2; i++) // maybe draw pixels between
+						{
+							surface_pen.put_value(color);
+							surface_pen.inc_x();
+						}
+						if (x2e!=0)	// maybe draw right pixel
+						{
+							surface_pen.set_alpha(x2e*(y2f-y1f));
+							surface_pen.put_value(color);
+						}
 					}
-					if (x2e!=0)	// maybe draw bottom right pixel
+					// case 4 - a proper block of pixels
+					else
 					{
-						surface_pen.set_alpha(x2e*y2e);
-						surface_pen.put_value(color);
-					}
-					surface_pen.dec_y();
-				}
-				else
-					surface_pen.move_to(x2,y2-1);
+						if (x1e!=0)	// maybe draw left edge
+						{
+							surface_pen.move_to(x1-1,y1-1);
+							if (y1e!=0)	// maybe draw top left pixel
+							{
+								surface_pen.set_alpha(x1e*y1e);
+								surface_pen.put_value(color);
+							}
+							surface_pen.inc_y();
+							surface_pen.set_alpha(x1e);
+							for(int i=y1; i<y2; i++) // maybe draw pixels along the left edge
+							{
+								surface_pen.put_value(color);
+								surface_pen.inc_y();
+							}
+							if (y2e!=0)	// maybe draw bottom left pixel
+							{
+								surface_pen.set_alpha(x1e*y2e);
+								surface_pen.put_value(color);
+							}
+							surface_pen.inc_x();
+						}
+						else
+							surface_pen.move_to(x1,y2);
 
-				if (x2e!=0)	// maybe draw right edge
-				{
-					surface_pen.set_alpha(x2e);
-					for(int i=y1; i<y2; i++) // maybe draw pixels along the right edge
-					{
-						surface_pen.put_value(color);
-						surface_pen.dec_y();
-					}
-					if (y1e!=0)	// maybe draw top right pixel
-					{
-						surface_pen.set_alpha(x2e*y1e);
-						surface_pen.put_value(color);
-					}
-					surface_pen.dec_x();
-				}
-				else
-					surface_pen.move_to(x2-1,y1-1);
+						if (y2e!=0)	// maybe draw bottom edge
+						{
+							surface_pen.set_alpha(y2e);
+							for(int i=x1; i<x2; i++) // maybe draw pixels along the bottom edge
+							{
+								surface_pen.put_value(color);
+								surface_pen.inc_x();
+							}
+							if (x2e!=0)	// maybe draw bottom right pixel
+							{
+								surface_pen.set_alpha(x2e*y2e);
+								surface_pen.put_value(color);
+							}
+							surface_pen.dec_y();
+						}
+						else
+							surface_pen.move_to(x2,y2-1);
 
-				if (y1e!=0)	// maybe draw top edge
-				{
-					surface_pen.set_alpha(y1e);
-					for(int i=x1; i<x2; i++) // maybe draw pixels along the top edge
-					{
-						surface_pen.put_value(color);
-						surface_pen.dec_x();
+						if (x2e!=0)	// maybe draw right edge
+						{
+							surface_pen.set_alpha(x2e);
+							for(int i=y1; i<y2; i++) // maybe draw pixels along the right edge
+							{
+								surface_pen.put_value(color);
+								surface_pen.dec_y();
+							}
+							if (y1e!=0)	// maybe draw top right pixel
+							{
+								surface_pen.set_alpha(x2e*y1e);
+								surface_pen.put_value(color);
+							}
+							surface_pen.dec_x();
+						}
+						else
+							surface_pen.move_to(x2-1,y1-1);
+
+						if (y1e!=0)	// maybe draw top edge
+						{
+							surface_pen.set_alpha(y1e);
+							for(int i=x1; i<x2; i++) // maybe draw pixels along the top edge
+							{
+								surface_pen.put_value(color);
+								surface_pen.dec_x();
+							}
+						}
 					}
 				}
 			}
+
+			if (reverse)
+			{
+				if (--iter == particle_list.begin())
+					break;
+			}
+			else
+			{
+				if (++iter == particle_list.end())
+					break;
+			}
 		}
 	}
 
