@@ -2,10 +2,11 @@
 /*!	\file mptr_png.cpp
 **	\brief ppm Target Module
 **
-**	$Id: mptr_png.cpp 631 2007-09-08 15:33:07Z dooglus $
+**	$Id: mptr_png.cpp 1642 2008-02-09 18:25:35Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -62,7 +63,7 @@ SYNFIG_IMPORTER_INIT(png_mptr);
 SYNFIG_IMPORTER_SET_NAME(png_mptr,"png");
 SYNFIG_IMPORTER_SET_EXT(png_mptr,"png");
 SYNFIG_IMPORTER_SET_VERSION(png_mptr,"0.1");
-SYNFIG_IMPORTER_SET_CVS_ID(png_mptr,"$Id: mptr_png.cpp 631 2007-09-08 15:33:07Z dooglus $");
+SYNFIG_IMPORTER_SET_CVS_ID(png_mptr,"$Id: mptr_png.cpp 1642 2008-02-09 18:25:35Z dooglus $");
 
 /* === M E T H O D S ======================================================= */
 
@@ -162,6 +163,21 @@ png_mptr::png_mptr(const char *file_name)
 	png_init_io(png_ptr, file);
 	png_set_sig_bytes(png_ptr,PNG_CHECK_BYTES);
 
+	png_read_info(png_ptr, info_ptr);
+
+	int bit_depth,color_type,interlace_type, compression_type,filter_method;
+	png_uint_32 width,height;
+
+	png_get_IHDR(png_ptr, info_ptr, &width, &height,
+				 &bit_depth, &color_type, &interlace_type,
+				 &compression_type, &filter_method);
+
+	if (bit_depth == 16)
+		png_set_strip_16(png_ptr);
+
+	if (bit_depth < 8)
+		png_set_packing(png_ptr);
+
 	double fgamma;
 	if (png_get_gAMA(png_ptr, info_ptr, &fgamma))
 	{
@@ -184,18 +200,23 @@ png_mptr::png_mptr(const char *file_name)
 
 	png_set_read_user_chunk_fn(png_ptr, this, &png_mptr::read_chunk_callback);
 
+	// man libpng tells me:
+	//   You must use png_transforms and not call any
+	//   png_set_transform() functions when you use png_read_png().
+	// but we used png_set_gamma(), which may be why we were seeing a crash at the end
+	//   png_read_png(png_ptr, info_ptr, PNG_TRANSFORM_PACKING|PNG_TRANSFORM_STRIP_16, NULL);
 
-	png_read_png(png_ptr, info_ptr, PNG_TRANSFORM_PACKING|PNG_TRANSFORM_STRIP_16, NULL);
-
-	int bit_depth,color_type,interlace_type, compression_type,filter_method;
-	png_uint_32 width,height;
-
-    png_get_IHDR(png_ptr, info_ptr, &width, &height,
-       &bit_depth, &color_type, &interlace_type,
-       &compression_type, &filter_method);
+	png_read_update_info(png_ptr, info_ptr);
+	png_uint_32 rowbytes = png_get_rowbytes(png_ptr, info_ptr);
 
+	// allocate buffer to read image data into
 	png_bytep *row_pointers=new png_bytep[height];
-	row_pointers = png_get_rows(png_ptr, info_ptr);
+	png_byte *data = new png_byte[rowbytes*height];
+	for (png_uint_32 i = 0; i < height; i++)
+		row_pointers[i] = &(data[rowbytes*i]);
+
+	png_read_image(png_ptr, row_pointers);
+
 	int x;
 	int y;
 	surface_buffer.set_wh(width,height);
@@ -203,7 +224,6 @@ png_mptr::png_mptr(const char *file_name)
 	switch(color_type)
 	{
 	case PNG_COLOR_TYPE_RGB:
-		DEBUGPOINT();
 		for(y=0;y<surface_buffer.get_h();y++)
 			for(x=0;x<surface_buffer.get_w();x++)
 			{
@@ -228,7 +248,6 @@ png_mptr::png_mptr(const char *file_name)
 		break;
 
 	case PNG_COLOR_TYPE_RGB_ALPHA:
-		DEBUGPOINT();
 		for(y=0;y<surface_buffer.get_h();y++)
 			for(x=0;x<surface_buffer.get_w();x++)
 			{
@@ -305,24 +324,16 @@ png_mptr::png_mptr(const char *file_name)
 		return;
 	}
 
-	DEBUGPOINT();
-
-	// \fixme These shouldn't be uncommented, but for some
-	// reason, they crash the program. I will have to look into this
-	// later. This is a memory leak, but it shouldn't be too bad.
-
-	/*
 	png_read_end(png_ptr, end_info);
 	png_destroy_read_struct(&png_ptr, &info_ptr, &end_info);
 	fclose(file);
-	*/
 
 	delete [] row_pointers;
+	delete [] data;
 }
 
 png_mptr::~png_mptr()
 {
-	DEBUGPOINT();
 }
 
 bool
