@@ -2,7 +2,7 @@
 /*!	\file trgt_ppm.cpp
 **	\brief ppm Target Module
 **
-**	$Id: trgt_ppm.cpp 848 2007-10-06 02:25:36Z dooglus $
+**	$Id: trgt_ppm.cpp 972 2007-10-25 18:38:36Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -53,7 +53,7 @@ SYNFIG_TARGET_INIT(ppm);
 SYNFIG_TARGET_SET_NAME(ppm,"ppm");
 SYNFIG_TARGET_SET_EXT(ppm,"ppm");
 SYNFIG_TARGET_SET_VERSION(ppm,"0.1");
-SYNFIG_TARGET_SET_CVS_ID(ppm,"$Id: trgt_ppm.cpp 848 2007-10-06 02:25:36Z dooglus $");
+SYNFIG_TARGET_SET_CVS_ID(ppm,"$Id: trgt_ppm.cpp 972 2007-10-25 18:38:36Z dooglus $");
 
 /* === M E T H O D S ======================================================= */
 
@@ -103,18 +103,15 @@ ppm::start_frame(synfig::ProgressCallback *callback)
 	}
 	else if(multi_image)
 	{
-		String
-			newfilename(filename),
-			ext(find(filename.begin(),filename.end(),'.'),filename.end());
-		newfilename.erase(find(newfilename.begin(),newfilename.end(),'.'),newfilename.end());
-
-		newfilename+=etl::strprintf("%04d",imagecount)+ext;
-		file=SmartFILE(fopen(newfilename.c_str(),"wb"));
+		String newfilename(filename_sans_extension(filename) +
+						   etl::strprintf(".%04d",imagecount) +
+						   filename_extension(filename));
+		file=SmartFILE(fopen(newfilename.c_str(),POPEN_BINARY_WRITE_TYPE));
 		if(callback)callback->task(newfilename);
 	}
 	else
 	{
-		file=SmartFILE(fopen(filename.c_str(),"wb"));
+		file=SmartFILE(fopen(filename.c_str(),POPEN_BINARY_WRITE_TYPE));
 		if(callback)callback->task(filename);
 	}
 
