@@ -2,10 +2,11 @@
 /*!	\file trgt_yuv.cpp
 **	\brief Template File
 **
-**	$Id: trgt_yuv.cpp 631 2007-09-08 15:33:07Z dooglus $
+**	$Id: trgt_yuv.cpp 1642 2008-02-09 18:25:35Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -58,13 +59,13 @@ SYNFIG_TARGET_INIT(yuv);
 SYNFIG_TARGET_SET_NAME(yuv,"yuv420p");
 SYNFIG_TARGET_SET_EXT(yuv,"yuv");
 SYNFIG_TARGET_SET_VERSION(yuv,"0.1");
-SYNFIG_TARGET_SET_CVS_ID(yuv,"$Id: trgt_yuv.cpp 631 2007-09-08 15:33:07Z dooglus $");
+SYNFIG_TARGET_SET_CVS_ID(yuv,"$Id: trgt_yuv.cpp 1642 2008-02-09 18:25:35Z dooglus $");
 
 /* === M E T H O D S ======================================================= */
 
 yuv::yuv(const char *FILENAME):
 	filename(FILENAME),
-	file( (filename=="-")?stdout:fopen(filename.c_str(),"wb") ),
+	file( (filename=="-")?stdout:fopen(filename.c_str(),POPEN_BINARY_WRITE_TYPE) ),
 	dithering(true)
 {
 	// YUV420P doesn't have an alpha channel
@@ -75,6 +76,18 @@ yuv::~yuv()
 {
 }
 
+bool
+yuv::init()
+{
+	if (!file)
+		return false;
+
+	fprintf(file.get(), "YUV4MPEG2 W%d H%d F%d:1 Ip\n",
+			desc.get_w(), desc.get_h(),
+			round_to_int(desc.get_frame_rate()));
+	return true;
+}
+
 bool
 yuv::set_rend_desc(RendDesc *given_desc)
 {
@@ -95,6 +108,7 @@ yuv::set_rend_desc(RendDesc *given_desc)
 bool
 yuv::start_frame(synfig::ProgressCallback */*callback*/)
 {
+	fprintf(file.get(), "FRAME\n");
 	return static_cast<bool>(file);
 }
 
