@@ -2,7 +2,7 @@
 /*!	\file synfig/blur.cpp
 **	\brief Blur Implementation File
 **
-**	$Id: blur.cpp 857 2007-10-07 22:28:34Z dooglus $
+**	$Id: blur.cpp 1684 2008-02-13 01:57:55Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -56,7 +56,7 @@ using namespace synfig;
 /* === P R O C E D U R E S ================================================= */
 
 /* === M E T H O D S ======================================================= */
-Point Blur::operator ()(const Point &pos) const
+Point Blur::operator()(const Point &pos) const
 {
 	Point blurpos(pos);
 
@@ -114,7 +114,7 @@ Point Blur::operator ()(const Point &pos) const
 	return blurpos;
 }
 
-Point Blur::operator ()(synfig::Real x, synfig::Real y) const
+Point Blur::operator()(synfig::Real x, synfig::Real y) const
 {
 	return (*this)(Point(x,y));
 }
@@ -128,7 +128,7 @@ static inline T zero()
 }
 
 template <>
-static inline Color zero<Color>()
+inline Color zero<Color>()
 {
 	return Color::alpha();
 }
@@ -170,7 +170,7 @@ static void GuassianBlur_3x3(etl::surface<T,AT,VP> &surface)
 	T *SC0=new T[w+1];
 	T *SC1=new T[w+1];
 
-	// Setup the row bufers
+	// Setup the row buffers
 	for(x=0;x<w;x++)SC0[x]=surface[0][x]*4;
 //	memcpy(SC1,surface[0],w*sizeof(T));
 
@@ -218,7 +218,7 @@ inline static void GaussianBlur_5x5_(etl::surface<T,AT,VP> &surface,T *SC0,T *SC
 	w=surface.get_w();
 	h=surface.get_h();
 
-	// Setup the row bufers
+	// Setup the row buffers
 	for(x=0;x<w;x++)SC0[x+2]=surface[0][x]*24;
 //	memset(SC0,0,(w+2)*sizeof(T));
 	memset(SC1,0,(w+2)*sizeof(T));
@@ -449,9 +449,9 @@ static void GuassianBlur_1x3(etl::surface<T,AT,VP> &surface)
 }
 
 //THE GOOD ONE!!!!!!!!!
-bool Blur::operator ()(const Surface &surface,
-						const Vector &resolution,
-						Surface &out) const
+bool Blur::operator()(const Surface &surface,
+					  const Vector &resolution,
+					  Surface &out) const
 {
 	int w = surface.get_w(),
 		h = surface.get_h();
@@ -714,7 +714,7 @@ bool Blur::operator ()(const Surface &surface,
 			}*/
 
             /* Squaring the pw and ph values
-			   is necessary to insure consistant
+			   is necessary to insure consistent
 			   results when rendered to different
 			   resolutions.
 			   Unfortunately, this automatically
@@ -846,9 +846,9 @@ bool Blur::operator ()(const Surface &surface,
 	return true;
 }
 
-bool Blur::operator ()(const surface<float> &surface,
-						const Vector &resolution,
-						surface<float> &out) const
+bool Blur::operator()(const etl::surface<float> &surface,
+					  const synfig::Vector &resolution,
+					  etl::surface<float> &out) const
 {
 	int w = surface.get_w(),
 		h = surface.get_h();
@@ -1088,7 +1088,7 @@ bool Blur::operator ()(const surface<float> &surface,
 			}*/
 
             /* Squaring the pw and ph values
-			   is necessary to insure consistant
+			   is necessary to insure consistent
 			   results when rendered to different
 			   resolutions.
 			   Unfortunately, this automatically
