@@ -2,7 +2,7 @@
 /*!	\file synfig/blur.h
 **	\brief Blur Helper Header file
 **
-**	$Id: blur.h 335 2007-03-16 00:39:09Z dooglus $
+**	$Id: blur.h 1684 2008-02-13 01:57:55Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -35,7 +35,9 @@
 /* === T Y P E D E F S ===================================================== */
 
 /* === C L A S S E S & S T R U C T S ======================================= */
-class synfig::ProgressCallback;
+namespace synfig {
+	class ProgressCallback;
+}
 
 class Blur
 {
@@ -71,16 +73,16 @@ public:
 	Blur(synfig::Real sx, synfig::Real sy, int t, synfig::ProgressCallback *callb = 0): size(sx,sy), type(t), cb(callb) {}
 
 	//Parametric Blur
-	synfig::Point operator ()(const synfig::Point &p) const;
-	synfig::Point operator ()(synfig::Real x, synfig::Real y) const;
+	synfig::Point operator()(const synfig::Point &p) const;
+	synfig::Point operator()(synfig::Real x, synfig::Real y) const;
 
 	//Surface based blur
 	//	input surface can be the same as output surface,
 	//	though both have to be the same size
-	bool operator ()(const synfig::Surface &surface, const synfig::Vector &resolution, synfig::Surface &out) const;
+	bool operator()(const synfig::Surface &surface, const synfig::Vector &resolution, synfig::Surface &out) const;
 
-	bool operator ()(const etl::surface<float> &surface, const synfig::Vector &resolution, etl::surface<float> &out) const;
-	//bool operator ()(const etl::surface<unsigned char> &surface, const synfig::Vector &resolution, etl::surface<unsigned char> &out) const;
+	bool operator()(const etl::surface<float> &surface, const synfig::Vector &resolution, etl::surface<float> &out) const;
+	//bool operator()(const etl::surface<unsigned char> &surface, const synfig::Vector &resolution, etl::surface<unsigned char> &out) const;
 };
 
 /* === E N D =============================================================== */
