@@ -2,7 +2,7 @@
 /*!	\file curve_helper.cpp
 **	\brief Curve Helper File
 **
-**	$Id: curve_helper.cpp 465 2007-04-12 15:10:11Z dooglus $
+**	$Id: curve_helper.cpp 1202 2007-12-15 09:58:33Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -352,7 +352,7 @@ int intersect(const BezHull &bh, const Point &p, const Vector &v)
 {
 	float mint = 0, maxt = 1e20;
 
-	//polygon cliping
+	//polygon clipping
 	Vector n;
 	Vector::value_type	nv;
 
@@ -530,7 +530,7 @@ static int recurse_intersect(const CIntersect::SCurve &b, const Point &p1, int d
 
 		for(int i = 0; i < 3; ++i)
 		{
-			//intersect line segmentsssss
+			//intersect line segments
 
 			//solve for the y_value
 			Vector v = b.b[i+1] - b.b[i];
@@ -569,7 +569,7 @@ int intersect(const bezier<Point> &b, const Point &p)
 //Curve curve intersection
 void CIntersect::recurse_intersect(const SCurve &left, const SCurve &right, int depth)
 {
-	//reject curves that do not overlap with bouding boxes
+	//reject curves that do not overlap with bounding boxes
 	if(!intersect(left.aabb,right.aabb)) return;
 
 	//accept curves (and perform super detailed check for intersections)
@@ -590,7 +590,7 @@ void CIntersect::recurse_intersect(const SCurve &left, const SCurve &right, int
 		{
 			for(int j = 0; j < 3; ++j)
 			{
-				//intersect line segmentsssss
+				//intersect line segments
 				if(intersect_line_segments(left.b[i],left.b[i+1],t,right.b[j],right.b[j+1],s))
 				{
 					//We got one Jimmy
@@ -612,7 +612,7 @@ void CIntersect::recurse_intersect(const SCurve &left, const SCurve &right, int
 	left.Split(l1,r1);	//subdivide left
 	right.Split(l2,r2); //subdivide right
 
-	//Test each cantidate against eachother
+	//Test each candidate against each other
 	recurse_intersect(l1,l2);
 	recurse_intersect(l1,r2);
 	recurse_intersect(r1,l2);
@@ -621,11 +621,11 @@ void CIntersect::recurse_intersect(const SCurve &left, const SCurve &right, int
 
 
 
-bool CIntersect::operator()(const bezier<Point> &c1, const bezier<Point> &c2)
+bool CIntersect::operator()(const etl::bezier<Point> &c1, const etl::bezier<Point> &c2)
 {
 	times.clear();
 
-	//need to subdivide and check recursive bounding regions against eachother
+	//need to subdivide and check recursive bounding regions against each other
 	//so track a list of dirty curves and compare compare compare
 
 
