@@ -2,7 +2,7 @@
 /*!	\file general.h
 **	\brief General macros, classes, and procedure declarations
 **
-**	$Id: general.h 658 2007-09-12 20:36:47Z dooglus $
+**	$Id: general.h 1233 2007-12-27 04:50:43Z pabs $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -30,15 +30,21 @@
 #include <ETL/stringf>
 #include "string.h"
 #include "version.h"
-#include <locale.h>
+#ifdef ENABLE_NLS
+ #include <locale.h>
+ #include <libintl.h>
+#endif
 
 /* === M A C R O S ========================================================= */
 
-// Quick hack to keep stuff working until gettext support is added
-#ifndef _
-#define _(x)		(x)
-#define N_(x)		(x)
-//#define gettext(x)	(x)
+#ifdef ENABLE_NLS
+#define _(x) dgettext("synfig",x)
+#define gettext_noop(x) x
+#define N_(x) gettext_noop(x)
+#else
+#define dgettext(a,x) (x)
+#define _(x) (x)
+#define N_(x) (x)
 #endif
 
 #define SYNFIG_COPYRIGHT "Copyright (c) 2001-2005 Robert B. Quattlebaum Jr., Adrian Bentley"
@@ -119,19 +125,6 @@ public:
 	virtual bool valid() const { return cb != 0; }
 };
 
-/*! \class SoftwareExpired
-**	\brief This class is thrown when the software timeout has been reached.
-*/
-class SoftwareExpired
-{
-}; // END of class SoftwareExpired
-
-
-#ifdef DEATH_TIME
-inline void CHECK_EXPIRE_TIME() { if(time(0)>DEATH_TIME) throw SoftwareExpired(); }
-#else
-#define CHECK_EXPIRE_TIME() while(0){ }
-#endif
 
 /*
 extern bool add_to_module_search_path(const std:string &path);
