@@ -2,7 +2,7 @@
 /*!	\file gradient.cpp
 **	\brief Color Gradient Class Member Definitions
 **
-**	$Id: gradient.cpp 848 2007-10-06 02:25:36Z dooglus $
+**	$Id: gradient.cpp 1463 2008-01-25 12:29:39Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -320,7 +320,7 @@ synfig::Gradient::operator()(const Real &x,float supersample)const
 	const_iterator iter,next;
 
 	/*
-	//optimizize...
+	//optimize...
 	Real 	left = x-supersample/2, right = x+supersample/2;
 
 	if(left < front().pos) left = front().pos;
@@ -349,7 +349,7 @@ synfig::Gradient::operator()(const Real &x,float supersample)const
 		//return Color::blend(iterr->color,iterl->color,lambda,Color::BLEND_STRAIGHT);
 	}else
 	{
-		//itegration madness
+		//integration madness
 		const_iterator i = iterl, ie = iterr+1;
 		Real wlast = left;
 
@@ -405,7 +405,7 @@ synfig::Gradient::operator()(const Real &x,float supersample)const
 	//! using a binary search.
 	for(;iter<end();iter=next++)
 	{
-		if(next==end() || x>=iter->pos &&  x<next->pos && iter->pos!=next->pos)
+		if(next==end() || (x>=iter->pos && x<next->pos && iter->pos!=next->pos))
 		{
 			// If the supersample region falls square in between
 			// two CPoints, then we don't have to do anything special.
