@@ -2,7 +2,7 @@
 /*!	\file guid.h
 **	\brief Template Header
 **
-**	$Id: guid.h 335 2007-03-16 00:39:09Z dooglus $
+**	$Id: guid.h 1511 2008-01-27 12:16:51Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -60,7 +60,7 @@ public:
 		{ make_unique(); }
 	GUID(const GUID& x):data(x.data)
 		{ }
-	GUID(const int i){assert(!i); data.u_64.a=0;data.u_64.b=0;}
+	GUID(const int i __attribute__ ((unused))){assert(!i); data.u_64.a=0;data.u_64.b=0;}
 
 	GUID(const String& str);
 
