@@ -2,10 +2,11 @@
 /*!	\file guidset.h
 **	\brief Template Header
 **
-**	$Id: guidset.h 335 2007-03-16 00:39:09Z dooglus $
+**	$Id: guidset.h 1643 2008-02-09 19:12:18Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -25,8 +26,6 @@
 #ifndef __SYNFIG_GUIDSET_H
 #define __SYNFIG_GUIDSET_H
 
-#define HASH_SET_H <ext/hash_set>
-
 /* === H E A D E R S ======================================================= */
 
 #include "guid.h"
@@ -49,7 +48,7 @@ class GUIDSet : public
 #ifdef HASH_SET_H
 std::set<synfig::GUID>
 #else
-std::hash_set<synfig::GUID,synfig::GUIDHash>
+HASH_SET_CLASS<synfig::GUID,synfig::GUIDHash>
 #endif
 {
 }; // END of class GUIDSet
