@@ -2,10 +2,11 @@
 /*!	\file importer.cpp
 **	\brief writeme
 **
-**	$Id: importer.cpp 335 2007-03-16 00:39:09Z dooglus $
+**	$Id: importer.cpp 1642 2008-02-09 18:25:35Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -97,13 +98,14 @@ Importer::open(const String &filename)
 		return (*__open_importers)[filename];
 	}
 
-	if(find(filename.begin(),filename.end(),'.')==filename.end())
+	if(filename_extension(filename) == "")
 	{
 		synfig::error(_("Importer::open(): Couldn't find extension"));
 		return 0;
 	}
 
-	String ext=string(filename.begin()+filename.find_last_of('.')+1,filename.end());
+	String ext(filename_extension(filename));
+	if (ext.size()) ext = ext.substr(1); // skip initial '.'
 	std::transform(ext.begin(),ext.end(),ext.begin(),&::tolower);
 
 
