@@ -2,10 +2,11 @@
 /*!	\file layer.h
 **	\brief Layer Class Header
 **
-**	$Id: layer.h 578 2007-09-03 19:13:34Z dooglus $
+**	$Id: layer.h 1648 2008-02-10 09:13:54Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -41,46 +42,85 @@
 /* === M A C R O S ========================================================= */
 
 //! \writeme
-#define SYNFIG_LAYER_MODULE_EXT public: static const char name__[], version__[], cvs_id__[], local_name__[], category__[]; static Layer *create();
+#define SYNFIG_LAYER_MODULE_EXT															\
+	public:																				\
+	static const char name__[], version__[], cvs_id__[], local_name__[], category__[];	\
+	static Layer *create();
 
 //! Sets the name of the layer
-#define SYNFIG_LAYER_SET_NAME(class,x) const char class::name__[]=x
+#define SYNFIG_LAYER_SET_NAME(class,x)													\
+	const char class::name__[]=x
 
 //! Sets the local name of the layer
-#define SYNFIG_LAYER_SET_LOCAL_NAME(class,x) const char class::local_name__[]=x;
+#define SYNFIG_LAYER_SET_LOCAL_NAME(class,x)											\
+	const char class::local_name__[]=x;
 
 //! Sets the category of the layer
-#define SYNFIG_LAYER_SET_CATEGORY(class,x) const char class::category__[]=x
+#define SYNFIG_LAYER_SET_CATEGORY(class,x)												\
+	const char class::category__[]=x
 
 //! Sets the version string for the layer
-#define SYNFIG_LAYER_SET_VERSION(class,x) const char class::version__[]=x
+#define SYNFIG_LAYER_SET_VERSION(class,x)												\
+	const char class::version__[]=x
 
 //! Sets the CVS ID string for the layer
-#define SYNFIG_LAYER_SET_CVS_ID(class,x) const char class::cvs_id__[]=x
+#define SYNFIG_LAYER_SET_CVS_ID(class,x)												\
+	const char class::cvs_id__[]=x
 
 //! \writeme
-#define SYNFIG_LAYER_INIT(class) synfig::Layer* class::create() { return new class(); }
+#define SYNFIG_LAYER_INIT(class)														\
+	synfig::Layer* class::create()														\
+	{																					\
+		return new class();																\
+	}
 
 //! \writeme
-#define IMPORT_PLUS(x,y) if(param==#x && value.same_type_as(x)) { value.put(&x);{y;}return true;}
+#define IMPORT_PLUS(x,y)																\
+	if (param==#x && value.same_type_as(x))												\
+	{																					\
+		value.put(&x);																	\
+		{																				\
+			y;																			\
+		}																				\
+		return true;																	\
+	}
 
 //! \writeme
-#define IMPORT_AS(x,y) if(param==y && value.same_type_as(x)) { value.put(&x); return true;}
+#define IMPORT_AS(x,y)																	\
+	if (param==y && value.same_type_as(x))												\
+	{																					\
+		value.put(&x);																	\
+		return true;																	\
+	}
 
 //! \writeme
-#define IMPORT(x) IMPORT_AS(x,#x)
+#define IMPORT(x)																		\
+	IMPORT_AS(x,#x)
 
 //! \writeme
-#define EXPORT_AS(x,y) if(param==y) { return ValueBase(x); }
+#define EXPORT_AS(x,y)																	\
+	if (param==y)																		\
+		return ValueBase(x);
 
 //! \writeme
-#define EXPORT(x)					EXPORT_AS(x,#x)
+#define EXPORT(x)																		\
+	EXPORT_AS(x,#x)
 
 //! \writeme
-#define EXPORT_NAME()	if(param=="Name" || param=="name" || param=="name__") { return name__; } if(param=="local_name__") { return local_name__; }
+#define EXPORT_NAME()																	\
+	if (param=="Name" || param=="name" || param=="name__")								\
+		return name__;																	\
+	else if (param=="local_name__")														\
+		return dgettext("synfig",local_name__);
 
 //! \writeme
-#define EXPORT_VERSION()	if(param=="Version" || param=="version" || param=="version__") { return version__; }
+#define EXPORT_VERSION()																\
+	if (param=="Version" || param=="version" || param=="version__")						\
+		return version__;
+
+//! This is used as the category for layer book entries which represent aliases of layers.
+//! It prevents these layers showing up in the menu.
+#define CATEGORY_DO_NOT_USE "Do Not Use"
 
 /* === T Y P E D E F S ===================================================== */
 
@@ -134,8 +174,18 @@ public:
 		String cvs_id;
 		String version;
 		BookEntry() { }
-		BookEntry(Factory factory, const String& name,const String& local_name,const String& category,const String& cvs_id,const String& version):
-			factory(factory),name(name),local_name(local_name),category(category),cvs_id(cvs_id),version(version) { }
+		BookEntry(Factory		 factory,
+				  const String	&name,
+				  const String	&local_name,
+				  const String	&category,
+				  const String	&cvs_id,
+				  const String	&version):
+			factory(factory),
+			name(name),
+			local_name(local_name),
+			category(category),
+			cvs_id(cvs_id),
+			version(version) { }
 	};
 
 	typedef std::map<String,BookEntry> Book;
@@ -318,6 +368,12 @@ public:
 	//! \writeme
 	void set_description(const String& x);
 
+	//! Returns the layer's description if it's not empty, else its local name
+	const String get_non_empty_description()const { return get_description().empty() ? get_local_name() : get_description(); }
+
+	//! Returns the localised version of the given layer parameter
+	const String get_param_local_name(const String &param_name)const;
+
 	/*
  --	** -- V I R T U A L   F U N C T I O N S -----------------------------------
 	*/
@@ -333,7 +389,7 @@ public:
 	//! Returns a string containing the localized name of the Layer
 	virtual String get_local_name()const;
 
-	//! Gets the paramater vocabulary
+	//! Gets the parameter vocabulary
 	virtual Vocab get_param_vocab()const;
 
 	//! Gets the version string for this layer
@@ -376,14 +432,14 @@ public:
 	virtual ParamList get_param_list()const;
 
 	//! Sets the \a time for the selected Layer and those under it
-	/*!	\param context		Context iterator refering to next Layer.
+	/*!	\param context		Context iterator referring to next Layer.
 	**	\param time			writeme
 	**	\see Handle::set_time()
 	*/
 	virtual void set_time(Context context, Time time)const;
 
 	//! Sets the \a time for the selected Layer and those under it for a specific \a point
-	/*!	\param context		Context iterator refering to next Layer.
+	/*!	\param context		Context iterator referring to next Layer.
 	**	\param time			writeme
 	**	\param point		writeme
 	**	\see Handle::set_time()
@@ -391,14 +447,14 @@ public:
 	virtual void set_time(Context context, Time time, const Point &point)const;
 
 	//! Gets the color of the Canvas at \a pos
-	/*!	\param context		Context iterator refering to next Layer.
+	/*!	\param context		Context iterator referring to next Layer.
 	**	\param pos		Point which indicates where the Color should come from
 	**	\see Handle::get_color()
 	*/
 	virtual Color get_color(Context context, const Point &pos)const;
 
 	//! Renders the Canvas to the given Surface in an accelerated manner
-	/*!	\param context		Context iterator refering to next Layer.
+	/*!	\param context		Context iterator referring to next Layer.
 	**	\param surface		Pointer to Surface to render to.
 	**	\param quality		The requested quality-level to render at.
 	**	\param renddesc		The associated RendDesc.
@@ -409,7 +465,7 @@ public:
 	virtual bool accelerated_render(Context context,Surface *surface,int quality, const RendDesc &renddesc, ProgressCallback *cb)const;
 
 	//! Checks to see if a part of the layer is directly under \a point
-	/*!	\param context		Context iterator refering to next Layer.
+	/*!	\param context		Context iterator referring to next Layer.
 	**	\param point		The point to check
 	**	\return 	The handle of the layer under \a point. If there is not
 	**				a layer under \a point, then returns an empty handle. */
@@ -418,8 +474,18 @@ public:
 	//! Duplicates the Layer
 	virtual Handle clone(const GUID& deriv_guid=GUID())const;
 
+	//! Returns true if the layer needs to be able to examine its context.
+	/*! context to render itself, other than for simple blending.  For
+	**  example, the blur layer will return true - it can't do its job
+	**  if it can't see its context, and the circle layer will return
+	**  false - rendering a circle doesn't depend on the underlying
+	**  context until the final blend operation. */
+	virtual bool reads_context()const;
+
+#ifdef THIS_CODE_IS_NOT_USED
 	//! Duplicates the Layer without duplicating the value nodes
 	virtual Layer *simple_clone()const;
+#endif /* THIS_CODE_IS_NOT_USED */
 
 protected:
 
