@@ -2,7 +2,7 @@
 /*!	\file layer_bitmap.h
 **	\brief Template Header
 **
-**	$Id: layer_bitmap.h,v 1.2 2005/01/24 03:08:18 darco Exp $
+**	$Id: layer_bitmap.h 335 2007-03-16 00:39:09Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -45,28 +45,28 @@ class Layer_Bitmap : public Layer_Composite, public Layer_NoDeform
 {
 	const Color& filter(const Color& c)const;
 public:
-	typedef etl::handle<Layer_Bitmap> Handle;	
+	typedef etl::handle<Layer_Bitmap> Handle;
 
 	Point tl;
 	Point br;
 	int c;
 	mutable Surface surface;
-	
+
 	Real gamma_adjust;
-	
+
 	Layer_Bitmap();
-	
+
 	virtual bool set_param(const String & param, ValueBase value);
 
 	virtual ValueBase get_param(const String & param)const;
 
 	virtual Color get_color(Context context, const Point &pos)const;
-	
+
 	virtual Vocab get_param_vocab()const;
 
 	virtual Rect get_bounding_rect()const;
 
-	virtual bool accelerated_render(Context context,Surface *surface,int quality, const RendDesc &rend_desc, ProgressCallback *callback)const;
+	virtual bool accelerated_render(Context context,Surface *surface,int quality, const RendDesc &renddesc, ProgressCallback *cb)const;
 
 	virtual synfig::Layer::Handle hit_check(synfig::Context context, const synfig::Point &point)const;
 }; // END of class Layer_Bitmap
