@@ -2,11 +2,11 @@
 /*!	\file layer_composite.h
 **	\brief Composite Layer Class Implementation
 **
-**	$Id: layer_composite.h 848 2007-10-06 02:25:36Z dooglus $
+**	$Id: layer_composite.h 1643 2008-02-09 19:12:18Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
-**	Copyright (c) 2007 Chris Moore
+**	Copyright (c) 2007, 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -43,7 +43,7 @@ class Layer_NoDeform {};
 
 
 /*!	\class Layer_Composite
-**	\brief Base class for layers that put stuff ontop of lower layers
+**	\brief Base class for layers that put stuff on top of lower layers
 */
 class Layer_Composite : public Layer
 {
@@ -60,9 +60,14 @@ protected:
 		Color::BlendMethod 	blend_method=Color::BLEND_COMPOSITE
 	):
 		amount_				(amount),
-		blend_method_		(blend_method)
+		blend_method_		(blend_method),
+		converted_blend_	(false),
+		transparent_color_	(false)
 	{ }
 
+	bool converted_blend_;
+	bool transparent_color_;
+
 public:
 
 	float get_amount()const { return amount_; }
