@@ -1,8 +1,8 @@
 /* === S Y N F I G ========================================================= */
 /*!	\file layer_polygon.cpp
-**	\brief Template Header
+**	\brief Implementation of the "Polygon" layer
 **
-**	$Id: layer_polygon.cpp 578 2007-09-03 19:13:34Z dooglus $
+**	$Id: layer_polygon.cpp 1202 2007-12-15 09:58:33Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -56,10 +56,10 @@ using namespace etl;
 
 SYNFIG_LAYER_INIT(Layer_Polygon);
 SYNFIG_LAYER_SET_NAME(Layer_Polygon,"polygon");
-SYNFIG_LAYER_SET_LOCAL_NAME(Layer_Polygon,_("Polygon"));
-SYNFIG_LAYER_SET_CATEGORY(Layer_Polygon,_("Geometry"));
+SYNFIG_LAYER_SET_LOCAL_NAME(Layer_Polygon,N_("Polygon"));
+SYNFIG_LAYER_SET_CATEGORY(Layer_Polygon,N_("Geometry"));
 SYNFIG_LAYER_SET_VERSION(Layer_Polygon,"0.1");
-SYNFIG_LAYER_SET_CVS_ID(Layer_Polygon,"$Id: layer_polygon.cpp 578 2007-09-03 19:13:34Z dooglus $");
+SYNFIG_LAYER_SET_CVS_ID(Layer_Polygon,"$Id: layer_polygon.cpp 1202 2007-12-15 09:58:33Z dooglus $");
 
 /* === C L A S S E S ======================================================= */
 
@@ -106,7 +106,7 @@ Layer_Polygon::sync()
 }
 
 void
-Layer_Polygon::add_polygon(const vector<Point> &point_list)
+Layer_Polygon::add_polygon(const std::vector<Point> &point_list)
 {
 	int i,pointcount=point_list.size();
 
