@@ -2,10 +2,11 @@
 /*!	\file listimporter.cpp
 **	\brief Template File
 **
-**	$Id: listimporter.cpp 658 2007-09-12 20:36:47Z dooglus $
+**	$Id: listimporter.cpp 1643 2008-02-09 19:12:18Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007, 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -64,6 +65,62 @@ ListImporter::ListImporter(const String &filename)
 	}
 	String line;
 	String prefix=etl::dirname(filename)+ETL_DIRECTORY_SEPARATOR;
+	getline(stream,line);		// read first line and check whether it is a Papagayo lip sync file
+
+	if (line == "MohoSwitch1")	// it is a Papagayo lipsync file
+	{
+		String phoneme, prevphoneme, prevext, ext(".jpg"); // default image format
+		int frame, prevframe = -1; // it means that the previous phoneme is not known
+
+		while(!stream.eof())
+		{
+			getline(stream,line);
+
+			if(line.find(String("FPS ")) == 0)
+			{
+				float f = atof(String(line.begin()+4,line.end()).c_str());
+				if (f) fps = f;
+				continue;
+			}
+
+			if (line == "bmp"  ||
+				line == "gif"  ||
+				line == "jpg"  ||
+				line == "png"  ||
+				line == "ppm"  ||
+				line == "tiff" )
+			{
+				ext = String(".") + line;
+				continue;
+			}
+
+			size_t pos = line.find(String(" ")); // find space position. The format is "frame phoneme-name".
+			if(pos != String::npos)
+			{
+				frame = atoi(String(line.begin(),line.begin()+pos).c_str());
+				phoneme = String(line.begin()+pos+1, line.end());
+
+				if (prevframe != -1)
+					while (prevframe < frame)
+					{
+						filename_list.push_back(prefix + prevphoneme + prevext);
+						synfig::info("frame %d, phoneme = %s, path = '%s'", prevframe, prevphoneme.c_str(), (prefix + prevphoneme + prevext).c_str());
+						prevframe++;
+					}
+
+				prevext = ext;
+				prevframe = frame;
+				prevphoneme = phoneme;
+			}
+		}
+
+		filename_list.push_back(prefix + prevphoneme + prevext);	// do it one more time for the last phoneme
+		synfig::info("finally, frame %d, phoneme = %s, path = '%s'", prevframe, prevphoneme.c_str(), (prefix + prevphoneme + prevext).c_str());
+
+		return;
+	}
+
+	stream.seekg(ios_base::beg);
 	while(!stream.eof())
 	{
 		getline(stream,line);
@@ -95,9 +152,7 @@ ListImporter::~ListImporter()
 bool
 ListImporter::get_frame(Surface &surface,Time time, ProgressCallback *cb)
 {
-//			DEBUGPOINT();
-	int frame=static_cast<int>(time*fps);
-//			DEBUGPOINT();
+	int frame=round_to_int(time*fps);
 
 	if(!filename_list.size())
 	{
@@ -106,18 +161,15 @@ ListImporter::get_frame(Surface &surface,Time time, ProgressCallback *cb)
 		return false;
 	}
 
-//			DEBUGPOINT();
 	if(frame<0)frame=0;
 	if(frame>=(signed)filename_list.size())frame=filename_list.size()-1;
 
-//			DEBUGPOINT();
 	// See if that frame is cached
-	std::list<std::pair<int,Surface> >::iterator iter;
+	std::list<std::pair<String,Surface> >::iterator iter;
 	for(iter=frame_cache.begin();iter!=frame_cache.end();++iter)
 	{
-		if(iter->first==frame)
+		if(iter->first==filename_list[frame])
 		{
-//			DEBUGPOINT();
 			surface.mirror(iter->second);
 			return static_cast<bool>(surface);
 		}
@@ -125,8 +177,6 @@ ListImporter::get_frame(Surface &surface,Time time, ProgressCallback *cb)
 
 	Importer::Handle importer(Importer::open(filename_list[frame]));
 
-//	DEBUGPOINT();
-
 	if(!importer)
 	{
 		if(cb)cb->error(_("Unable to open ")+filename_list[frame]);
@@ -134,8 +184,6 @@ ListImporter::get_frame(Surface &surface,Time time, ProgressCallback *cb)
 		return false;
 	}
 
-//	DEBUGPOINT();
-
 	if(!importer->get_frame(surface,0,cb))
 	{
 		if(cb)cb->error(_("Unable to get frame from ")+filename_list[frame]);
@@ -143,21 +191,13 @@ ListImporter::get_frame(Surface &surface,Time time, ProgressCallback *cb)
 		return false;
 	}
 
-//	DEBUGPOINT();
-
 	if(frame_cache.size()>=LIST_IMPORTER_CACHE_SIZE)
 		frame_cache.pop_front();
 
-//	DEBUGPOINT();
-
-	frame_cache.push_back(std::pair<int,Surface>(frame,surface));
-
-//	DEBUGPOINT();
+	frame_cache.push_back(std::pair<String,Surface>(filename_list[frame],surface));
 
 	surface.mirror(frame_cache.back().second);
 
-//	DEBUGPOINT();
-
 	return static_cast<bool>(surface);
 }
 
