@@ -2,10 +2,11 @@
 /*!	\file listimporter.h
 **	\brief Template Header
 **
-**	$Id: listimporter.h 335 2007-03-16 00:39:09Z dooglus $
+**	$Id: listimporter.h 1642 2008-02-09 18:25:35Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -50,7 +51,7 @@ class ListImporter : public Importer
 {
 	float fps;
 	std::vector<String> filename_list;
-	std::list<std::pair<int,Surface> > frame_cache;
+	std::list<std::pair<String,Surface> > frame_cache;
 protected:
 	ListImporter(const String &filename);
 
