@@ -2,7 +2,7 @@
 /*!	\file paramdesc.h
 **	\brief ParamDesc Class Implementation
 **
-**	$Id: paramdesc.h 335 2007-03-16 00:39:09Z dooglus $
+**	$Id: paramdesc.h 1697 2008-02-15 13:55:34Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -156,7 +156,6 @@ public:
    	/*! This value determines how the value is to be presented
    	**	to the user when editing visually. */
    	ParamDesc &set_scalar(const Real &n) { scalar_=n; return *this; }
-   	ParamDesc &set_scalar(const String &h) { hint_=h; return *this; }
 
    	//!	Marks the parameter as not necessary for saving or copying
    	ParamDesc &not_critical() { critical_=false; return *this; }
@@ -186,7 +185,7 @@ public:
    	//! Returns the localized description of the parameter
    	const String &get_description()const { return desc_; }
 
-   	//! Returns the paramater's group
+   	//! Returns the parameter's group
    	const String &get_group()const { return group_; }
 
    	//! Returns a "hint" about the parameter, regarding how it is to be displayed to the user
