@@ -2,7 +2,7 @@
 /*!	\file synfig/renddesc.cpp
 **	\brief RendDesc
 **
-**	$Id: renddesc.cpp 335 2007-03-16 00:39:09Z dooglus $
+**	$Id: renddesc.cpp 1202 2007-12-15 09:58:33Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -396,7 +396,7 @@ const int &
 RendDesc::get_antialias()const
 { return a; }
 
-//! Set the antilaias amount
+//! Set the antialias amount
 RendDesc &
 RendDesc::set_antialias(const int &x)
 { a=x; return *this; }
@@ -525,7 +525,7 @@ RendDesc::set_viewport(const Point &__tl, const Point &__br)
 { tl_=__tl; br_=__br; return *this; }
 
 RendDesc &
-RendDesc::set_viewport(Real a,Real b,Real c,Real d)
+RendDesc::set_viewport(Vector::value_type a, Vector::value_type b, Vector::value_type c, Vector::value_type d)
 { tl_=Point(a,b); br_=Point(c,d); return *this; }
 
 Real
