@@ -2,10 +2,11 @@
 /*!	\file synfig/renddesc.h
 **	\brief Template Header
 **
-**	$Id: renddesc.h 335 2007-03-16 00:39:09Z dooglus $
+**	$Id: renddesc.h 1643 2008-02-09 19:12:18Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -241,7 +242,7 @@ public:
 	//! Return the antialias amount
 	const int &get_antialias()const;
 
-	//! Set the antilaias amount
+	//! Set the antialias amount
 	RendDesc &set_antialias(const int &x);
 
 	//! Return the distance from the bottom-right to the top-left
@@ -278,7 +279,7 @@ public:
 	//! Returns the height of one pixel
 	Real get_ph()const;
 
-	//! Sets viewport to represent the screen at the give pixel coordinates
+	//! Sets viewport to represent the screen at the given pixel coordinates
 	RendDesc &set_subwindow(int x, int y, int w, int h);
 };	// END of class RendDesc
 
@@ -303,14 +304,15 @@ inline RendDesc::Lock operator~(RendDesc::Lock rhs)
 	return static_cast<RendDesc::Lock>(~(int)rhs);
 }
 
+//! \todo This code isn't used - so how are flags checked?  Using the FLAGS macro from color.h?
 //! This operator is for checking RendDesc::Lock flags.
 /*! Don't think of it as "less then or equal to", but think of it
 **	like an arrow. Is \a rhs inside of \a lhs ?
 **	\see RendDesc::Lock, RendDesc */
-inline bool operator<=(RendDesc::Lock lhs, RendDesc::Lock rhs)
-{
-	return static_cast<int>(lhs) & static_cast<int>(rhs)==static_cast<int>(rhs);
-}
+// inline bool operator<=(RendDesc::Lock lhs, RendDesc::Lock rhs)
+// {
+// 	return (static_cast<int>(lhs) & static_cast<int>(rhs)) == static_cast<int>(rhs);
+// }
 
 
 }; /* end namespace synfig */
