@@ -2,11 +2,11 @@
 /*!	\file savecanvas.cpp
 **	\brief Writeme
 **
-**	$Id: savecanvas.cpp 848 2007-10-06 02:25:36Z dooglus $
+**	$Id: savecanvas.cpp 1812 2008-02-24 20:50:18Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
-**	Copyright (c) 2007 Chris Moore
+**	Copyright (c) 2007, 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -79,6 +79,9 @@ using namespace synfig;
 
 /* === G L O B A L S ======================================================= */
 
+ReleaseVersion save_canvas_version = ReleaseVersion(RELEASE_VERSION_END-1);
+int valuenode_too_new_count;
+
 /* === P R O C E D U R E S ================================================= */
 
 xmlpp::Element* encode_canvas(xmlpp::Element* root,Canvas::ConstHandle canvas);
@@ -248,7 +251,7 @@ xmlpp::Element* encode_value(xmlpp::Element* root,const ValueBase &data,Canvas::
 		root->set_name("nil");
 		return root;
 	default:
-		synfig::error(strprintf("Unknown value(%s), cannot create XML representation!",ValueBase::type_name(data.get_type()).c_str()));
+		synfig::error(strprintf(_("Unknown value(%s), cannot create XML representation!"),ValueBase::type_local_name(data.get_type()).c_str()));
 		root->set_name("nil");
 		return root;
 	}
@@ -292,9 +295,7 @@ xmlpp::Element* encode_animated(xmlpp::Element* root,ValueNode_Animated::ConstHa
 			waypoint_node->set_attribute("before","halt");
 			break;
 		case INTERPOLATION_LINEAR:
-			// This is the default value for angles, so don't add a new attribute for them
-			if (value_node->get_type() != ValueBase::TYPE_ANGLE)
-				waypoint_node->set_attribute("before","linear");
+			waypoint_node->set_attribute("before","linear");
 			break;
 		case INTERPOLATION_MANUAL:
 			waypoint_node->set_attribute("before","manual");
@@ -303,9 +304,7 @@ xmlpp::Element* encode_animated(xmlpp::Element* root,ValueNode_Animated::ConstHa
 			waypoint_node->set_attribute("before","constant");
 			break;
 		case INTERPOLATION_TCB:
-			// This is the default value, so don't add a new attribute (unless it's an angle - they default to linear)
-			if (value_node->get_type() == ValueBase::TYPE_ANGLE)
-				waypoint_node->set_attribute("before","auto");
+			waypoint_node->set_attribute("before","auto");
 			break;
 		default:
 			error("Unknown waypoint type for \"before\" attribute");
@@ -317,9 +316,7 @@ xmlpp::Element* encode_animated(xmlpp::Element* root,ValueNode_Animated::ConstHa
 			waypoint_node->set_attribute("after","halt");
 			break;
 		case INTERPOLATION_LINEAR:
-			// This is the default value for angles, so don't add a new attribute for them
-			if (value_node->get_type() != ValueBase::TYPE_ANGLE)
-				waypoint_node->set_attribute("after","linear");
+			waypoint_node->set_attribute("after","linear");
 			break;
 		case INTERPOLATION_MANUAL:
 			waypoint_node->set_attribute("after","manual");
@@ -328,9 +325,7 @@ xmlpp::Element* encode_animated(xmlpp::Element* root,ValueNode_Animated::ConstHa
 			waypoint_node->set_attribute("after","constant");
 			break;
 		case INTERPOLATION_TCB:
-			// This is the default value, so don't add a new attribute (unless it's an angle - they default to linear)
-			if (value_node->get_type() == ValueBase::TYPE_ANGLE)
-				waypoint_node->set_attribute("after","auto");
+			waypoint_node->set_attribute("after","auto");
 			break;
 		default:
 			error("Unknown waypoint type for \"after\" attribute");
@@ -350,27 +345,6 @@ xmlpp::Element* encode_animated(xmlpp::Element* root,ValueNode_Animated::ConstHa
 	return root;
 }
 
-xmlpp::Element* encode_composite(xmlpp::Element* root,ValueNode_Composite::ConstHandle value_node,Canvas::ConstHandle canvas=0)
-{
-	assert(value_node);
-	root->set_name("composite");
-
-	root->set_attribute("type",ValueBase::type_name(value_node->get_type()));
-
-	int i;
-	for(i=0;i<value_node->link_count();i++)
-	{
-		string name(strprintf("c%d",i+1));
-		assert(value_node->get_link(i));
-		if(value_node->get_link(i)->is_exported())
-			root->set_attribute(name,value_node->get_link(i)->get_relative_id(canvas));
-		else
-			encode_value_node(root->add_child(name)->add_child("value_node"),value_node->get_link(i).constant(),canvas);
-	}
-
-	return root;
-}
-
 xmlpp::Element* encode_subtract(xmlpp::Element* root,ValueNode_Subtract::ConstHandle value_node,Canvas::ConstHandle canvas=0)
 {
 	assert(value_node);
@@ -499,7 +473,26 @@ xmlpp::Element* encode_dynamic_list(xmlpp::Element* root,ValueNode_DynamicList::
 xmlpp::Element* encode_linkable_value_node(xmlpp::Element* root,LinkableValueNode::ConstHandle value_node,Canvas::ConstHandle canvas=0)
 {
 	assert(value_node);
-	root->set_name(value_node->get_name());
+
+	String name(value_node->get_name());
+	ReleaseVersion saving_version(get_file_version());
+	ReleaseVersion feature_version(LinkableValueNode::book()[name].release_version);
+
+	if (saving_version < feature_version)
+	{
+		valuenode_too_new_count++;
+		warning("can't save <%s> valuenodes in this old file format version", name.c_str());
+
+		ValueBase value((*value_node)(0));
+		encode_value(root,value,canvas);
+
+		// ValueNode_Const::ConstHandle const_value(ValueNode_Const::create((*value_node)(0)));
+		// encode_value_node(root,const_value,canvas);
+
+		return root;
+	}
+
+	root->set_name(name);
 
 	root->set_attribute("type",ValueBase::type_name(value_node->get_type()));
 
@@ -525,9 +518,6 @@ xmlpp::Element* encode_value_node(xmlpp::Element* root,ValueNode::ConstHandle va
 	if(ValueNode_Animated::ConstHandle::cast_dynamic(value_node))
 		encode_animated(root,ValueNode_Animated::ConstHandle::cast_dynamic(value_node),canvas);
 	else
-	if(ValueNode_Composite::ConstHandle::cast_dynamic(value_node))
-		encode_composite(root,ValueNode_Composite::ConstHandle::cast_dynamic(value_node),canvas);
-	else
 	if(ValueNode_Subtract::ConstHandle::cast_dynamic(value_node))
 		encode_subtract(root,ValueNode_Subtract::ConstHandle::cast_dynamic(value_node),canvas);
 	else
@@ -644,7 +634,7 @@ xmlpp::Element* encode_canvas(xmlpp::Element* root,Canvas::ConstHandle canvas)
 	root->set_name("canvas");
 
 	if(canvas->is_root())
-		root->set_attribute("version","0.1");
+		root->set_attribute("version",canvas->get_version());
 
 	if(!canvas->get_id().empty() && !canvas->is_root() && !canvas->is_inline())
 		root->set_attribute("id",canvas->get_id());
@@ -713,7 +703,8 @@ xmlpp::Element* encode_canvas(xmlpp::Element* root,Canvas::ConstHandle canvas)
 	}
 
 	// Output the <defs> section
-	if(!canvas->is_inline() && !canvas->value_node_list().empty() || !canvas->children().empty())
+	//! \todo check where the parentheses should really go - around the && or the ||?
+	if((!canvas->is_inline() && !canvas->value_node_list().empty()) || !canvas->children().empty())
 	{
 		xmlpp::Element *node=root->add_child("defs");
 		const ValueNodeList &value_node_list(canvas->value_node_list());
@@ -745,6 +736,18 @@ xmlpp::Element* encode_canvas(xmlpp::Element* root,Canvas::ConstHandle canvas)
 	return root;
 }
 
+xmlpp::Element* encode_canvas_toplevel(xmlpp::Element* root,Canvas::ConstHandle canvas)
+{
+	valuenode_too_new_count = 0;
+
+	xmlpp::Element* ret = encode_canvas(root, canvas);
+
+	if (valuenode_too_new_count)
+		warning("saved %d valuenodes as constant values in old file format\n", valuenode_too_new_count);
+
+	return ret;
+}
+
 bool
 synfig::save_canvas(const String &filename, Canvas::ConstHandle canvas)
 {
@@ -752,7 +755,7 @@ synfig::save_canvas(const String &filename, Canvas::ConstHandle canvas)
 
 	synfig::String tmp_filename(filename+".TMP");
 
-	if (String(filename.begin() + filename.find_last_of('.')+1, filename.end()) == "sifz")
+	if (filename_extension(filename) == ".sifz")
 		xmlSetCompressMode(9);
 	else
 		xmlSetCompressMode(0);
@@ -762,32 +765,31 @@ synfig::save_canvas(const String &filename, Canvas::ConstHandle canvas)
 		assert(canvas);
 		xmlpp::Document document;
 
-		encode_canvas(document.create_root_node("canvas"),canvas);
+		encode_canvas_toplevel(document.create_root_node("canvas"),canvas);
 
 		document.write_to_file_formatted(tmp_filename);
-	}
-	catch(...) { synfig::error("synfig::save_canvas(): Caught unknown exception"); return false; }
-
 
 #ifdef _WIN32
-	// On Win32 platforms, rename() has bad behavior. work around it.
-	char old_file[80]="sif.XXXXXXXX";
-	mktemp(old_file);
-	rename(filename.c_str(),old_file);
-	if(rename(tmp_filename.c_str(),filename.c_str())!=0)
-	{
-		rename(old_file,tmp_filename.c_str());
-		synfig::error("synfig::save_canvas(): Unable to rename file to correct filename, errno=%d",errno);
-		return false;
-	}
-	remove(old_file);
+		// On Win32 platforms, rename() has bad behavior. work around it.
+		char old_file[80]="sif.XXXXXXXX";
+		mktemp(old_file);
+		rename(filename.c_str(),old_file);
+		if(rename(tmp_filename.c_str(),filename.c_str())!=0)
+		{
+			rename(old_file,tmp_filename.c_str());
+			synfig::error("synfig::save_canvas(): Unable to rename file to correct filename, errno=%d",errno);
+			return false;
+		}
+		remove(old_file);
 #else
-	if(rename(tmp_filename.c_str(),filename.c_str())!=0)
-	{
-		synfig::error("synfig::save_canvas(): Unable to rename file to correct filename, errno=%d",errno);
-		return false;
-	}
+		if(rename(tmp_filename.c_str(),filename.c_str())!=0)
+		{
+			synfig::error("synfig::save_canvas(): Unable to rename file to correct filename, errno=%d",errno);
+			return false;
+		}
 #endif
+	}
+	catch(...) { synfig::error("synfig::save_canvas(): Caught unknown exception"); return false; }
 
 	return true;
 }
@@ -800,7 +802,19 @@ synfig::canvas_to_string(Canvas::ConstHandle canvas)
 
 	xmlpp::Document document;
 
-	encode_canvas(document.create_root_node("canvas"),canvas);
+	encode_canvas_toplevel(document.create_root_node("canvas"),canvas);
 
 	return document.write_to_string_formatted();
 }
+
+void
+synfig::set_file_version(ReleaseVersion version)
+{
+	save_canvas_version = version;
+}
+
+ReleaseVersion
+synfig::get_file_version()
+{
+	return save_canvas_version;
+}
