@@ -2,7 +2,7 @@
 /*!	\file synfig.h
 **	\brief Primary Header for Synfig
 **
-**	$Id: synfig.h 335 2007-03-16 00:39:09Z dooglus $
+**	$Id: synfig.h 1217 2007-12-19 03:06:20Z pabs $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -33,13 +33,15 @@
 
 /* === M A C R O S ========================================================= */
 
+#define SYNFIG_LEAN
+#undef SYNFIG_LEAN
 /*! \def SYNFIG_LEAN
 **	\brief Define this to remove unused features, speeding up compile time.
 **
 **	Define SYNFIG_LEAN if your plug-in
 **	or program doesn't use the synfig::Angle class
 **	or the rendering subsystem. This can speed up
-**	compiles. You may also wish to individualy
+**	compiles. You may also wish to individually
 **	use the macros SYNFIG_NO_ANGLE and
 **	SYNFIG_NO_RENDER.
 **	\see SYNFIG_NO_ANGLE, SYNFIG_NO_RENDER
@@ -72,7 +74,7 @@
 */
 #ifdef SYNFIG_TARGET
 # ifdef SYNFIG_NO_RENDER
-#  error You defined SYNFIG_TARGET, but also SYNFIG_NO_RENDER. This doesnt make sense.
+#  error You defined SYNFIG_TARGET, but also SYNFIG_NO_RENDER. This does not make sense.
 # endif
 # ifndef SYNFIG_NO_ANGLE
 #  define SYNFIG_NO_ANGLE
