@@ -2,10 +2,11 @@
 /*!	\file target.h
 **	\brief Target Class Implementation
 **
-**	$Id: target.h 465 2007-04-12 15:10:11Z dooglus $
+**	$Id: target.h 1642 2008-02-09 18:25:35Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -27,6 +28,7 @@
 
 /* === H E A D E R S ======================================================= */
 
+#include <sigc++/signal.h>
 #include "string_decl.h"
 #include <utility>
 //#include <list>
@@ -79,6 +81,27 @@ public:
 	typedef etl::loose_handle<Target> LooseHandle;
 	typedef etl::handle<const Target> ConstHandle;
 
+	/*
+ -- ** -- S I G N A L S -------------------------------------------------------
+	*/
+
+private:
+
+	sigc::signal<void> signal_progress_;
+
+	/*
+ -- ** -- S I G N A L   I N T E R F A C E -------------------------------------
+	*/
+
+public:
+
+	sigc::signal<void>& signal_progress() { return signal_progress_; }
+
+	/*
+ --	** -- C O N S T R U C T O R S ---------------------------------------------
+	*/
+
+public:
 	typedef Target* (*Factory)(const char *filename);
 
 	//! A type for a map of targets, indexed by the name of the Target
@@ -152,7 +175,7 @@ public:
 
 	virtual bool init() { return true; }
 
-	//! Creates a new Target described by \a type, outputing to a file described by \a filename.
+	//! Creates a new Target described by \a type, outputting to a file described by \a filename.
 	static Handle create(const String &type, const String &filename);
 }; // END of class Target
 
