@@ -2,10 +2,11 @@
 /*!	\file target_tile.cpp
 **	\brief Template File
 **
-**	$Id: target_tile.cpp 389 2007-03-27 16:33:57Z dooglus $
+**	$Id: target_tile.cpp 1825 2008-02-29 15:36:18Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007, 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -47,12 +48,12 @@ using namespace etl;
 using namespace synfig;
 
 /* === M A C R O S ========================================================= */
-const unsigned int	DEF_TILE_WIDTH = 64;
-const unsigned int	DEF_TILE_HEIGHT= 64;
+const unsigned int	DEF_TILE_WIDTH = TILE_SIZE / 2;
+const unsigned int	DEF_TILE_HEIGHT= TILE_SIZE / 2;
 
-#define SYNFIG_OPTIMIZE_LAYER_TREE 	1
+#define SYNFIG_OPTIMIZE_LAYER_TREE
 #ifdef _DEBUG
-#define SYNFIG_DISPLAY_EFFICIENCY	1
+// #define SYNFIG_DISPLAY_EFFICIENCY
 #endif
 
 /* === G L O B A L S ======================================================= */
@@ -276,12 +277,13 @@ synfig::Target_Tile::render_frame_(Context context,ProgressCallback *cb)
 				add_tile_time+=timer();
 			}
 			tile_timer.reset();
+			signal_progress()();
 		}
 	}
 	if(cb && !cb->amount_complete(total_tiles,total_tiles))
 		return false;
 
-#if SYNFIG_DISPLAY_EFFICIENCY==1
+#ifdef SYNFIG_DISPLAY_EFFICIENCY
 	synfig::info(">>>>>> Render Time: %fsec, Find Tile Time: %fsec, Add Tile Time: %fsec, Total Time: %fsec",work_time,find_tile_time,add_tile_time,total_time());
 	synfig::info(">>>>>> FRAME EFFICIENCY: %f%%",(100.0f*work_time/total_time()));
 #endif
@@ -307,7 +309,7 @@ synfig::Target_Tile::render(ProgressCallback *cb)
 	curr_frame_=0;
 	init();
 	if( !init() ){
-		if(cb) cb->error(_("Target initialisation failure"));
+		if(cb) cb->error(_("Target initialization failure"));
 		return false;
 	}
 
@@ -354,21 +356,29 @@ synfig::Target_Tile::render(ProgressCallback *cb)
 
 			Context context;
 
-			#ifdef SYNFIG_OPTIMIZE_LAYER_TREE
-			Canvas::Handle op_canvas(Canvas::create());
-			optimize_layers(canvas->get_context(), op_canvas);
-			context=op_canvas->get_context();
-			#else
+#ifdef SYNFIG_OPTIMIZE_LAYER_TREE
+			Canvas::Handle op_canvas;
+			if (!getenv("SYNFIG_DISABLE_OPTIMIZE_LAYER_TREE"))
+			{
+				op_canvas = Canvas::create();
+				op_canvas->set_file_name(canvas->get_file_name());
+				optimize_layers(canvas->get_time(), canvas->get_context(), op_canvas);
+				context=op_canvas->get_context();
+			}
+			else
+				context=canvas->get_context();
+#else
 			context=canvas->get_context();
-			#endif
+#endif
 
 /*
 			#ifdef SYNFIG_OPTIMIZE_LAYER_TREE
 			Context context;
 			Canvas::Handle op_canvas(Canvas::create());
+			op_canvas->set_file_name(canvas->get_file_name());
 			// Set the time that we wish to render
 			canvas->set_time(t);
-			optimize_layers(canvas->get_context(), op_canvas);
+			optimize_layers(canvas->get_time(), canvas->get_context(), op_canvas);
 			context=op_canvas->get_context();
 			#else
 			Context context;
@@ -399,13 +409,20 @@ synfig::Target_Tile::render(ProgressCallback *cb)
 
 			Context context;
 
-			#ifdef SYNFIG_OPTIMIZE_LAYER_TREE
-			Canvas::Handle op_canvas(Canvas::create());
-			optimize_layers(canvas->get_context(), op_canvas);
-			context=op_canvas->get_context();
-			#else
+#ifdef SYNFIG_OPTIMIZE_LAYER_TREE
+			Canvas::Handle op_canvas;
+			if (!getenv("SYNFIG_DISABLE_OPTIMIZE_LAYER_TREE"))
+			{
+				op_canvas = Canvas::create();
+				op_canvas->set_file_name(canvas->get_file_name());
+				optimize_layers(canvas->get_time(), canvas->get_context(), op_canvas);
+				context=op_canvas->get_context();
+			}
+			else
+				context=canvas->get_context();
+#else
 			context=canvas->get_context();
-			#endif
+#endif
 
 			if(!render_frame_(context, cb))
 				return false;
