@@ -2,11 +2,11 @@
 /*!	\file time.cpp
 **	\brief Template File
 **
-**	$Id: time.cpp 848 2007-10-06 02:25:36Z dooglus $
+**	$Id: time.cpp 1823 2008-02-29 15:35:54Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
-**	Copyright (c) 2007 Chris Moore
+**	Copyright (c) 2007, 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -101,7 +101,7 @@ Time::Time(const String &str_, float fps):
 	int read;
 	float amount;
 
-	// Now try to read it in the letter-abreviated format
+	// Now try to read it in the letter-abbreviated format
 	while(pos<str.size() && sscanf(String(str,pos).c_str(),"%f%n",&amount,&read))
 	{
 		pos+=read;
@@ -193,7 +193,7 @@ Time::get_string(float fps, Time::Format format)const
 		int second;
 		second=time;time-=second;
 
-		if(fps)
+		if(fps && fps>1)
 		{
 			int frame;
 			frame=round_to_int(time*fps);
@@ -204,39 +204,57 @@ Time::get_string(float fps, Time::Format format)const
 			return strprintf("%02d:%02d:%02d",hour,minute,second);
 	}
 
+	if (format <= FORMAT_FRAMES)
+	{
+		if (fps && fps>0)
+			return strprintf("%df", round_to_int(time * fps));
+		else
+			return strprintf("%ds", round_to_int(time * 1));
+	}
+
 	String ret;
 	bool started = false;
 
 	if(format<=FORMAT_FULL || hour)
 	{
-		ret+=strprintf(format<=FORMAT_NOSPACES?"%dh":"%dh ",hour);
+		ret+=strprintf("%dh",hour);
 		started = true;
 	}
 
 	if(format<=FORMAT_FULL || minute)
 	{
-		ret+=strprintf(format<=FORMAT_NOSPACES?"%dm":"%dm ",minute);
+		if (!(format<=FORMAT_NOSPACES) && started)
+			ret += " ";
+
+		ret += strprintf("%dm", minute);
 		started = true;
 	}
 
-	if(fps)
+	if(fps && fps>1)
 	{
 		int second;
 		float frame;
 		second=time;time-=second;
 		frame=time*fps;
+
 		if(format<=FORMAT_FULL || second)
 		{
-			ret+=strprintf(format<=FORMAT_NOSPACES?"%ds":"%ds ",(int)second);
+			if (!(format<=FORMAT_NOSPACES) && started)
+				ret += " ";
+
+			ret += strprintf("%ds", (int)second);
 			started = true;
 		}
 
 		if(format<=FORMAT_FULL || frame || !started)
 		{
-			if(abs(frame-floor(frame)>=epsilon_()))
-				ret+=strprintf("%0.3ff",frame);
+			if (!(format<=FORMAT_NOSPACES) && started)
+				ret += " ";
+
+			if(abs(frame-floor(frame) >= epsilon_()))
+				ret += strprintf("%0.3ff", frame);
 			else
-				ret+=strprintf("%0.0ff",frame);
+				ret += strprintf("%0.0ff", frame);
 		}
 	}
 	else
@@ -245,8 +263,24 @@ Time::get_string(float fps, Time::Format format)const
 		second=time;
 		if(format<=FORMAT_FULL || second || !started)
 		{
+			if (!(format<=FORMAT_NOSPACES) && started)
+				ret += " ";
+
 			if(abs(second-floor(second))>=epsilon_())
-				ret+=strprintf("%0.8fs",second);
+			{
+				String seconds(strprintf("%0.8f",second));
+
+				// skip trailing zeros
+				int count = 0;
+				String::reverse_iterator i = seconds.rbegin();
+				for ( ; (*i) == '0'; i++)
+					count++;
+
+				// if we removed too many, go back one place, leaving one zero
+				if (*i < '0' || *i > '9') count--;
+
+				ret += seconds.substr(0, seconds.size()-count) + "s";
+			}
 			else
 				ret+=strprintf("%0.0fs",second);
 		}
@@ -270,6 +304,14 @@ Time::round(float fps)const
 		return ceil(time)/fps;
 }
 
+#ifdef _DEBUG
+const char *
+Time::c_str()const
+{
+	return get_string().c_str();
+}
+#endif
+
 //! \writeme
 bool
 Time::is_valid()const
