@@ -2,10 +2,11 @@
 /*!	\file time.h
 **	\brief Template Header
 **
-**	$Id: time.h 335 2007-03-16 00:39:09Z dooglus $
+**	$Id: time.h 1822 2008-02-29 15:35:42Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2007 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -54,7 +55,8 @@ public:
 		FORMAT_NORMAL=0,		//!< Represents the default method of printing the time
 		FORMAT_NOSPACES=(1<<0),	//!< Remove any whitespace
 		FORMAT_FULL=(1<<1),		//!< Do not remove units that have "zero" value
-		FORMAT_VIDEO=(1<<2),	//!< Use the HH:MM:SS.ff format
+		FORMAT_VIDEO=(1<<2),	//!< Use the HH:MM:SS.FF format
+		FORMAT_FRAMES=(1<<3),	//!< Use the FF format (frames only)
 
 		FORMAT_END=(1<<4)		//!< \internal Not used
 	}; // END of enum Format
@@ -62,7 +64,7 @@ public:
 private:
 	value_type value_;
 
-	static const value_type epsilon_() { return static_cast<value_type>(0.0005); }
+	static value_type epsilon_() { return static_cast<value_type>(0.0005); }
 
 public:
 	Time() { }
@@ -98,6 +100,10 @@ public:
 	/*!	\see Format */
 	String get_string(float fps=0, Time::Format format=FORMAT_NORMAL)const;
 
+#ifdef _DEBUG
+	const char *c_str()const;
+#endif
+
 	//! \writeme
 	bool is_valid()const;
 
