@@ -1,12 +1,12 @@
 /* === S Y N F I G ========================================================= */
 /*!	\file valuenode.cpp
-**	\brief Template File
+**	\brief Implementation of the "Placeholder" valuenode conversion.
 **
-**	$Id: valuenode.cpp 848 2007-10-06 02:25:36Z dooglus $
+**	$Id: valuenode.cpp 1708 2008-02-16 04:56:00Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
-**	Copyright (c) 2007 Chris Moore
+**	Copyright (c) 2007, 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -37,6 +37,8 @@
 #include "valuenode.h"
 #include "general.h"
 #include "canvas.h"
+#include "paramdesc.h"
+#include "releases.h"
 
 #include "valuenode_const.h"
 #include "valuenode_linear.h"
@@ -45,6 +47,8 @@
 #include "valuenode_scale.h"
 #include "valuenode_blinecalctangent.h"
 #include "valuenode_blinecalcvertex.h"
+#include "valuenode_blinecalcwidth.h"
+#include "valuenode_blinereversetangent.h"
 #include "valuenode_segcalctangent.h"
 #include "valuenode_segcalcvertex.h"
 #include "valuenode_repeat_gradient.h"
@@ -59,7 +63,15 @@
 #include "valuenode_radialcomposite.h"
 #include "valuenode_gradientrotate.h"
 #include "valuenode_sine.h"
+#include "valuenode_cos.h"
+#include "valuenode_atan2.h"
 #include "valuenode_exp.h"
+#include "valuenode_switch.h"
+#include "valuenode_timeloop.h"
+#include "valuenode_reciprocal.h"
+#include "valuenode_duplicate.h"
+#include "valuenode_integer.h"
+#include "valuenode_step.h"
 
 #include "layer.h"
 
@@ -95,37 +107,51 @@ ValueNode::subsys_init()
 {
 	book_=new LinkableValueNode::Book();
 
-#define ADD_VALUENODE(class,name,local)															\
+#define ADD_VALUENODE(class,name,local,version)													\
 	(*book_)[name].factory=reinterpret_cast<LinkableValueNode::Factory>(&class::create);		\
 	(*book_)[name].check_type=&class::check_type;												\
-	(*book_)[name].local_name=local
+	(*book_)[name].local_name=local;															\
+	(*book_)[name].release_version=version
 
-#define ADD_VALUENODE2(class,name,local)														\
+#define ADD_VALUENODE2(class,name,local,version)												\
 	(*book_)[name].factory=reinterpret_cast<LinkableValueNode::Factory>(&class::create_from);	\
 	(*book_)[name].check_type=&class::check_type;												\
-	(*book_)[name].local_name=local
+	(*book_)[name].local_name=local;															\
+	(*book_)[name].release_version=version
 
-	ADD_VALUENODE(ValueNode_Linear,			"linear",			_("Linear")				);
-	ADD_VALUENODE(ValueNode_Composite,		"composite",		_("Composite")			);
-	ADD_VALUENODE(ValueNode_RadialComposite,"radial_composite",	_("Radial Composite")	);
-	ADD_VALUENODE(ValueNode_Reference,		"reference",		_("Reference")			);
-	ADD_VALUENODE(ValueNode_Repeat_Gradient,"repeat_gradient",	_("Repeat Gradient")	);
-	ADD_VALUENODE(ValueNode_Scale,			"scale",			_("Scale")				);
-	ADD_VALUENODE(ValueNode_BLineCalcTangent,"blinecalctangent",_("BLine Tangent")		);
-	ADD_VALUENODE(ValueNode_BLineCalcVertex,"blinecalcvertex",	_("BLine Vertex")		);
-	ADD_VALUENODE(ValueNode_SegCalcTangent,	"segcalctangent",	_("Segment Tangent")	);
-	ADD_VALUENODE(ValueNode_SegCalcVertex,	"segcalcvertex",	_("Segment Vertex")		);
-	ADD_VALUENODE(ValueNode_Stripes,		"stripes",			_("Stripes")			);
-	ADD_VALUENODE(ValueNode_Range,			"range",			_("Range")				);
-	ADD_VALUENODE(ValueNode_Add,			"add",				_("Add")				);
-	ADD_VALUENODE(ValueNode_Subtract,		"subtract",			_("Subtract")			);
-	ADD_VALUENODE(ValueNode_TimedSwap,		"timed_swap",		_("Timed Swap")			);
-	ADD_VALUENODE(ValueNode_TwoTone,		"twotone",			_("Two-Tone")			);
-	ADD_VALUENODE(ValueNode_BLine,			"bline",			_("BLine")				);
-	ADD_VALUENODE2(ValueNode_DynamicList,	"dynamic_list",		_("Dynamic List")		);
-	ADD_VALUENODE(ValueNode_GradientRotate,	"gradient_rotate",	_("Gradient Rotate")	);
-	ADD_VALUENODE(ValueNode_Sine,			"sine",				_("Sine")				);
-	ADD_VALUENODE(ValueNode_Exp,			"exp",				_("Exponential")		);
+	ADD_VALUENODE(ValueNode_Linear,			  "linear",			  _("Linear"),			 RELEASE_VERSION_0_61_06);
+	ADD_VALUENODE(ValueNode_Composite,		  "composite",		  _("Composite"),		 RELEASE_VERSION_0_61_06);
+	ADD_VALUENODE(ValueNode_RadialComposite,  "radial_composite", _("Radial Composite"), RELEASE_VERSION_0_61_06);
+	ADD_VALUENODE(ValueNode_Reference,		  "reference",		  _("Reference"),		 RELEASE_VERSION_0_61_06);
+	ADD_VALUENODE(ValueNode_Scale,			  "scale",			  _("Scale"),			 RELEASE_VERSION_0_61_06);
+	ADD_VALUENODE(ValueNode_SegCalcTangent,	  "segcalctangent",	  _("Segment Tangent"),	 RELEASE_VERSION_0_61_06);
+	ADD_VALUENODE(ValueNode_SegCalcVertex,	  "segcalcvertex",	  _("Segment Vertex"),	 RELEASE_VERSION_0_61_06);
+	ADD_VALUENODE(ValueNode_Stripes,		  "stripes",		  _("Stripes"),			 RELEASE_VERSION_0_61_06);
+	ADD_VALUENODE(ValueNode_Subtract,		  "subtract",		  _("Subtract"),		 RELEASE_VERSION_0_61_06);
+	ADD_VALUENODE(ValueNode_TwoTone,		  "twotone",		  _("Two-Tone"),		 RELEASE_VERSION_0_61_06);
+	ADD_VALUENODE(ValueNode_BLine,			  "bline",			  _("BLine"),			 RELEASE_VERSION_0_61_06);
+	ADD_VALUENODE2(ValueNode_DynamicList,	  "dynamic_list",	  _("Dynamic List"),	 RELEASE_VERSION_0_61_06);
+	ADD_VALUENODE(ValueNode_GradientRotate,	  "gradient_rotate",  _("Gradient Rotate"),	 RELEASE_VERSION_0_61_06);
+	ADD_VALUENODE(ValueNode_Sine,			  "sine",			  _("Sine"),			 RELEASE_VERSION_0_61_06);
+
+	ADD_VALUENODE(ValueNode_TimedSwap,		  "timed_swap",		  _("Timed Swap"),		 RELEASE_VERSION_0_61_07); // SVN r610
+	ADD_VALUENODE(ValueNode_Repeat_Gradient,  "repeat_gradient",  _("Repeat Gradient"),	 RELEASE_VERSION_0_61_07); // SVN r666
+	ADD_VALUENODE(ValueNode_Exp,			  "exp",			  _("Exponential"),		 RELEASE_VERSION_0_61_07); // SVN r739
+	ADD_VALUENODE(ValueNode_Add,			  "add",			  _("Add"),				 RELEASE_VERSION_0_61_07); // SVN r742
+	ADD_VALUENODE(ValueNode_BLineCalcTangent, "blinecalctangent", _("BLine Tangent"),	 RELEASE_VERSION_0_61_07); // SVN r744
+	ADD_VALUENODE(ValueNode_BLineCalcVertex,  "blinecalcvertex",  _("BLine Vertex"),	 RELEASE_VERSION_0_61_07); // SVN r744
+	ADD_VALUENODE(ValueNode_Range,			  "range",			  _("Range"),			 RELEASE_VERSION_0_61_07); // SVN r776
+
+	ADD_VALUENODE(ValueNode_Switch,			  "switch",			  _("Switch"),			 RELEASE_VERSION_0_61_08); // SVN r923
+	ADD_VALUENODE(ValueNode_Cos,			  "cos",			  _("Cos"),				 RELEASE_VERSION_0_61_08); // SVN r1111
+	ADD_VALUENODE(ValueNode_Atan2,			  "atan2",			  _("aTan2"),			 RELEASE_VERSION_0_61_08); // SVN r1132
+	ADD_VALUENODE(ValueNode_BLineRevTangent,  "blinerevtangent",  _("Reverse Tangent"),	 RELEASE_VERSION_0_61_08); // SVN r1162
+	ADD_VALUENODE(ValueNode_TimeLoop,		  "timeloop",		  _("Time Loop"),		 RELEASE_VERSION_0_61_08); // SVN r1226
+	ADD_VALUENODE(ValueNode_Reciprocal,		  "reciprocal",		  _("Reciprocal"),		 RELEASE_VERSION_0_61_08); // SVN r1238
+	ADD_VALUENODE(ValueNode_Duplicate,		  "duplicate",		  _("Duplicate"),		 RELEASE_VERSION_0_61_08); // SVN r1267
+	ADD_VALUENODE(ValueNode_Integer,		  "fromint",		  _("From Integer"),	 RELEASE_VERSION_0_61_08); // SVN r1267
+	ADD_VALUENODE(ValueNode_Step,			  "step",			  _("Step"),			 RELEASE_VERSION_0_61_08); // SVN r1691
+	ADD_VALUENODE(ValueNode_BLineCalcWidth,	  "blinecalcwidth",	  _("BLine Width"),		 RELEASE_VERSION_0_61_08); // SVN r1694
 
 #undef ADD_VALUENODE
 #undef ADD_VALUENODE2
@@ -149,19 +175,19 @@ ValueNode::subsys_stop()
 		for(iter=global_value_node_map.begin();iter!=global_value_node_map.end();++iter)
 		{
 			if(!iter->second->is_exported())
-				synfig::info("%s: count:%d name:%s type:%s",
+				synfig::info(_("%s: count:%d name:%s type:%s"),
 					iter->first.get_string().c_str(),
 					iter->second->count(),
 					iter->second->get_name().c_str(),
-					ValueBase::type_name(iter->second->get_type()).c_str()
+					ValueBase::type_local_name(iter->second->get_type()).c_str()
 				);
 			else
-				synfig::info("%s: id:%s count:%d name:%s type:%s",
+				synfig::info(_("%s: id:%s count:%d name:%s type:%s"),
 					iter->first.get_string().c_str(),
 					iter->second->get_id().c_str(),
 					iter->second->count(),
 					iter->second->get_name().c_str(),
-					ValueBase::type_name(iter->second->get_type()).c_str()
+					ValueBase::type_local_name(iter->second->get_type()).c_str()
 				);
 		}
 	}
@@ -185,6 +211,17 @@ LinkableValueNode::create(const String &name, const ValueBase& x)
 {
 	if(!book().count(name))
 		return 0;
+
+	if (!check_type(name, x.get_type()) &&
+		// the Duplicate ValueNode is an exception - we don't want the
+		// user creating it for themselves, so check_type() fails for
+		// it even when it is valid
+		!(name == "duplicate" && x.get_type() == ValueBase::TYPE_REAL))
+	{
+		error(_("Bad type: ValueNode '%s' doesn't accept type '%s'"), book()[name].local_name.c_str(), ValueBase::type_local_name(x.get_type()).c_str());
+		return 0;
+	}
+
 	return book()[name].factory(x);
 }
 
@@ -239,8 +276,6 @@ ValueNode::~ValueNode()
 	value_node_count--;
 
 	begin_delete();
-
-	//DEBUGPOINT();
 }
 
 void
@@ -285,6 +320,23 @@ ValueNode::set_id(const String &x)
 	}
 }
 
+String
+ValueNode::get_description(bool show_exported_name)const
+{
+	String ret(_("ValueNode"));
+
+	if (dynamic_cast<const LinkableValueNode*>(this))
+		return (dynamic_cast<const LinkableValueNode*>(this))->get_description(-1, show_exported_name);
+
+	if (show_exported_name && !is_exported())
+		show_exported_name = false;
+
+	if (show_exported_name)
+		ret += strprintf(" (%s)", get_id().c_str());
+
+	return ret;
+}
+
 ValueNodeList::ValueNodeList():
 	placeholder_count_(0)
 {
@@ -298,7 +350,8 @@ ValueNodeList::count(const String &id)const
 	if(id.empty())
 		return false;
 
-	for(iter=begin();iter!=end() && id!=(*iter)->get_id();++iter);
+	for(iter=begin();iter!=end() && id!=(*iter)->get_id();++iter)
+		;
 
 	if(iter==end())
 		return false;
@@ -314,7 +367,8 @@ ValueNodeList::find(const String &id)
 	if(id.empty())
 		throw Exception::IDNotFound("Empty ID");
 
-	for(iter=begin();iter!=end() && id!=(*iter)->get_id();++iter);
+	for(iter=begin();iter!=end() && id!=(*iter)->get_id();++iter)
+		;
 
 	if(iter==end())
 		throw Exception::IDNotFound("ValueNode in ValueNodeList: "+id);
@@ -330,7 +384,8 @@ ValueNodeList::find(const String &id)const
 	if(id.empty())
 		throw Exception::IDNotFound("Empty ID");
 
-	for(iter=begin();iter!=end() && id!=(*iter)->get_id();++iter);
+	for(iter=begin();iter!=end() && id!=(*iter)->get_id();++iter)
+		;
 
 	if(iter==end())
 		throw Exception::IDNotFound("ValueNode in ValueNodeList: "+id);
@@ -460,7 +515,11 @@ PlaceholderValueNode::PlaceholderValueNode(ValueBase::Type type):
 ValueNode*
 LinkableValueNode::clone(const GUID& deriv_guid)const
 {
-	{ ValueNode* x(find_value_node(get_guid()^deriv_guid).get()); if(x)return x; }
+	{
+		ValueNode* x(find_value_node(get_guid()^deriv_guid).get());
+		if(x)
+			return x;
+	}
 
 	int i;
 	LinkableValueNode *ret=create_new();
@@ -525,3 +584,67 @@ void LinkableValueNode::get_times_vfunc(Node::time_set &set) const
 		}
 	}
 }
+
+String
+LinkableValueNode::get_description(int index, bool show_exported_name)const
+{
+	String description;
+
+	if (index == -1)
+	{
+		if (show_exported_name && is_exported())
+			description += strprintf(" (%s)", get_id().c_str());
+	}
+	else
+	{
+		description = String(":") + link_local_name(index);
+
+		if (show_exported_name)
+		{
+			ValueNode::LooseHandle link(get_link(index));
+			if (link->is_exported())
+				description += strprintf(" (%s)", link->get_id().c_str());
+		}
+	}
+
+	const synfig::Node* node = this;
+	LinkableValueNode::ConstHandle parent_linkable_vn = 0;
+
+	// walk up through the valuenodes trying to find the layer at the top
+	while (!node->parent_set.empty() && !dynamic_cast<const Layer*>(node))
+	{
+		LinkableValueNode::ConstHandle linkable_value_node(dynamic_cast<const LinkableValueNode*>(node));
+		if (linkable_value_node)
+		{
+			String link;
+			int cnt = linkable_value_node->link_count();
+			for (int i = 0; i < cnt; i++)
+				if (linkable_value_node->get_link(i) == parent_linkable_vn)
+				{
+					link = String(":") + linkable_value_node->link_local_name(i);
+					break;
+				}
+
+			description = linkable_value_node->get_local_name() + link + (parent_linkable_vn?">":"") + description;
+		}
+		node = *node->parent_set.begin();
+		parent_linkable_vn = linkable_value_node;
+	}
+
+	Layer::ConstHandle parent_layer(dynamic_cast<const Layer*>(node));
+	if(parent_layer)
+	{
+		String param;
+		const Layer::DynamicParamList &dynamic_param_list(parent_layer->dynamic_param_list());
+		// loop to find the parameter in the dynamic parameter list - this gives us its name
+		for (Layer::DynamicParamList::const_iterator iter = dynamic_param_list.begin(); iter != dynamic_param_list.end(); iter++)
+			if (iter->second == parent_linkable_vn)
+				param = String(":") + parent_layer->get_param_local_name(iter->first);
+		description = strprintf("(%s)%s>%s",
+								parent_layer->get_non_empty_description().c_str(),
+								param.c_str(),
+								description.c_str());
+	}
+
+	return description;
+}
