@@ -1,11 +1,12 @@
 /* === S Y N F I G ========================================================= */
 /*!	\file valuenode_composite.cpp
-**	\brief Template File
+**	\brief Implementation of the "Composite" valuenode conversion.
 **
-**	$Id: valuenode_composite.cpp 601 2007-09-05 14:04:03Z dooglus $
+**	$Id: valuenode_composite.cpp 1643 2008-02-09 19:12:18Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -37,6 +38,7 @@
 #include "vector.h"
 #include "color.h"
 #include "segment.h"
+#include "savecanvas.h"
 
 #endif
 
@@ -88,7 +90,7 @@ synfig::ValueNode_Composite::ValueNode_Composite(const ValueBase &value):
 		}
 		default:
 			assert(0);
-			throw Exception::BadType(ValueBase::type_name(get_type()));
+			throw Exception::BadType(ValueBase::type_local_name(get_type()));
 	}
 }
 
@@ -184,8 +186,7 @@ ValueNode_Composite::link_count()const
 bool
 ValueNode_Composite::set_link_vfunc(int i,ValueNode::Handle x)
 {
-	assert(i>=0);
-	assert(i<6);
+	assert(i>=0 && i<link_count());
 
 	if(PlaceholderValueNode::Handle::cast_dynamic(x))
 	{
@@ -196,7 +197,6 @@ ValueNode_Composite::set_link_vfunc(int i,ValueNode::Handle x)
 	switch(get_type())
 	{
 		case ValueBase::TYPE_VECTOR:
-			assert(i<2);
 			if(x->get_type()==ValueBase(Real()).get_type() || PlaceholderValueNode::Handle::cast_dynamic(x))
 			{
 				components[i]=x;
@@ -205,7 +205,6 @@ ValueNode_Composite::set_link_vfunc(int i,ValueNode::Handle x)
 			break;
 
 		case ValueBase::TYPE_COLOR:
-			assert(i<4);
 			if(x->get_type()==ValueBase(Real()).get_type() || PlaceholderValueNode::Handle::cast_dynamic(x))
 			{
 				components[i]=x;
@@ -214,7 +213,6 @@ ValueNode_Composite::set_link_vfunc(int i,ValueNode::Handle x)
 			break;
 
 		case ValueBase::TYPE_SEGMENT:
-			assert(i<4);
 			if(x->get_type()==ValueBase(Point()).get_type() || PlaceholderValueNode::Handle::cast_dynamic(x))
 			{
 				components[i]=x;
@@ -223,7 +221,6 @@ ValueNode_Composite::set_link_vfunc(int i,ValueNode::Handle x)
 			break;
 
 		case ValueBase::TYPE_BLINEPOINT:
-			assert(i<6);
 			if((i==0 || i==4 || i==5) && x->get_type()==ValueBase(Point()).get_type())
 			{
 				components[i]=x;
@@ -250,14 +247,16 @@ ValueNode_Composite::set_link_vfunc(int i,ValueNode::Handle x)
 ValueNode::LooseHandle
 ValueNode_Composite::get_link_vfunc(int i)const
 {
-	assert(i>=0 && i<6);
+	assert(i>=0 && i<link_count());
+
 	return components[i];
 }
 
 String
 ValueNode_Composite::link_local_name(int i)const
 {
-	assert(i>=0 && i<6);
+	assert(i>=0 && i<link_count());
+
 	switch(get_type())
 	{
 		case ValueBase::TYPE_VECTOR:
@@ -298,6 +297,10 @@ ValueNode_Composite::link_local_name(int i)const
 				return _("Tangent 2");
 
 		default:
+			assert(0);
+			// notice that Composite counts from 1 and Radial Composite counts
+			// from 0!  we need to keep it like that to correctly load old
+			// animations, but let's not save "c%d" format link names in future
 			return etl::strprintf(_("C%d"),i+1);
 	}
 }
@@ -306,8 +309,58 @@ ValueNode_Composite::link_local_name(int i)const
 String
 ValueNode_Composite::link_name(int i)const
 {
-	assert(i>=0 && i<5);
-	return strprintf("c%d",i);
+	assert(i>=0 && i<link_count());
+
+	if (get_file_version() < RELEASE_VERSION_0_61_08)
+		return strprintf("c%d",i+1);
+
+	switch(get_type())
+	{
+	case ValueBase::TYPE_COLOR:
+		switch(i)
+		{
+		case 0: return "red";
+		case 1: return "green";
+		case 2: return "blue";
+		case 3: return "alpha";
+		}
+		break;
+	case ValueBase::TYPE_SEGMENT:
+		switch(i)
+		{
+		case 0: return "p1";
+		case 1: return "t1";
+		case 2: return "p2";
+		case 3: return "t2";
+		}
+		break;
+	case ValueBase::TYPE_VECTOR:
+		switch(i)
+		{
+		case 0: return "x";
+		case 1: return "y";
+		}
+		break;
+	case ValueBase::TYPE_BLINEPOINT:
+		switch(i)
+		{
+		case 0: return "point";
+		case 1: return "width";
+		case 2: return "origin";
+		case 3: return "split";
+		case 4: return "t1";
+		case 5: return "t2";
+		}
+		break;
+	default:
+		break;
+	}
+
+	assert(0);
+	// notice that Composite counts from 1 and Radial Composite counts
+	// from 0!  we need to keep it like that to correctly load old
+	// animations, but let's not save "c%d" format link names in future
+	return strprintf("c%d",i+1);
 }
 
 int
@@ -316,8 +369,8 @@ ValueNode_Composite::get_link_index_from_name(const String &name)const
 	if(name.empty())
 		throw Exception::BadLinkName(name);
 
-	if(name[0]=='c')
-		return name[1]-'0';
+	if(name[0]=='c' && name.size() == 2 && name[1]-'1' >= 0 && name[1]-'1' < link_count())
+		return name[1]-'1';
 
 	switch(get_type())
 	{
@@ -344,7 +397,7 @@ ValueNode_Composite::get_link_index_from_name(const String &name)const
 			return 0;
 		if(name[0]=='y')
 			return 1;
-		if(name[0]=='z')
+		if(name[0]=='z')		// \todo "z"?  really?
 			return 2;
 	case ValueBase::TYPE_BLINEPOINT:
 		if(name[0]=='p' || name=="v1" || name=="p1")
