@@ -1,8 +1,8 @@
 /* === S Y N F I G ========================================================= */
 /*!	\file valuenode_dynamiclist.h
-**	\brief Template Header
+**	\brief Header file for implementation of the "Dynamic List" valuenode conversion.
 **
-**	$Id: valuenode_dynamiclist.h 335 2007-03-16 00:39:09Z dooglus $
+**	$Id: valuenode_dynamiclist.h 1761 2008-02-19 18:51:09Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -41,6 +41,7 @@
 
 namespace synfig {
 class ValueNode_BLine;
+class Canvas;
 
 /*! \class ValueNode_DynamicList
 **	\brief Animated List ValueNode
@@ -55,7 +56,7 @@ class ValueNode_BLine;
 **	The problems arise when we introduce the concept of a
 **	Keyframe. Keyframes can be manipulated via the Synfig
 **	Application Library. They allow the user to quickly
-**	and "automagickly" rearange an animation by moving
+**	and "automagically" rearrange an animation by moving
 **	the associated keyframes. With the old way that the
 **	"on" and "off" points were handled, this task became
 **	overly complicated.
@@ -197,6 +198,8 @@ public:
 	bool get_loop()const { return loop_; }
 	void set_loop(bool x) { loop_=x; }
 
+	void set_member_canvas(etl::loose_handle<Canvas>);
+
 	ValueBase::Type get_contained_type()const;
 
 
