@@ -1,11 +1,12 @@
 /* === S Y N F I G ========================================================= */
 /*!	\file valuenode_reference.cpp
-**	\brief Template File
+**	\brief Implementation of the "Reference" valuenode conversion.
 **
-**	$Id: valuenode_reference.cpp 631 2007-09-08 15:33:07Z dooglus $
+**	$Id: valuenode_reference.cpp 1643 2008-02-09 19:12:18Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -78,20 +79,22 @@ ValueNode_Reference::~ValueNode_Reference()
 }
 
 bool
-ValueNode_Reference::set_link_vfunc(int i,ValueNode::Handle x)
+ValueNode_Reference::set_link_vfunc(int i,ValueNode::Handle value)
 {
-	assert(i==0);
-	if(x->get_type()!=get_type() && !PlaceholderValueNode::Handle::cast_dynamic(x))
-		return false;
-	link_=x;
-	signal_child_changed()(i);signal_value_changed()();
-	return true;
+	assert(i>=0 && i<link_count());
+
+	switch(i)
+	{
+	case 0: CHECK_TYPE_AND_SET_VALUE(link_, get_type());
+	}
+	return false;
 }
 
 ValueNode::LooseHandle
-ValueNode_Reference::get_link_vfunc(int i)const
+ValueNode_Reference::get_link_vfunc(int i __attribute__ ((unused)))const
 {
-	assert(i==0);
+	assert(i>=0 && i<link_count());
+
 	return link_;
 }
 
@@ -104,14 +107,25 @@ ValueNode_Reference::link_count()const
 String
 ValueNode_Reference::link_local_name(int i)const
 {
-	assert(i==0);
-	return _("Link");
+	assert(i>=0 && i<link_count());
+
+	switch(i)
+	{
+	case 0: return _("Link");
+	}
+	return String();
 }
 
 String
-ValueNode_Reference::link_name(int /*i*/)const
+ValueNode_Reference::link_name(int i)const
 {
-	return "link";
+	assert(i>=0 && i<link_count());
+
+	switch(i)
+	{
+	case 0: return "link";
+	}
+	return String();
 }
 
 int
