@@ -1,12 +1,12 @@
 /* === S Y N F I G ========================================================= */
 /*!	\file valuenode_segcalcvertex.cpp
-**	\brief Template File
+**	\brief Implementation of the "Segment Vertex" valuenode conversion.
 **
-**	$Id: valuenode_segcalcvertex.cpp 848 2007-10-06 02:25:36Z dooglus $
+**	$Id: valuenode_segcalcvertex.cpp 1643 2008-02-09 19:12:18Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
-**	Copyright (c) 2007 Chris Moore
+**	Copyright (c) 2007, 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -58,7 +58,7 @@ ValueNode_SegCalcVertex::ValueNode_SegCalcVertex(const ValueBase::Type &x):
 	LinkableValueNode(x)
 {
 	if(x!=ValueBase::TYPE_VECTOR)
-		throw Exception::BadType(ValueBase::type_name(x));
+		throw Exception::BadType(ValueBase::type_local_name(x));
 
 	set_link("segment",ValueNode_Const::create(ValueBase::TYPE_SEGMENT));
 	set_link("amount",ValueNode_Const::create(Real(0.5)));
@@ -105,20 +105,14 @@ ValueNode_SegCalcVertex::check_type(ValueBase::Type type)
 }
 
 bool
-ValueNode_SegCalcVertex::set_link_vfunc(int i,ValueNode::Handle x)
+ValueNode_SegCalcVertex::set_link_vfunc(int i,ValueNode::Handle value)
 {
-	assert(i==0 || i==1);
-	if(i==0)
+	assert(i>=0 && i<link_count());
+
+	switch(i)
 	{
-		segment_=x;
-		signal_child_changed()(i);signal_value_changed()();
-		return true;
-	}
-	if(i==1)
-	{
-		amount_=x;
-		signal_child_changed()(i);signal_value_changed()();
-		return true;
+	case 0: CHECK_TYPE_AND_SET_VALUE(segment_, ValueBase::TYPE_SEGMENT);
+	case 1: CHECK_TYPE_AND_SET_VALUE(amount_,  ValueBase::TYPE_REAL);
 	}
 	return false;
 }
@@ -126,7 +120,8 @@ ValueNode_SegCalcVertex::set_link_vfunc(int i,ValueNode::Handle x)
 ValueNode::LooseHandle
 ValueNode_SegCalcVertex::get_link_vfunc(int i)const
 {
-	assert(i==0 || i==1);
+	assert(i>=0 && i<link_count());
+
 	if(i==0)
 		return segment_;
 	if(i==1)
@@ -144,7 +139,8 @@ ValueNode_SegCalcVertex::link_count()const
 String
 ValueNode_SegCalcVertex::link_name(int i)const
 {
-	assert(i==0 || i==1);
+	assert(i>=0 && i<link_count());
+
 	if(i==0)
 		return "segment";
 	if(i==1)
@@ -155,7 +151,8 @@ ValueNode_SegCalcVertex::link_name(int i)const
 String
 ValueNode_SegCalcVertex::link_local_name(int i)const
 {
-	assert(i==0 || i==1);
+	assert(i>=0 && i<link_count());
+
 	if(i==0)
 		return _("Segment");
 	if(i==1)
