@@ -1,12 +1,12 @@
 /* === S Y N F I G ========================================================= */
 /*!	\file valuenode_sine.cpp
-**	\brief Template File
+**	\brief Implementation of the "Sine" valuenode conversion.
 **
-**	$Id: valuenode_sine.cpp 848 2007-10-06 02:25:36Z dooglus $
+**	$Id: valuenode_sine.cpp 1643 2008-02-09 19:12:18Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
-**	Copyright (c) 2007 Chris Moore
+**	Copyright (c) 2007, 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -60,7 +60,7 @@ ValueNode_Sine::ValueNode_Sine(const ValueBase &value):
 		set_link("amp",ValueNode_Const::create(value.get(Real())));
 		break;
 	default:
-		throw Exception::BadType(ValueBase::type_name(value.get_type()));
+		throw Exception::BadType(ValueBase::type_local_name(value.get_type()));
 	}
 
 	DCAST_HACK_ENABLE();
@@ -113,20 +113,14 @@ ValueNode_Sine::check_type(ValueBase::Type type)
 }
 
 bool
-ValueNode_Sine::set_link_vfunc(int i,ValueNode::Handle x)
+ValueNode_Sine::set_link_vfunc(int i,ValueNode::Handle value)
 {
-	assert(i==0 || i==1);
-	if(i==0)
+	assert(i>=0 && i<link_count());
+
+	switch(i)
 	{
-		angle_=x;
-		signal_child_changed()(i);signal_value_changed()();
-		return true;
-	}
-	if(i==1)
-	{
-		amp_=x;
-		signal_child_changed()(i);signal_value_changed()();
-		return true;
+	case 0: CHECK_TYPE_AND_SET_VALUE(angle_, ValueBase::TYPE_ANGLE);
+	case 1: CHECK_TYPE_AND_SET_VALUE(amp_,   ValueBase::TYPE_REAL);
 	}
 	return false;
 }
@@ -134,7 +128,8 @@ ValueNode_Sine::set_link_vfunc(int i,ValueNode::Handle x)
 ValueNode::LooseHandle
 ValueNode_Sine::get_link_vfunc(int i)const
 {
-	assert(i==0 || i==1);
+	assert(i>=0 && i<link_count());
+
 	if(i==0)
 		return angle_;
 	if(i==1)
@@ -152,7 +147,8 @@ ValueNode_Sine::link_count()const
 String
 ValueNode_Sine::link_name(int i)const
 {
-	assert(i==0 || i==1);
+	assert(i>=0 && i<link_count());
+
 	if(i==0)
 		return "angle";
 	if(i==1)
@@ -163,7 +159,8 @@ ValueNode_Sine::link_name(int i)const
 String
 ValueNode_Sine::link_local_name(int i)const
 {
-	assert(i==0 || i==1);
+	assert(i>=0 && i<link_count());
+
 	if(i==0)
 		return _("Angle");
 	if(i==1)
