@@ -1,11 +1,12 @@
 /* === S Y N F I G ========================================================= */
 /*!	\file valuenode_stripes.h
-**	\brief Template Header
+**	\brief Header file for implementation of the "Stripes" valuenode conversion.
 **
-**	$Id: valuenode_stripes.h 335 2007-03-16 00:39:09Z dooglus $
+**	$Id: valuenode_stripes.h 1643 2008-02-09 19:12:18Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -55,20 +56,6 @@ public:
 
 	virtual ~ValueNode_Stripes();
 
-//	static Handle create(ValueBase::Type id=ValueBase::TYPE_GRADIENT);
-
-	bool set_color1(ValueNode::Handle a);
-	ValueNode::Handle get_color1()const { return color1_; }
-
-	bool set_color2(ValueNode::Handle a);
-	ValueNode::Handle get_color2()const { return color2_; }
-
-	bool set_stripes(ValueNode::Handle b);
-	ValueNode::Handle get_stripes()const { return stripes_; }
-
-	bool set_width(ValueNode::Handle x);
-
-
 	virtual bool set_link_vfunc(int i,ValueNode::Handle x);
 
 	virtual ValueNode::LooseHandle get_link_vfunc(int i)const;
