@@ -1,12 +1,12 @@
 /* === S Y N F I G ========================================================= */
 /*!	\file valuenode_subtract.cpp
-**	\brief Template File
+**	\brief Implementation of the "Subtract" valuenode conversion.
 **
-**	$Id: valuenode_subtract.cpp 848 2007-10-06 02:25:36Z dooglus $
+**	$Id: valuenode_subtract.cpp 1643 2008-02-09 19:12:18Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
-**	Copyright (c) 2007 Chris Moore
+**	Copyright (c) 2007, 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -35,9 +35,11 @@
 #include "valuenode_const.h"
 #include <stdexcept>
 #include "color.h"
+#include "gradient.h"
 #include "vector.h"
 #include "angle.h"
 #include "real.h"
+#include <ETL/misc>
 
 #endif
 
@@ -58,7 +60,7 @@ using namespace synfig;
 synfig::ValueNode_Subtract::ValueNode_Subtract(const ValueBase &value):
 	LinkableValueNode(value.get_type())
 {
-	set_scalar(1.0);
+	set_link("scalar",ValueNode_Const::create(Real(1.0)));
 	ValueBase::Type id(value.get_type());
 
 	switch(id)
@@ -71,6 +73,10 @@ synfig::ValueNode_Subtract::ValueNode_Subtract(const ValueBase &value):
 		set_link("lhs",ValueNode_Const::create(value.get(Color())));
 		set_link("rhs",ValueNode_Const::create(Color(0,0,0,0)));
 		break;
+	case ValueBase::TYPE_GRADIENT:
+		set_link("lhs",ValueNode_Const::create(value.get(Gradient())));
+		set_link("rhs",ValueNode_Const::create(Gradient()));
+		break;
 	case ValueBase::TYPE_INTEGER:
 		set_link("lhs",ValueNode_Const::create(value.get(int())));
 		set_link("rhs",ValueNode_Const::create(int(0)));
@@ -89,11 +95,11 @@ synfig::ValueNode_Subtract::ValueNode_Subtract(const ValueBase &value):
 		break;
 	default:
 		assert(0);
-		throw runtime_error("synfig::ValueNode_Subtract:Bad type "+ValueBase::type_name(id));
+		throw runtime_error(get_local_name()+_(":Bad type ")+ValueBase::type_local_name(id));
 	}
 
-	assert(get_lhs()->get_type()==id);
-	assert(get_rhs()->get_type()==id);
+	assert(ref_a->get_type()==id);
+	assert(ref_b->get_type()==id);
 	assert(get_type()==id);
 
 	DCAST_HACK_ENABLE();
@@ -116,51 +122,6 @@ synfig::ValueNode_Subtract::~ValueNode_Subtract()
 	unlink_all();
 }
 
-void
-ValueNode_Subtract::set_scalar(Real value)
-{
-	set_link("scalar",ValueNode_Const::create(value));
-}
-
-bool
-synfig::ValueNode_Subtract::set_scalar(ValueNode::Handle value)
-{
-	if(value->get_type()!=ValueBase::TYPE_REAL&& !PlaceholderValueNode::Handle::cast_dynamic(value))
-		return false;
-	scalar=value;
-	return true;
-}
-
-bool
-synfig::ValueNode_Subtract::set_lhs(ValueNode::Handle x)
-{
-	assert(get_type());
-
-	if(!x ||
-	   (get_type()==ValueBase::TYPE_NIL && !check_type(x->get_type())) ||
-	   (get_type()!=ValueBase::TYPE_NIL && x->get_type()!=get_type() && !PlaceholderValueNode::Handle::cast_dynamic(x)))
-		return false;
-
-	ref_a=x;
-
-	return true;
-}
-
-bool
-synfig::ValueNode_Subtract::set_rhs(ValueNode::Handle x)
-{
-	assert(get_type());
-
-	if(!x ||
-	   (get_type()==ValueBase::TYPE_NIL && !check_type(x->get_type())) ||
-	   (get_type()!=ValueBase::TYPE_NIL && x->get_type()!=get_type() && !PlaceholderValueNode::Handle::cast_dynamic(x)))
-		return false;
-
-	ref_b=x;
-
-	return true;
-}
-
 synfig::ValueBase
 synfig::ValueNode_Subtract::operator()(Time t)const
 {
@@ -172,12 +133,10 @@ synfig::ValueNode_Subtract::operator()(Time t)const
 		return ((*ref_a)(t).get(Angle())-(*ref_b)(t).get(Angle()))*(*scalar)(t).get(Real());
 	case ValueBase::TYPE_COLOR:
 		return ((*ref_a)(t).get(Color())-(*ref_b)(t).get(Color()))*(*scalar)(t).get(Real());
+	case ValueBase::TYPE_GRADIENT:
+		return ((*ref_a)(t).get(Gradient())-(*ref_b)(t).get(Gradient()))*(*scalar)(t).get(Real());
 	case ValueBase::TYPE_INTEGER:
-	{
-		Real ret = ((*ref_a)(t).get(int())-(*ref_b)(t).get(int()))*(*scalar)(t).get(Real()) + 0.5f;
-		if (ret < 0) return static_cast<int>(ret-1);
-		return static_cast<int>(ret); 
-	}
+		return round_to_int(((*ref_a)(t).get(int())-(*ref_b)(t).get(int()))*(*scalar)(t).get(Real()));
 	case ValueBase::TYPE_REAL:
 		return ((*ref_a)(t).get(Vector::value_type())-(*ref_b)(t).get(Vector::value_type()))*(*scalar)(t).get(Real());
 	case ValueBase::TYPE_TIME:
@@ -194,28 +153,22 @@ synfig::ValueNode_Subtract::operator()(Time t)const
 bool
 ValueNode_Subtract::set_link_vfunc(int i,ValueNode::Handle value)
 {
-	assert(i>=0 && i<3);
+	assert(i>=0 && i<link_count());
+
 	switch(i)
 	{
-		case 0:
-			if(set_lhs(value)) { signal_child_changed()(i);signal_value_changed()(); return true; }
-			return false;
-		case 1:
-			if(set_rhs(value)) { signal_child_changed()(i);signal_value_changed()(); return true; }
-			return false;
-		case 2:
-			scalar=value;
-			signal_child_changed()(i);signal_value_changed()();
-			return true;
+	case 0: CHECK_TYPE_AND_SET_VALUE(ref_a,  get_type());
+	case 1: CHECK_TYPE_AND_SET_VALUE(ref_b,  get_type());
+	case 2: CHECK_TYPE_AND_SET_VALUE(scalar, ValueBase::TYPE_REAL);
 	}
-
 	return false;
 }
 
 ValueNode::LooseHandle
 ValueNode_Subtract::get_link_vfunc(int i)const
 {
-	assert(i>=0 && i<3);
+	assert(i>=0 && i<link_count());
+
 	switch(i)
 	{
 		case 0: return ref_a;
@@ -234,7 +187,8 @@ ValueNode_Subtract::link_count()const
 String
 ValueNode_Subtract::link_local_name(int i)const
 {
-	assert(i>=0 && i<3);
+	assert(i>=0 && i<link_count());
+
 	switch(i)
 	{
 		case 0: return _("LHS");
@@ -247,7 +201,8 @@ ValueNode_Subtract::link_local_name(int i)const
 String
 ValueNode_Subtract::link_name(int i)const
 {
-	assert(i>=0 && i<3);
+	assert(i>=0 && i<link_count());
+
 	switch(i)
 	{
 		case 0: return "lhs";
@@ -283,6 +238,7 @@ ValueNode_Subtract::check_type(ValueBase::Type type)
 {
 	return type==ValueBase::TYPE_ANGLE
 		|| type==ValueBase::TYPE_COLOR
+		|| type==ValueBase::TYPE_GRADIENT
 		|| type==ValueBase::TYPE_INTEGER
 		|| type==ValueBase::TYPE_REAL
 		|| type==ValueBase::TYPE_TIME
