@@ -1,11 +1,12 @@
 /* === S Y N F I G ========================================================= */
 /*!	\file valuenode_twotone.h
-**	\brief Template Header
+**	\brief Header file for implementation of the "Two-Tone" valuenode conversion.
 **
-**	$Id: valuenode_twotone.h 335 2007-03-16 00:39:09Z dooglus $
+**	$Id: valuenode_twotone.h 1643 2008-02-09 19:12:18Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -53,21 +54,6 @@ public:
 
 	virtual ~ValueNode_TwoTone();
 
-//	static Handle create(ValueBase::Type id=ValueBase::TYPE_GRADIENT);
-
-	//! Sets the left-hand-side value_node
-	bool set_lhs(ValueNode::Handle a);
-
-	//! Gets the left-hand-side value_node
-	ValueNode::Handle get_lhs()const { return ref_a; }
-
-	//! Sets the right-hand-side value_node
-	bool set_rhs(ValueNode::Handle b);
-
-	//! Gets the right-hand-side value_node
-	ValueNode::Handle get_rhs()const { return ref_b; }
-
-
 	virtual bool set_link_vfunc(int i,ValueNode::Handle x);
 
 	virtual ValueNode::LooseHandle get_link_vfunc(int i)const;
