@@ -2,7 +2,7 @@
 /*!	\file waypoint.cpp
 **	\brief Template File
 **
-**	$Id: waypoint.cpp 335 2007-03-16 00:39:09Z dooglus $
+**	$Id: waypoint.cpp 1202 2007-12-15 09:58:33Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -63,7 +63,7 @@ Waypoint::Waypoint(ValueBase value, Time time):
 		after=before=INTERPOLATION_LINEAR;
 }
 
-Waypoint::Waypoint(ValueNode::Handle value_node, Time time):
+Waypoint::Waypoint(etl::handle<ValueNode> value_node, Time time):
 	priority_(0),
 	before(INTERPOLATION_TCB),
 	after(INTERPOLATION_TCB),
@@ -99,7 +99,7 @@ Waypoint::set_value(const ValueBase &x)
 }
 
 void
-Waypoint::set_value_node(const ValueNode::Handle &x)
+Waypoint::set_value_node(const etl::handle<ValueNode> &x)
 {
 	if(!value_node && x->get_type()==ValueBase::TYPE_ANGLE)
 		after=before=INTERPOLATION_LINEAR;
