@@ -2,10 +2,11 @@
 /*!	\file waypoint.h
 **	\brief Template Header
 **
-**	$Id: waypoint.h 335 2007-03-16 00:39:09Z dooglus $
+**	$Id: waypoint.h 1725 2008-02-17 09:07:26Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -77,6 +78,10 @@ public:
 
 	public:
 		Model():
+			// we don't need to initialise these 5, but the compiler thinks they're used uninitialised if we don't
+			// and this constructor isn't called often, so it's ok
+			priority(0), before(INTERPOLATION_NIL), after(INTERPOLATION_NIL), tension(0), continuity(0), bias(0), temporal_tension(0),
+
 			priority_flag(false),
 			before_flag(false),
 			after_flag(false),
@@ -141,6 +146,13 @@ public:
 		}
 	};
 
+	enum Side
+	{
+		SIDE_UNSPECIFIED, SIDE_LEFT, SIDE_RIGHT,
+
+	    SIDE_END=2				//!< \internal
+	};
+
 	/*
  --	** -- D A T A -------------------------------------------------------------
 	*/
