@@ -2,11 +2,11 @@
 /*!	\file tool/main.cpp
 **	\brief SYNFIG Tool
 **
-**	$Id: main.cpp 848 2007-10-06 02:25:36Z dooglus $
+**	$Id: main.cpp 1791 2008-02-20 18:20:54Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
-**	Copyright (c) 2007 Chris Moore
+**	Copyright (c) 2007, 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -35,6 +35,7 @@
 #include <list>
 #include <ETL/clock>
 #include <algorithm>
+#include <cstring>
 
 #include <synfig/loadcanvas.h>
 #include <synfig/savecanvas.h>
@@ -57,18 +58,26 @@ using namespace synfig;
 
 /* === M A C R O S ========================================================= */
 
+#ifdef ENABLE_NLS
+#undef _
+#define _(x) gettext(x)
+#else
+#undef _
+#define _(x) (x)
+#endif
+
 enum exit_code
 {
-	SYNFIGTOOL_OK				=0,
-	SYNFIGTOOL_FILENOTFOUND		=1,
-	SYNFIGTOOL_BORRED			=2,
-	SYNFIGTOOL_HELP				=3,
-	SYNFIGTOOL_UNKNOWNARGUMENT	=4,
-	SYNFIGTOOL_UNKNOWNERROR		=5,
-	SYNFIGTOOL_INVALIDTARGET		=6,
-	SYNFIGTOOL_RENDERFAILURE		=7,
-	SYNFIGTOOL_BLANK				=8,
-	SYNFIGTOOL_BADVERSION		=9,
+	SYNFIGTOOL_OK				= 0,
+	SYNFIGTOOL_FILENOTFOUND		= 1,
+	SYNFIGTOOL_BORED			= 2,
+	SYNFIGTOOL_HELP				= 3,
+	SYNFIGTOOL_UNKNOWNARGUMENT	= 4,
+	SYNFIGTOOL_UNKNOWNERROR		= 5,
+	SYNFIGTOOL_INVALIDTARGET	= 6,
+	SYNFIGTOOL_RENDERFAILURE	= 7,
+	SYNFIGTOOL_BLANK			= 8,
+	SYNFIGTOOL_BADVERSION		= 9,
 	SYNFIGTOOL_MISSINGARGUMENT	=10
 };
 
@@ -249,6 +258,7 @@ struct Job
 
 	int quality;
 	bool sifout;
+	bool list_canvases;
 };
 
 typedef list<String> arg_list_t;
@@ -258,9 +268,7 @@ void guid_test()
 {
 	cout<<"GUID Test"<<endl;
 	for(int i=20;i;i--)
-	{
 		cout<<synfig::GUID().get_string()<<' '<<synfig::GUID().get_string()<<endl;
-	}
 }
 
 void signal_test_func()
@@ -296,12 +304,14 @@ void display_help(int amount)
 				cerr<<strprintf(" %s %s %s",flag, arg, spaces+strlen(arg)+strlen(flag)+1)+description<<endl;
 			else
 				cerr<<strprintf(" %s %s",flag,spaces+strlen(flag))+description<<endl;
-
 		}
 	};
-	cerr<<_("syntax: ")<<progname<<" [DEFAULT OPTIONS] ([SIF FILE] [SPECIFIC OPTIONS])..."<<endl;
-	cerr<<endl;
-	if(amount>=1)
+
+	cerr << endl << _("syntax: ") << progname << " [DEFAULT OPTIONS] ([SIF FILE] [SPECIFIC OPTIONS])..." << endl << endl;
+
+	if(amount == 0)
+		Argument("--help",NULL,_("Print out usage and syntax info"));
+	else
 	{
 		Argument("-t","<output type>",_("Specify output target (Default:unknown)"));
 		Argument("-w","<pixel width>",_("Set the image width (Use zero for file default)"));
@@ -315,14 +325,17 @@ void display_help(int amount)
 		Argument("-c","<canvas id>",_("Render the canvas with the given id instead of the root."));
 		Argument("-o","<output file>",_("Specify output filename"));
 		Argument("-T","<# of threads>",_("Enable multithreaded renderer using specified # of threads"));
-
 		Argument("-b",NULL,_("Print Benchmarks"));
-
 		Argument("--fps","<framerate>",_("Set the frame rate"));
 		Argument("--time","<time>",_("Render a single frame at <seconds>"));
 		Argument("--begin-time","<time>",_("Set the starting time"));
+		Argument("--start-time","<time>",_("Set the starting time"));
 		Argument("--end-time","<time>",_("Set the ending time"));
-		Argument("--dpi","<res>",_("Set the dots-per-inch"));
+		Argument("--dpi","<res>",_("Set the physical resolution (dots-per-inch)"));
+		Argument("--dpi-x","<res>",_("Set the physical X resolution (dots-per-inch)"));
+		Argument("--dpi-y","<res>",_("Set the physical Y resolution (dots-per-inch)"));
+
+		Argument("--list-canvases",NULL,_("List the exported canvases in the composition"));
 		Argument("--append","<filename>",_("Append layers in <filename> to composition"));
 
 		Argument("--layer-info","<layer>",_("Print out layer's description, parameter info, etc."));
@@ -340,9 +353,7 @@ void display_help(int amount)
 		Argument("--signal-test",NULL,_("Test signal implementation"));
 #endif
 	}
-	else
 
-	Argument("--help",NULL,_("Print out usage and syntax info"));
 	cerr<<endl;
 }
 
@@ -367,18 +378,16 @@ int process_global_flags(arg_list_t &arg_list)
 			return SYNFIGTOOL_HELP;
 		}
 
-
 		if(*iter == "--help")
 		{
 			display_help(1);
-
 			return SYNFIGTOOL_HELP;
 		}
 
 		if(*iter == "--info")
 		{
 			cout<<PACKAGE"-"VERSION<<endl;
-			cout<<"Compiled on "__DATE__ " at "__TIME__;
+			cout<<"Compiled on "__DATE__ /* " at "__TIME__ */;
 #ifdef __GNUC__
 			cout<<" with GCC "<<__VERSION__;
 #endif
@@ -400,7 +409,8 @@ int process_global_flags(arg_list_t &arg_list)
 			synfig::Main synfig_main(dirname(progname),&p);
 			synfig::Layer::Book::iterator iter=synfig::Layer::book().begin();
 			for(;iter!=synfig::Layer::book().end();iter++)
-				cout<<iter->first<<endl;
+				if (iter->second.category != CATEGORY_DO_NOT_USE)
+					cout<<iter->first<<endl;
 
 			return SYNFIGTOOL_HELP;
 		}
@@ -410,6 +420,11 @@ int process_global_flags(arg_list_t &arg_list)
 			Progress p(PACKAGE);
 			synfig::Main synfig_main(dirname(progname),&p);
 			iter=next++;
+			if (iter==arg_list.end())
+			{
+				error("The `%s' flag requires a value.  Use --help for a list of options.", "--layer-info");
+				return SYNFIGTOOL_MISSINGARGUMENT;
+			}
 			Layer::Handle layer=synfig::Layer::create(*iter);
 			cout<<"Layer Name: "<<layer->get_name()<<endl;
 			cout<<"Localized Layer Name: "<<layer->get_local_name()<<endl;
@@ -447,7 +462,6 @@ int process_global_flags(arg_list_t &arg_list)
 			synfig::Target::Book::iterator iter=synfig::Target::book().begin();
 			for(;iter!=synfig::Target::book().end();iter++)
 				cout<<iter->first<<endl;
-
 			return SYNFIGTOOL_HELP;
 		}
 
@@ -458,7 +472,6 @@ int process_global_flags(arg_list_t &arg_list)
 			synfig::LinkableValueNode::Book::iterator iter=synfig::LinkableValueNode::book().begin();
 			for(;iter!=synfig::LinkableValueNode::book().end();iter++)
 				cout<<iter->first<<endl;
-
 			return SYNFIGTOOL_HELP;
 		}
 
@@ -469,16 +482,13 @@ int process_global_flags(arg_list_t &arg_list)
 			synfig::Importer::Book::iterator iter=synfig::Importer::book().begin();
 			for(;iter!=synfig::Importer::book().end();iter++)
 				cout<<iter->first<<endl;
-
 			return SYNFIGTOOL_HELP;
 		}
 
 		if(*iter == "--version")
 		{
 			cerr<<PACKAGE<<" "<<VERSION<<endl;
-
 			arg_list.erase(iter);
-
 			return SYNFIGTOOL_HELP;
 		}
 
@@ -494,33 +504,26 @@ int process_global_flags(arg_list_t &arg_list)
 **\n\
 **	" << endl << endl;
 			arg_list.erase(iter);
-
 			return SYNFIGTOOL_HELP;
 		}
 
 		if(*iter == "-v")
 		{
 			verbosity++;
-
 			arg_list.erase(iter);
-
 			continue;
 		}
 
 		if(*iter == "-q")
 		{
 			be_quiet=true;
-
 			arg_list.erase(iter);
-
 			continue;
 		}
 		if(*iter == "-b")
 		{
 			print_benchmarks=true;
-
 			arg_list.erase(iter);
-
 			continue;
 		}
 	}
@@ -528,6 +531,15 @@ int process_global_flags(arg_list_t &arg_list)
 	return SYNFIGTOOL_OK;
 }
 
+/* true if the given flag takes an extra parameter */
+bool flag_requires_value(String flag)
+{
+	return (flag=="-a"			|| flag=="-c"			|| flag=="-g"			|| flag=="-h"			|| flag=="-o"		||
+			flag=="-Q"			|| flag=="-s"			|| flag=="-t"			|| flag=="-T"			|| flag=="-w"		||
+			flag=="--append"	|| flag=="--begin-time"	|| flag=="--dpi"		|| flag=="--dpi-x"		|| flag=="--dpi-y"	||
+			flag=="--end-time"	|| flag=="--fps"		|| flag=="--layer-info"	|| flag=="--start-time"	|| flag=="--time"	);
+}
+
 int extract_arg_cluster(arg_list_t &arg_list,arg_list_t &cluster)
 {
 	arg_list_t::iterator iter, next;
@@ -540,34 +552,13 @@ int extract_arg_cluster(arg_list_t &arg_list,arg_list_t &cluster)
 			return SYNFIGTOOL_OK;
 		}
 
-		if(
-			*iter=="-t" ||
-			*iter=="-w" ||
-			*iter=="-h" ||
-			*iter=="-a" ||
-			*iter=="-g" ||
-			*iter=="-o" ||
-			*iter=="-s" ||
-			*iter=="-Q" ||
-			*iter=="-c" ||
-			*iter=="--fps" ||
-			*iter=="--start-time" ||
-			*iter=="--begin-time" ||
-			*iter=="--end-time" ||
-			*iter=="--start-frame" ||
-			*iter=="--end-frame" ||
-			*iter=="--time" ||
-			*iter=="--frame" ||
-			*iter=="--dpi" ||
-			*iter=="--dpi-x" ||
-			*iter=="--dpi-y" ||
-			*iter=="--append" ||
-			*iter=="-T" )
+		if (flag_requires_value(*iter))
 		{
 			cluster.push_back(*iter);
 			arg_list.erase(iter);
 			iter=next++;
-			if (iter==arg_list.end()) {
+			if (iter==arg_list.end())
+			{
 				error("The `%s' flag requires a value.  Use --help for a list of options.", cluster.back().c_str());
 				return SYNFIGTOOL_MISSINGARGUMENT;
 			}
@@ -688,6 +679,8 @@ int extract_RendDesc(arg_list_t &arg_list,RendDesc &desc)
 			//desc.set_gamma(Gamma(atof(iter->c_str())));
 			arg_list.erase(iter);
 		}
+		else if (flag_requires_value(*iter))
+			iter=next++;
 	}
 	if(w&&h)
 	{
@@ -725,6 +718,8 @@ int extract_quality(arg_list_t &arg_list,int &quality)
 			VERBOSE_OUT(1)<<strprintf(_("Quality set to %d"),quality)<<endl;
 			arg_list.erase(iter);
 		}
+		else if (flag_requires_value(*iter))
+			iter=next++;
 	}
 
 	return SYNFIGTOOL_OK;
@@ -743,6 +738,8 @@ int extract_threads(arg_list_t &arg_list,int &threads)
 			VERBOSE_OUT(1)<<strprintf(_("Threads set to %d"),threads)<<endl;
 			arg_list.erase(iter);
 		}
+		else if (flag_requires_value(*iter))
+			iter=next++;
 	}
 
 	return SYNFIGTOOL_OK;
@@ -762,6 +759,8 @@ int extract_target(arg_list_t &arg_list,string &type)
 			type=*iter;
 			arg_list.erase(iter);
 		}
+		else if (flag_requires_value(*iter))
+			iter=next++;
 	}
 
 	return SYNFIGTOOL_OK;
@@ -781,6 +780,8 @@ int extract_append(arg_list_t &arg_list,string &filename)
 			filename=*iter;
 			arg_list.erase(iter);
 		}
+		else if (flag_requires_value(*iter))
+			iter=next++;
 	}
 
 	return SYNFIGTOOL_OK;
@@ -802,6 +803,8 @@ int extract_outfile(arg_list_t &arg_list,string &outfile)
 			arg_list.erase(iter);
 			ret=SYNFIGTOOL_OK;
 		}
+		else if (flag_requires_value(*iter))
+			iter=next++;
 	}
 
 	return ret;
@@ -821,11 +824,37 @@ int extract_canvasid(arg_list_t &arg_list,string &canvasid)
 			canvasid=*iter;
 			arg_list.erase(iter);
 		}
+		else if (flag_requires_value(*iter))
+			iter=next++;
 	}
 
 	return SYNFIGTOOL_OK;
 }
 
+int extract_list_canvases(arg_list_t &arg_list,bool &list_canvases)
+{
+	arg_list_t::iterator iter, next;
+
+	for(next=arg_list.begin(),iter=next++;iter!=arg_list.end();iter=next++)
+		if(*iter=="--list-canvases")
+		{
+			list_canvases = true;
+			arg_list.erase(iter);
+		}
+
+	return SYNFIGTOOL_OK;
+}
+
+void list_child_canvases(string prefix, Canvas::Handle canvas)
+{
+	Canvas::Children children(canvas->children());
+	for (Canvas::Children::iterator iter = children.begin(); iter != children.end(); iter++)
+	{
+		cout << prefix << ":" << (*iter)->get_id() << endl;
+		list_child_canvases(prefix + ":" + (*iter)->get_id(), *iter);
+	}
+}
+
 /* === M E T H O D S ======================================================= */
 
 /* === E N T R Y P O I N T ================================================= */
@@ -836,6 +865,13 @@ int main(int argc, char *argv[])
 	arg_list_t arg_list;
 	job_list_t job_list;
 
+	setlocale(LC_ALL, "");
+
+#ifdef ENABLE_NLS
+	bindtextdomain("synfig", LOCALEDIR);
+	textdomain("synfig");
+#endif
+
 	progname=argv[0];
 	Progress p(argv[0]);
 
@@ -844,6 +880,7 @@ int main(int argc, char *argv[])
 		cerr<<_("FATAL: Synfig Version Mismatch")<<endl;
 		return SYNFIGTOOL_BADVERSION;
 	}
+
 	if(argc==1)
 	{
 		display_help(0);
@@ -881,9 +918,8 @@ int main(int argc, char *argv[])
 			  return ret;
 
 			// Open the composition
-			{
-				job_list.front().root=open_canvas(job_list.front().filename);
-			}
+			job_list.front().root=open_canvas(job_list.front().filename);
+
 			if(!job_list.front().root)
 			{
 				cerr<<_("Unable to open ")<<job_list.front().filename<<"."<<endl;
@@ -892,6 +928,10 @@ int main(int argc, char *argv[])
 				continue;
 			}
 
+			bool list_canvases = false;
+			extract_list_canvases(imageargs, list_canvases);
+			job_list.front().list_canvases = list_canvases;
+
 			job_list.front().root->set_time(0);
 
 			string canvasid;
@@ -916,7 +956,6 @@ int main(int argc, char *argv[])
 					cerr<<_("Throwing out job...")<<endl;
 					job_list.pop_front();
 					continue;
-
 				}
 			}
 			else
@@ -949,7 +988,7 @@ int main(int argc, char *argv[])
 					}
 					VERBOSE_OUT(2)<<_("Appended contents of ")<<composite_file<<endl;
 				}
-			}while(false);
+			} while(false);
 
 			VERBOSE_OUT(4)<<_("Attempting to determine target/outfile...")<<endl;
 
@@ -958,11 +997,28 @@ int main(int argc, char *argv[])
 			if(target_name.empty() && !job_list.front().outfilename.empty())
 			{
 				VERBOSE_OUT(3)<<_("Target name undefined, attempting to figure it out")<<endl;
-				string ext=job_list.front().outfilename.substr(job_list.front().outfilename.rfind('.')+1);
+				string ext = filename_extension(job_list.front().outfilename);
+				if (ext.length()) ext = ext.substr(1);
 				if(Target::ext_book().count(ext))
+				{
 					target_name=Target::ext_book()[ext];
+					info("target name not specified - using %s", target_name.c_str());
+				}
 				else
-					target_name=ext;
+				{
+					string lower_ext(ext);
+
+					for(unsigned int i=0;i<ext.length();i++)
+						lower_ext[i] = tolower(ext[i]);
+
+					if(Target::ext_book().count(lower_ext))
+					{
+						target_name=Target::ext_book()[lower_ext];
+						info("target name not specified - using %s", target_name.c_str());
+					}
+					else
+						target_name=ext;
+				}
 			}
 
 			// If the target type is STILL not yet defined, then
@@ -978,9 +1034,7 @@ int main(int argc, char *argv[])
 			// given input filename. (ie: change the extension)
 			if(job_list.front().outfilename.empty())
 			{
-				job_list.front().outfilename=job_list.front().filename;
-				job_list.front().outfilename.erase(find(job_list.front().outfilename.begin(),job_list.front().outfilename.end(),'.'),job_list.front().outfilename.end());
-				job_list.front().outfilename+='.';
+				job_list.front().outfilename = filename_sans_extension(job_list.front().filename) + '.';
 				if(Target::book().count(target_name))
 					job_list.front().outfilename+=Target::book()[target_name].second;
 				else
@@ -994,9 +1048,7 @@ int main(int argc, char *argv[])
 			job_list.front().target=synfig::Target::create(target_name,job_list.front().outfilename);
 
 			if(target_name=="sif")
-			{
 				job_list.front().sifout=true;
-			}
 			else
 			{
 				if(!job_list.front().target)
@@ -1020,9 +1072,7 @@ int main(int argc, char *argv[])
 
 			// Set the threads for the target
 			if(job_list.front().target && Target_Scanline::Handle::cast_dynamic(job_list.front().target))
-			{
 				Target_Scanline::Handle::cast_dynamic(job_list.front().target)->set_threads(threads);
-			}
 
 			if(imageargs.size())
 			{
@@ -1034,8 +1084,6 @@ int main(int argc, char *argv[])
 				job_list.pop_front();
 				continue;
 			}
-			//string bleh;
-			//getline(cin,bleh);
 		}
 	}
 
@@ -1051,7 +1099,7 @@ int main(int argc, char *argv[])
 	if(!job_list.size())
 	{
 		cerr<<_("Nothing to do!")<<endl;
-		return SYNFIGTOOL_BORRED;
+		return SYNFIGTOOL_BORED;
 	}
 
 	for(;job_list.size();job_list.pop_front())
@@ -1073,7 +1121,20 @@ int main(int argc, char *argv[])
 
 		RenderProgress p;
 		p.task(job_list.front().filename+" ==> "+job_list.front().outfilename);
-		if(!job_list.front().sifout)
+		if(job_list.front().sifout)
+		{
+			if(!save_canvas(job_list.front().outfilename,job_list.front().canvas))
+			{
+				cerr<<"Render Failure."<<endl;
+				return SYNFIGTOOL_RENDERFAILURE;
+			}
+		}
+		else if (job_list.front().list_canvases)
+		{
+			list_child_canvases(job_list.front().filename + "#", job_list.front().canvas);
+			cerr << endl;
+		}
+		else
 		{
 			VERBOSE_OUT(1)<<_("Rendering...")<<endl;
 			etl::clock timer;
@@ -1085,17 +1146,7 @@ int main(int argc, char *argv[])
 				return SYNFIGTOOL_RENDERFAILURE;
 			}
 			if(print_benchmarks)
-			{
 				cout<<job_list.front().filename+": Rendered in "<<timer()<<" seconds."<<endl;
-			}
-		}
-		else
-		{
-			if(!save_canvas(job_list.front().outfilename,job_list.front().canvas))
-			{
-				cerr<<"Render Failure."<<endl;
-				return SYNFIGTOOL_RENDERFAILURE;
-			}
 		}
 	}
 
